@@ -1,4 +1,4 @@
-/* $Id: autohint.c 4020 2015-06-14 18:15:09Z mskala $ */
+/* $Id: autohint.c 4485 2015-12-08 14:29:57Z mskala $ */
 /* Copyright (C) 2000-2012  George Williams
  * Copyright (C) 2015  Matthew Skala
  *
@@ -35,6 +35,7 @@
 #include <utype.h>
 #include <chardata.h>
 #include "edgelist.h"
+#include "hinttab.h"
 
 /* to create a type 1 font we must come up with the following entries for the
   private dictionary:
@@ -50,7 +51,7 @@ This file has routines to figure out at least some of these
 Also other routines to guess at good per-character hints
 */
 
-static void AddBlue(real val,real array[5],int force) {
+static void AddBlue(double val,double array[5],int force) {
    val=rint(val);
    if (!force && (val < array[0] - array[1] || val > array[0] + array[1]))
       return;			/* Outside of one sd */
@@ -62,7 +63,7 @@ static void AddBlue(real val,real array[5],int force) {
       array[3]=val;
 }
 
-static void MergeZones(real zone1[5],real zone2[5]) {
+static void MergeZones(double zone1[5],double zone2[5]) {
    if (zone1[2] != 0 && zone2[2] != 0 &&
        ((zone1[4] + 3 > zone2[3] && zone1[3] <= zone2[3]) ||
 	(zone2[4] + 3 > zone1[3] && zone2[3] <= zone1[3]))) {
@@ -84,341 +85,160 @@ static void MergeZones(real zone1[5],real zone2[5]) {
 /*  the same set of letter shapes and have all evolved together and have */
 /*  various common features (ascenders, descenders, lower case, etc.). Other */
 /*  scripts don't fit */
-void FindBlues(SplineFont *sf, int layer, real blues[14],
-	       real otherblues[10]) {
-   real caph[5], xh[5], ascenth[5], digith[5], descenth[5], base[5];
-
-   real otherdigits[5];
-
-   int i, j, k;
-
+void FindBlues(SplineFont *sf,int layer,double blues[14],double otherblues[10]) {
+   double zone[7][5];
+   int i,j,k;
    DBounds b;
+   
+   /* zero out all zones */
+   for (i=0;i<7;i++)
+     for (j=0;j<5;j++)
+       zone[i][j]=0;
+   
+   /* first pass:  compute statistics on things that might define the zones */
+   for (i=0;i<sf->glyphcnt;i++)
+     if ((sf->glyphs[i]!=NULL) &&
+	 (sf->glyphs[i]->layers[layer].splines!=NULL)) {
+	int enc,blue_class;
 
-   /* Go through once to get some idea of the average value so we can weed */
-   /*  out undesirables */
-   caph[0]=caph[1]=caph[2]=xh[0]=xh[1]=xh[2]=0;
-   ascenth[0]=ascenth[1]=ascenth[2]=digith[0]=digith[1]=digith[2] =
-      0;
-   descenth[0]=descenth[1]=descenth[2]=base[0]=base[1]=base[2]=0;
-   otherdigits[0]=otherdigits[1]=otherdigits[2]=0;
-   for (i=0; i < sf->glyphcnt; ++i) {
-      if (sf->glyphs[i] != NULL
-	  && sf->glyphs[i]->layers[layer].splines != NULL) {
-	 int enc=sf->glyphs[i]->unicodeenc;
+	enc=sf->glyphs[i]->unicodeenc;
+	blue_class=blue_zone_class_lookup(enc);
+	
+	if (blue_class==0)
+	  continue;
+	SplineCharFindBounds(sf->glyphs[i],&b);
+	if ((b.miny==0) && (b.maxy==0))
+	  continue;
 
-	 const unichar_t *upt;
-
-	 if (enc < 0x10000 && isalnum(enc) &&
-	     ((enc >= 32 && enc < 128) || enc==0xfe || enc==0xf0
-	      || enc==0xdf || enc==0x131 || (enc >= 0x391 && enc <= 0x3f3)
-	      || (enc >= 0x400 && enc <= 0x4e9))) {
-	    /* no accented characters (or ligatures) */
-	    if (unicode_alternates[enc >> 8] != NULL &&
-		(upt=unicode_alternates[enc >> 8][enc & 0xff]) != NULL &&
-		upt[1] != '\0')
-	       continue;
-	    SplineCharFindBounds(sf->glyphs[i], &b);
-	    if (b.miny==0 && b.maxy==0)
-	       continue;
-	    if (enc=='g' || enc=='j' || enc=='p' || enc=='q'
-		|| enc=='y' || enc==0xfe || enc==0x3c1 /* rho */  ||
-		enc==0x3c6 /* phi */  ||
-		enc==0x3c7 /* chi */  ||
-		enc==0x3c8 /* psi */  ||
-		enc==0x440 /* cyr er */  ||
-		enc==0x443 /* cyr u */  ||
-		enc==0x444 /* cyr ef */ ) {
-	       descenth[0] += b.miny;
-	       descenth[1] += b.miny * b.miny;
-	       ++descenth[2];
-	    } else if (enc=='x' || enc=='r' || enc=='o' || enc=='e' ||
-		       enc=='s' || enc=='c' || enc=='h' || enc=='k' ||
-		       enc=='l' || enc=='m' || enc=='n' ||
-		       enc==0x3b5 /* epsilon */  ||
-		       enc==0x3b9 /* iota */  ||
-		       enc==0x3ba /* kappa */  ||
-		       enc==0x3bf /* omicron */  ||
-		       enc==0x3c3 /* sigma */  ||
-		       enc==0x3c5 /* upsilon */  ||
-		       enc==0x430 /* cyr a */  ||
-		       enc==0x432 /* cyr ve */  ||
-		       enc==0x433 /* cyr ge */  ||
-		       enc==0x435 /* cyr e */  ||
-		       enc==0x436 /* cyr zhe */  ||
-		       enc==0x438 /* cyr i */  ||
-		       enc==0x43a /* cyr ka */  ||
-		       enc==0x43d /* cyr en */  ||
-		       enc==0x43e /* cyr o */  ||
-		       enc==0x441 /* cyr es */  ||
-		       enc==0x445 /* cyr ha */  ||
-		       enc==0x447 /* cyr che */  ||
-		       enc==0x448 /* cyr sha */  ||
-		       enc==0x44f /* cyr ya */ ) {
-	       base[0] += b.miny;
-	       base[1] += b.miny * b.miny;
-	       ++base[2];
-	    }
-	    /* careful of lowercase digits, 6 and 8 should be ascenders */
-	    if (enc=='6' || enc=='8') {
-	       digith[0] += b.maxy;
-	       digith[1] += b.maxy * b.maxy;
-	       ++digith[2];
-	    } else if (enc < 0x10000 && isdigit(enc)) {
-	       otherdigits[0] += b.maxy;
-	       otherdigits[1] += b.maxy * b.maxy;
-	       ++otherdigits[2];
-	    } else if (enc < 0x10000 && isupper(enc) && enc != 0x462
-		       && enc != 0x490) {
-	       caph[0] += b.maxy;
-	       caph[1] += b.maxy * b.maxy;
-	       ++caph[2];
-	    } else if (enc=='b' || enc=='d' || enc=='f' || enc=='h'
-		       || enc=='k' || enc=='l' || enc==0xf0
-		       || enc==0xfe || enc==0xdf || enc==0x3b2
-		       || enc==0x3b6 || enc==0x3b8 || enc==0x3bb
-		       || enc==0x3be
-		       || enc ==
-		       0x431
-		       /* cyr be *//* || enc==0x444 - ef may have varible height */
-		       ) {
-	       ascenth[0] += b.maxy;
-	       ascenth[1] += b.maxy * b.maxy;
-	       ++ascenth[2];
-	    } else if (enc=='c' || enc=='e' || enc=='o' || enc=='s'
-		       || enc=='u' || enc=='u' || enc=='v' || enc=='w'
-		       || enc=='x' || enc=='y' || enc=='z'
-		       || enc==0x3b5 /* epsilon */  ||
-		       enc==0x3b9 /* iota */  ||
-		       enc==0x3ba /* kappa */  ||
-		       enc==0x3bc /* mu */  ||
-		       enc==0x3bd /* nu */  ||
-		       enc==0x3bf /* omicron */  ||
-		       enc==0x3c0 /* pi */  ||
-		       enc==0x3c1 /* rho */  ||
-		       enc==0x3c5 /* upsilon */  ||
-		       enc==0x433 /* cyr ge */  ||
-		       enc==0x435 /* cyr e */  ||
-		       enc==0x436 /* cyr zhe */  ||
-		       enc==0x438 /* cyr i */  ||
-		       enc==0x43b /* cyr el */  ||
-		       enc==0x43d /* cyr en */  ||
-		       enc==0x43e /* cyr o */  ||
-		       enc==0x43f /* cyr pe */  ||
-		       enc==0x440 /* cyr er */  ||
-		       enc==0x441 /* cyr es */  ||
-		       enc==0x442 /* cyr te */  ||
-		       enc==0x443 /* cyr u */  ||
-		       enc==0x445 /* cyr ha */  ||
-		       enc==0x446 /* cyr tse */  ||
-		       enc==0x447 /* cyr che */  ||
-		       enc==0x448 /* cyr sha */  ||
-		       enc==0x449 /* cyr shcha */  ||
-		       enc==0x44a /* cyr hard sign */  ||
-		       enc==0x44b /* cyr yery */  ||
-		       enc==0x44c /* cyr soft sign */  ||
-		       enc==0x44d /* cyr reversed e */  ||
-		       enc==0x44f /* cyr ya */ ) {
-	       xh[0] += b.maxy;
-	       xh[1] += b.maxy * b.maxy;
-	       ++xh[2];
-	    }
-	 }
-      }
+	/* check all seven proto-blue zones */
+	for (j=0;j<7;j++)
+	  if ((blue_class&(1<<j))!=0) {
+	     if ((j==bzci_base) || (j==bzci_descenth)) {
+		zone[j][0]+=b.miny;
+		zone[j][1]+=(b.miny*b.miny);
+	     } else {
+		zone[j][0]+=b.maxy;
+		zone[j][1]+=(b.maxy*b.maxy);
+	     }
+	     zone[j][2]++;
+	  }
+     }
+   
+   /* check whether numerals are old style */
+   if ((zone[bzci_digith][2]>0) && (zone[bzci_otherdigits][2]>0) &&
+       ((zone[bzci_otherdigits][0]/zone[bzci_otherdigits][2])>
+	   0.95*(zone[bzci_digith][0]/zone[bzci_digith][2]))) {
+      /* no, 6 and 8 are about the same height as the others */
+      /* in that case, accumulate others with 6 and 8 */
+      zone[bzci_digith][0]+=zone[bzci_otherdigits][0];
+      zone[bzci_digith][1]+=zone[bzci_otherdigits][1];
+      zone[bzci_digith][2]+=zone[bzci_otherdigits][2];
    }
-   if (otherdigits[2] > 0 && digith[2] > 0) {
-      if (otherdigits[0] / otherdigits[2] >= .95 * digith[0] / digith[2]) {
-	 /* all digits are about the same height, not lowercase */
-	 digith[0] += otherdigits[0];
-	 digith[1] += otherdigits[1];
-	 digith[2] += otherdigits[2];
-      }
+   /* note "other digits" are not further used */
+   
+   /* compute sample mean and std. dev., for samples of 2 or more items */
+   for (j=0;j<6;j++)
+     if (zone[j][2]>1) {
+	zone[j][1]=sqrt((zone[j][1]-zone[j][0]*zone[j][0]/zone[j][2])
+			/(zone[j][2]-1));
+	zone[j][0]/=zone[j][2];
+     }
+   /* initial acceptance range is +-1 sigma from mean */
+
+   /* force zero to be included in base acceptance range */
+   if (zone[bzci_base][0]+zone[bzci_base][1]<0)
+     zone[bzci_base][1]=-zone[bzci_base][0];
+   if (zone[bzci_base][0]-zone[bzci_base][1]>0)
+     zone[bzci_base][1]=zone[bzci_base][0];
+
+   /* second pass:  find range of accepted values */
+   for (i=0;i<sf->glyphcnt;i++)
+     if ((sf->glyphs[i]!=NULL) &&
+	 (sf->glyphs[i]->layers[layer].splines!=NULL)) {
+	int enc,blue_class;
+
+	enc=sf->glyphs[i]->unicodeenc;
+	blue_class=blue_zone_class_lookup(enc);
+	
+	if (blue_class==0)
+	  continue;
+	SplineCharFindBounds(sf->glyphs[i],&b);
+	if ((b.miny==0) && (b.maxy==0))
+	  continue;
+	
+	/* "other" digits are now counted as digits */
+	if ((blue_class&bzcm_otherdigits)!=0)
+	  blue_class|=bzcm_digith;
+
+	/* check six remaining proto-blue zones */
+	for (j=0;j<6;j++)
+	  AddBlue(((j==bzci_base) || (j==bzci_descenth))?b.miny:b.maxy,
+		  zone[j],
+		  ((j==bzci_base) && ((enc=='O') || (enc=='o'))) ||
+		  ((j==bzci_xh) && ((enc=='x') || (enc=='o'))));
+     }
+   
+   /* GW: "the descent blue zone merges into the base zone" */
+   MergeZones(zone[bzci_descenth],zone[bzci_base]);
+   MergeZones(zone[bzci_xh],zone[bzci_base]);
+   MergeZones(zone[bzci_ascenth],zone[bzci_caph]);
+   MergeZones(zone[bzci_digith],zone[bzci_caph]);
+   MergeZones(zone[bzci_xh],zone[bzci_caph]);
+   MergeZones(zone[bzci_ascenth],zone[bzci_digith]);
+   MergeZones(zone[bzci_xh],zone[bzci_digith]);
+
+   /* empty output arrays */
+   if (otherblues!=NULL)
+     for (i=0;i<10;i++)
+       otherblues[i]=0;
+   for (i=0;i<14;i++)
+     blues[i]=0;
+
+   /* copy descent zone into "other blues" array, if both exist */
+   if ((otherblues!=NULL) && (zone[bzci_descenth][2]!=0)) {
+      otherblues[0]=zone[bzci_descenth][3];
+      otherblues[1]=zone[bzci_descenth][4];
    }
 
-   if (xh[2] > 1) {
-      xh[1]=sqrt((xh[1] - xh[0] * xh[0] / xh[2]) / (xh[2] - 1));
-      xh[0] /= xh[2];
-   }
-   if (ascenth[2] > 1) {
-      ascenth[1] =
-	 sqrt((ascenth[1] -
-	       ascenth[0] * ascenth[0] / ascenth[2]) / (ascenth[2] - 1));
-      ascenth[0] /= ascenth[2];
-   }
-   if (caph[2] > 1) {
-      caph[1]=sqrt((caph[1] - caph[0] * caph[0] / caph[2]) / (caph[2] - 1));
-      caph[0] /= caph[2];
-   }
-   if (digith[2] > 1) {
-      digith[1] =
-	 sqrt((digith[1] - digith[0] * digith[0] / digith[2]) / (digith[2] -
-								 1));
-      digith[0] /= digith[2];
-   }
-   if (base[2] > 1) {
-      base[1]=sqrt((base[1] - base[0] * base[0] / base[2]) / (base[2] - 1));
-      base[0] /= base[2];
-   }
-   if (descenth[2] > 1) {
-      descenth[1] =
-	 sqrt((descenth[1] -
-	       descenth[0] * descenth[0] / descenth[2]) / (descenth[2] - 1));
-      descenth[0] /= descenth[2];
-   }
-
-   /* we'll accept values between +/- 1sd of the mean */
-   /* array[0]==mean, array[1]==sd, array[2]==cnt, array[3]=min, array[4]==max */
-   if (base[0] + base[1] < 0)
-      base[1]=-base[0];	/* Make sure 0 is within the base bluezone */
-   caph[3]=caph[4]=0;
-   xh[3]=xh[4]=0;
-   ascenth[3]=ascenth[4]=0;
-   digith[3]=digith[4]=0;
-   descenth[3]=descenth[4]=0;
-   base[3]=base[4]=0;
-   for (i=0; i < sf->glyphcnt; ++i)
-      if (sf->glyphs[i] != NULL) {
-	 int enc=sf->glyphs[i]->unicodeenc;
-
-	 const unichar_t *upt;
-
-	 if (enc < 0x10000 && isalnum(enc) &&
-	     ((enc >= 32 && enc < 128) || enc==0xfe || enc==0xf0
-	      || enc==0xdf || (enc >= 0x391 && enc <= 0x3f3)
-	      || (enc >= 0x400 && enc <= 0x4e9))) {
-	    /* no accented characters (or ligatures) */
-	    if (unicode_alternates[enc >> 8] != NULL &&
-		(upt=unicode_alternates[enc >> 8][enc & 0xff]) != NULL &&
-		upt[1] != '\0')
-	       continue;
-	    SplineCharFindBounds(sf->glyphs[i], &b);
-	    if (b.miny==0 && b.maxy==0)
-	       continue;
-	    if (enc=='g' || enc=='j' || enc=='p' || enc=='q'
-		|| enc=='y' || enc==0xfe || enc==0x3c6 || enc==0x3c8
-		|| enc==0x440 || enc==0x443 || enc==0x444) {
-	       AddBlue(b.miny, descenth, false);
-	    } else {
-	       /* O and o get forced into the baseline blue value even if they */
-	       /*  are beyond 1 sd */
-	       AddBlue(b.miny, base, enc=='O' || enc=='o');
-	    }
-	    if (enc < 0x10000 && isdigit(enc)) {
-	       AddBlue(b.maxy, digith, false);
-	    } else if (enc < 0x10000 && isupper(enc)) {
-	       AddBlue(b.maxy, caph, enc=='O');
-	    } else if (enc=='b' || enc=='d' || enc=='f' || enc=='h'
-		       || enc=='k' || enc=='l' || enc=='t'
-		       || enc==0xf0 || enc==0xfe || enc==0xdf
-		       || enc==0x3b2 || enc==0x3b6 || enc==0x3b8
-		       || enc==0x3bb || enc==0x3be || enc==0x431) {
-	       AddBlue(b.maxy, ascenth, false);
-	    } else if (enc=='c' || enc=='e' || enc=='o' || enc=='s'
-		       || enc=='u' || enc=='u' || enc=='v' || enc=='w'
-		       || enc=='x' || enc=='y' || enc=='z'
-		       || enc==0x3b5 /* epsilon */  ||
-		       enc==0x3b9 /* iota */  ||
-		       enc==0x3ba /* kappa */  ||
-		       enc==0x3bc /* mu */  ||
-		       enc==0x3bd /* nu */  ||
-		       enc==0x3bf /* omicron */  ||
-		       enc==0x3c0 /* pi */  ||
-		       enc==0x3c1 /* rho */  ||
-		       enc==0x3c5 /* upsilon */  ||
-		       enc==0x433 /* cyr ge */  ||
-		       enc==0x435 /* cyr e */  ||
-		       enc==0x436 /* cyr zhe */  ||
-		       enc==0x438 /* cyr i */  ||
-		       enc==0x43b /* cyr el */  ||
-		       enc==0x43d /* cyr en */  ||
-		       enc==0x43e /* cyr o */  ||
-		       enc==0x43f /* cyr pe */  ||
-		       enc==0x440 /* cyr er */  ||
-		       enc==0x441 /* cyr es */  ||
-		       enc==0x442 /* cyr te */  ||
-		       enc==0x443 /* cyr u */  ||
-		       enc==0x445 /* cyr ha */  ||
-		       enc==0x446 /* cyr tse */  ||
-		       enc==0x447 /* cyr che */  ||
-		       enc==0x448 /* cyr sha */  ||
-		       enc==0x449 /* cyr shcha */  ||
-		       enc==0x44a /* cyr hard sign */  ||
-		       enc==0x44b /* cyr yery */  ||
-		       enc==0x44c /* cyr soft sign */  ||
-		       enc==0x44d /* cyr reversed e */  ||
-		       enc==0x44f /* cyr ya */ ) {
-	       AddBlue(b.maxy, xh, enc=='o' || enc=='x');
-	    }
-	 }
-      }
-
-   /* the descent blue zone merges into the base zone */
-   MergeZones(descenth, base);
-   MergeZones(xh, base);
-   MergeZones(ascenth, caph);
-   MergeZones(digith, caph);
-   MergeZones(xh, caph);
-   MergeZones(ascenth, digith);
-   MergeZones(xh, digith);
-
-   if (otherblues != NULL)
-      for (i=0; i < 10; ++i)
-	 otherblues[i]=0;
-   for (i=0; i < 14; ++i)
-      blues[i]=0;
-
-   if (otherblues != NULL && descenth[2] != 0) {
-      otherblues[0]=descenth[3];
-      otherblues[1]=descenth[4];
-   }
+   /* copy five standard blue zones into output array if they exist */
    i=0;
-   if (base[2]==0
-       && (xh[2] != 0 || ascenth[2] != 0 || caph[2] != 0 || digith[2] != 0)) {
-      /* base line blue value must be present if any other value is */
-      /*  make one up if we don't have one */
+   if ((zone[bzci_base][2]==0) &&
+       ((zone[bzci_xh][2]!=0) ||
+	   (zone[bzci_caph][2]!=0) ||
+	   (zone[bzci_digith][2]!=0) ||
+	   (zone[bzci_ascenth][2]!=0))) {
+      /* must have a "base" blue zone if any of these other four are
+       * present, so supply a fake one */
       blues[0]=-20;
       blues[1]=0;
       i=2;
-   } else if (base[2] != 0) {
-      blues[0]=base[3];
-      blues[1]=base[4];
-      i=2;
-   }
-   if (xh[2] != 0) {
-      blues[i++]=xh[3];
-      blues[i++]=xh[4];
-   }
-   if (caph[2] != 0) {
-      blues[i++]=caph[3];
-      blues[i++]=caph[4];
-   }
-   if (digith[2] != 0) {
-      blues[i++]=digith[3];
-      blues[i++]=digith[4];
-   }
-   if (ascenth[2] != 0) {
-      blues[i++]=ascenth[3];
-      blues[i++]=ascenth[4];
    }
+   for (j=0;j<5;j++)
+     if (zone[j][2]!=0) {
+	blues[i++]=zone[j][3];
+	blues[i++]=zone[j][4];
+     }
 
-   for (j=0; j < i; j += 2)
-      for (k=j + 2; k < i; k += 2) {
-	 if (blues[j] > blues[k]) {
-	    real temp=blues[j];
+   /* sort */
+   for (j=0;j<i;j+=2)
+     for (k=j+2;k<i;k+=2) {
+	if (blues[j]>blues[k]) {
+	   double temp;
+	   
+	   temp=blues[j];
+	   blues[j]=blues[k];
+	   blues[k]=temp;
 
-	    blues[j]=blues[k];
-	    blues[k]=temp;
-	    temp=blues[j + 1];
-	    blues[j + 1]=blues[k + 1];
-	    blues[k + 1]=temp;
-	 }
-      }
+	   temp=blues[j+1];
+	   blues[j+1]=blues[k+1];
+	   blues[k+1]=temp;
+	}
+     }
 }
 
 static int PVAddBlues(BlueData *bd,int bcnt,char *pt) {
    char *end;
-
-   real val1, val2;
-
+   double val1, val2;
    int i, j;
 
    if (pt==NULL)
@@ -456,24 +276,16 @@ static int PVAddBlues(BlueData *bd,int bcnt,char *pt) {
 /* Quick and dirty (and sometimes wrong) approach to figure out the common */
 /* alignment zones in latin (greek, cyrillic) alphabets */
 void QuickBlues(SplineFont *_sf, int layer, BlueData * bd) {
-   real xheight=-1e10, caph=-1e10, ascent=-1e10, descent =
+   double xheight=-1e10, caph=-1e10, ascent=-1e10, descent =
       1e10, max, min;
-   real xheighttop=-1e10, caphtop=-1e10;
-
-   real numh=-1e10, numhtop=-1e10;
-
-   real base=-1e10, basebelow=1e10;
-
+   double xheighttop=-1e10, caphtop=-1e10;
+   double numh=-1e10, numhtop=-1e10;
+   double base=-1e10, basebelow=1e10;
    SplineFont *sf;
-
    SplinePoint *sp;
-
    SplineSet *spl;
-
    int i, j, bcnt;
-
    SplineChar *t;
-
    char *pt;
 
    /* Get the alignment zones we care most about */
@@ -728,14 +540,11 @@ void ElFreeEI(EIList * el) {
    }
 }
 
-static int EIAddEdge(Spline *spline,real tmin,real tmax,EIList *el) {
+static int EIAddEdge(Spline *spline,double tmin,double tmax,EIList *el) {
    EI *new=calloc(1, sizeof(EI));
-
-   real min, max, temp;
-
+   double min, max, temp;
    Spline1D *s;
-
-   real dxdtmin, dxdtmax, dydtmin, dydtmax;
+   double dxdtmin, dxdtmax, dydtmin, dydtmax;
 
    new->spline=spline;
    new->tmin=tmin;
@@ -843,8 +652,7 @@ static int EIAddEdge(Spline *spline,real tmin,real tmax,EIList *el) {
 }
 
 static void EIAddSpline(Spline *spline,EIList *el) {
-   extended ts[6], temp;
-
+   double ts[6], temp;
    int i, j, base, last;
 
    ts[0]=0;
@@ -879,7 +687,6 @@ static void EIAddSpline(Spline *spline,EIList *el) {
 
 void ELFindEdges(SplineChar * sc, EIList * el) {
    Spline *spline, *first;
-
    SplineSet *spl;
 
    el->sc=sc;
@@ -909,8 +716,7 @@ void ELFindEdges(SplineChar * sc, EIList * el) {
 
 static int IsBiggerSlope(EI *test,EI *base,int major) {
    int other=!major;
-
-   real tdo, tdm, bdo, bdm, t;
+   double tdo, tdm, bdo, bdm, t;
 
    if ((major && test->vup) || (!major && test->hup))
       t=test->tmin;
@@ -950,9 +756,7 @@ static int IsBiggerSlope(EI *test,EI *base,int major) {
 
 void ELOrder(EIList * el, int major) {
    int other=!major;
-
    int pos;
-
    EI *ei, *prev, *test;
 
    el->low=floor(el->coordmin[major]);
@@ -1033,7 +837,6 @@ static HintInstance *HIMerge(HintInstance *into,HintInstance *hi) {
 
 StemInfo *HintCleanup(StemInfo * stem, int dosort, int instance_count) {
    StemInfo *s, *p=NULL, *t, *pt, *sn;
-
    int swap;
 
    for (s=stem; s != NULL; p=s, s=s->next) {
@@ -1103,16 +906,13 @@ StemInfo *HintCleanup(StemInfo * stem, int dosort, int instance_count) {
    return (stem);
 }
 
-real EITOfNextMajor(EI * e, EIList * el, real sought_m) {
+double EITOfNextMajor(EI * e, EIList * el, double sought_m) {
    /* We want to find t so that Mspline(t)=sought_m */
    /*  the curve is monotonic */
    Spline1D *msp=&e->spline->splines[el->major];
-
-   real new_t;
-
-   real found_m;
-
-   real t_mmax, t_mmin;
+   double new_t;
+   double found_m;
+   double t_mmax, t_mmin;
 
    if (msp->a==0 && msp->b==0) {
       if (msp->c==0) {
@@ -1148,7 +948,6 @@ real EITOfNextMajor(EI * e, EIList * el, real sought_m) {
 
 EI *EIActiveListReorder(EI * active, int *change) {
    int any;
-
    EI *pr, *apt;
 
    *change=false;
@@ -1181,12 +980,10 @@ EI *EIActiveListReorder(EI * active, int *change) {
    return (active);
 }
 
-EI *EIActiveEdgesRefigure(EIList * el, EI * active, real i, int major,
+EI *EIActiveEdgesRefigure(EIList * el, EI * active, double i, int major,
 			  int *_change) {
    EI *apt, *pr, *npt;
-
    int change=false, subchange;
-
    int other=!major;
 
    /* first remove any entry which doesn't intersect the new scan line */
@@ -1252,7 +1049,7 @@ EI *EIActiveEdgesRefigure(EIList * el, EI * active, real i, int major,
 /* Ah, but also if they are at different intersections and are connected */
 /*  by a series of horizontal/vertical lines (whichever are invisible to major)*/
 /*  then we still should. */
-int EISameLine(EI * e, EI * n, real i, int major) {
+int EISameLine(EI * e, EI * n, double i, int major) {
    EI *t;
 
    if (n != NULL &&		/*n->up==e->up && */
@@ -1289,7 +1086,7 @@ int EISameLine(EI * e, EI * n, real i, int major) {
    return (false);
 }
 
-int EISkipExtremum(EI * e, real i, int major) {
+int EISkipExtremum(EI * e, double i, int major) {
    EI *n=e->aenext, *t;
 
    if (n==NULL)
@@ -1329,8 +1126,7 @@ int EISkipExtremum(EI * e, real i, int major) {
 
 static StemInfo *StemRemoveFlexCandidates(StemInfo *stems) {
    StemInfo *s, *t, *sn;
-
-   const real BlueShift=7;
+   const double BlueShift=7;
 
    /* Suppose we have something that is a flex candidate */
    /* We might get two hints from it... one from the two end points */
@@ -1357,37 +1153,38 @@ static StemInfo *StemRemoveFlexCandidates(StemInfo *stems) {
    return (stems);
 }
 
-real HIlen(StemInfo * stems) {
+double HIlen(StemInfo * stems) {
    HintInstance *hi;
-
-   real len=0;
+   double len=0;
 
    for (hi=stems->where; hi != NULL; hi=hi->next)
       len += hi->end - hi->begin;
    return (len);
 }
 
-real HIoverlap(HintInstance * mhi, HintInstance * thi) {
+/* Compute the sum, over all pairs of one HintInstance in the mhi list
+ * and one in the thi list, of the lengths of the intersections of the two
+ * intervals in the pair.  Assume both lists are sorted in increasing
+ * order of interval start. */
+double HIoverlap(HintInstance *mhi,HintInstance *thi) {
    HintInstance *hi;
+   double len=0.0;
+   double s,e;
 
-   real len=0;
-
-   real s, e;
-
-   for (; mhi != NULL; mhi=mhi->next) {
-      for (hi=thi; hi != NULL && hi->begin <= mhi->end; hi=hi->next) {
-	 if (hi->end < mhi->begin) {
+   for (;mhi!=NULL;mhi=mhi->next) {
+      for (hi=thi;(hi!=NULL) && (hi->begin<=mhi->end);hi=hi->next) {
+	 if (hi->end<mhi->begin) {
 	    thi=hi;
 	    continue;
 	 }
-	 s=hi->begin < mhi->begin ? mhi->begin : hi->begin;
-	 e=hi->end > mhi->end ? mhi->end : hi->end;
-	 if (e < s)
+	 s=(hi->begin<mhi->begin)?mhi->begin:hi->begin;
+	 e=(hi->end>mhi->end)?mhi->end:hi->end;
+	 if (e<s)
 	    continue;		/* Shouldn't happen */
-	 len += e - s;
+	 len+=(e-s);
       }
    }
-   return (len);
+   return len;
 }
 
 int StemInfoAnyOverlaps(StemInfo * stems) {
@@ -1399,31 +1196,40 @@ int StemInfoAnyOverlaps(StemInfo * stems) {
    return (false);
 }
 
-int StemListAnyConflicts(StemInfo * stems) {
+int StemListAnyConflicts(StemInfo *stems) {
    StemInfo *s;
-
    int any=false;
+   double w,x,y,z;
 
-   double end;
-
-   for (s=stems; s != NULL; s=s->next)
+   for (s=stems;s!=NULL;s=s->next)
       s->hasconflicts=false;
-   while (stems != NULL) {
-      end=stems->width < 0 ? stems->start : stems->start + stems->width;
-      for (s=stems->next;
-	   s != NULL
-	   && (s->width > 0 ? s->start : s->start + s->width) <= end;
-	   s=s->next) {
-	 stems->hasconflicts=true;
-	 s->hasconflicts=true;
-	 any=true;
+   for (;stems!=NULL;stems=stems->next) {
+      if (stems->width<0) {
+	 w=stems->start+stems->width;
+	 x=stems->start;
+      } else {
+	 w=stems->start;
+	 x=stems->start+stems->width;
+      }
+      for (s=stems->next;s!=NULL;s=s->next) {
+	 if (s->width<0) {
+	    y=s->start+s->width;
+	    z=s->start;
+	 } else {
+	    y=s->start;
+	    z=s->start+s->width;
+	 }
+	 if ((w<=z) && (x>=y)) {
+	    stems->hasconflicts=true;
+	    s->hasconflicts=true;
+	    any=true;
+	 }
       }
-      stems=stems->next;
    }
-   return (any);
+   return any;
 }
 
-HintInstance *HICopyTrans(HintInstance * hi, real mul, real offset) {
+HintInstance *HICopyTrans(HintInstance * hi, double mul, double offset) {
    HintInstance *first=NULL, *last, *cur, *p;
 
    while (hi != NULL) {
@@ -1457,17 +1263,11 @@ HintInstance *HICopyTrans(HintInstance * hi, real mul, real offset) {
 static HintInstance *SCGuessHintPoints(SplineChar *sc,int layer,
 				       StemInfo * stem, int major, int off) {
    SplinePoint *starts[20], *ends[20];
-
    int spt=0, ept=0;
-
    SplinePointList *spl;
-
    SplinePoint *sp, *np;
-
    int sm, wm, i, j, val;
-
-   real coord;
-
+   double coord;
    HintInstance *head, *test, *cur, *prev;
 
    for (spl=sc->layers[layer].splines; spl != NULL; spl=spl->next) {
@@ -1521,16 +1321,14 @@ static HintInstance *SCGuessHintPoints(SplineChar *sc,int layer,
 
 static HintInstance *StemAddHIFromActive(struct stemdata *stem,int major) {
    int i;
-
    HintInstance *head=NULL, *cur, *t;
-
    double mino, maxo;
-
-   double dir=((real *) & stem->unit.x)[major] < 0 ? -1 : 1;
+   double dir=((double *) & stem->unit.x)[major] < 0 ? -1 : 1;
 
    for (i=0; i < stem->activecnt; ++i) {
-      mino=dir * stem->active[i].start + ((real *) & stem->left.x)[major];
-      maxo=dir * stem->active[i].end + ((real *) & stem->left.x)[major];
+      mino=dir * stem->active[i].start + ((double *) & stem->left.x)[major];
+      maxo=dir * stem->active[i].end + ((double *) & stem->left.x)[major];
+      ErrorMsg(1,"adding (%f,%f)\n",mino,maxo);
       cur=chunkalloc(sizeof(HintInstance));
       if (dir > 0) {
 	 cur->begin=mino;
@@ -1552,7 +1350,6 @@ static HintInstance *StemAddHIFromActive(struct stemdata *stem,int major) {
 
 static HintInstance *DStemAddHIFromActive(struct stemdata *stem) {
    int i;
-
    HintInstance *head=NULL, *cur, *t;
 
    for (i=0; i < stem->activecnt; ++i) {
@@ -1571,9 +1368,7 @@ static HintInstance *DStemAddHIFromActive(struct stemdata *stem) {
 static void SCGuessHVHintInstances(SplineChar *sc,int layer,StemInfo *si,
 				   int is_v) {
    struct glyphdata *gd;
-
    struct stemdata *sd;
-
    double em_size=(sc->parent != NULL) ?
       sc->parent->ascent + sc->parent->descent : 1000;
 
@@ -1591,13 +1386,9 @@ static void SCGuessHVHintInstances(SplineChar *sc,int layer,StemInfo *si,
 static void SCGuessHintInstancesLight(SplineChar *sc,int layer,
 				      StemInfo * stem, int major) {
    SplinePointList *spl;
-
    SplinePoint *sp, *np;
-
    int sm, wm, off;
-
-   real ob, oe;
-
+   double ob, oe;
    HintInstance *s=NULL, *w=NULL, *cur, *p, *t, *n, *w2;
 
    /* We've got a hint (from somewhere, old data, reading in a font, user specified etc.) */
@@ -1647,7 +1438,7 @@ static void SCGuessHintInstancesLight(SplineChar *sc,int layer,
 	 if (sm || wm) {
 	    cur=chunkalloc(sizeof(HintInstance));
 	    if (ob > oe) {
-	       real temp=ob;
+	       double temp=ob;
 
 	       ob=oe;
 	       oe=temp;
@@ -1719,7 +1510,6 @@ static void SCGuessHintInstancesLight(SplineChar *sc,int layer,
 	    w2=NULL;
 	 if (w2==NULL && w != NULL) {
 	    HintInstance *best=NULL;
-
 	    double best_off=1e10, off;
 
 	    for (w2=w; w2 != NULL; w2=w2->next) {
@@ -1791,17 +1581,11 @@ static StemInfo *StemInfoAdd(StemInfo *list,StemInfo *new) {
 void SCGuessHintInstancesList(SplineChar * sc, int layer, StemInfo * hstem,
 			      StemInfo * vstem, DStemInfo * dstem,
 			      int hvforce, int dforce) {
-
    struct glyphdata *gd;
-
    struct stemdata *sd;
-
    int i, cnt=0, hneeds_gd=false, vneeds_gd=false, dneeds_gd=false;
-
    StemInfo *test;
-
    DStemInfo *dtest;
-
    double em_size=(sc->parent != NULL) ?
       sc->parent->ascent + sc->parent->descent : 1000;
 
@@ -1879,9 +1663,7 @@ void SCGuessHintInstancesList(SplineChar * sc, int layer, StemInfo * hstem,
 
 void SCGuessDHintInstances(SplineChar * sc, int layer, DStemInfo * ds) {
    struct glyphdata *gd;
-
    struct stemdata *sd;
-
    double em_size=(sc->parent != NULL) ?
       sc->parent->ascent + sc->parent->descent : 1000;
 
@@ -1901,12 +1683,12 @@ void SCGuessDHintInstances(SplineChar * sc, int layer, DStemInfo * ds) {
 }
 
 void SCGuessHHintInstancesAndAdd(SplineChar * sc, int layer, StemInfo * stem,
-				 real guess1, real guess2) {
+				 double guess1, double guess2) {
    SCGuessHVHintInstances(sc, layer, stem, 0);
    sc->hstem=StemInfoAdd(sc->hstem, stem);
    if (stem->where==NULL && guess1 != 0x80000000) {
       if (guess1 > guess2) {
-	 real temp=guess1;
+	 double temp=guess1;
 
 	 guess1=guess2;
 	 guess2=temp;
@@ -1924,12 +1706,12 @@ void SCGuessHHintInstancesAndAdd(SplineChar * sc, int layer, StemInfo * stem,
 }
 
 void SCGuessVHintInstancesAndAdd(SplineChar * sc, int layer, StemInfo * stem,
-				 real guess1, real guess2) {
+				 double guess1, double guess2) {
    SCGuessHVHintInstances(sc, layer, stem, 1);
    sc->vstem=StemInfoAdd(sc->vstem, stem);
    if (stem->where==NULL && guess1 != 0x80000000) {
       if (guess1 > guess2) {
-	 real temp=guess1;
+	 double temp=guess1;
 
 	 guess1=guess2;
 	 guess2=temp;
@@ -1971,15 +1753,10 @@ void SCGuessVHintInstancesList(SplineChar * sc, int layer) {
    tests are required before we can add this stem to the given glyph. */
 int MergeDStemInfo(SplineFont *sf, DStemInfo ** ds, DStemInfo * test) {
    DStemInfo *dn, *cur, *prev, *next, *temp;
-
    double dot, loff, roff, soff, dist_error_diag;
-
    double ibegin, iend;
-
    int overlap;
-
    BasePoint *base, *nbase, *pbase;
-
    HintInstance *hi;
 
    if (*ds==NULL) {
@@ -2089,11 +1866,10 @@ int MergeDStemInfo(SplineFont *sf, DStemInfo ** ds, DStemInfo * test) {
    return (true);
 }
 
-static StemInfo *RefHintsMerge(StemInfo *into,StemInfo *rh,real mul,
-			       real offset, real omul, real oofset) {
+static StemInfo *RefHintsMerge(StemInfo *into,StemInfo *rh,double mul,
+			       double offset, double omul, double oofset) {
    StemInfo *prev, *h, *n;
-
-   real start, width;
+   double start, width;
 
    for (; rh != NULL; rh=rh->next) {
       start=rh->start * mul + offset;
@@ -2123,10 +1899,9 @@ static StemInfo *RefHintsMerge(StemInfo *into,StemInfo *rh,real mul,
 }
 
 static DStemInfo *RefDHintsMerge(SplineFont *sf,DStemInfo *into,
-				 DStemInfo * rh, real xmul, real xoffset,
-				 real ymul, real yoffset) {
+				 DStemInfo * rh, double xmul, double xoffset,
+				 double ymul, double yoffset) {
    DStemInfo *new;
-
    double dmul;
 
    for (; rh != NULL; rh=rh->next) {
@@ -2215,7 +1990,6 @@ static void AutoHintRefs(SplineChar *sc,int layer,BlueData *bd,
 
 void SCClearHints(SplineChar * sc) {
    int any=sc->hstem != NULL || sc->vstem != NULL || sc->dstem != NULL;
-
    int layer;
 
    for (layer=ly_fore; layer < sc->layer_cnt; ++layer) {
@@ -2236,9 +2010,7 @@ void SCClearHints(SplineChar * sc) {
 
 static void _SCClearHintMasks(SplineChar *sc,int layer,int counterstoo) {
    SplineSet *spl;
-
    SplinePoint *sp;
-
    RefChar *ref;
 
    if (counterstoo) {
@@ -2278,11 +2050,8 @@ static void _SCClearHintMasks(SplineChar *sc,int layer,int counterstoo) {
 
 static void SCFigureSimpleCounterMasks(SplineChar *sc) {
    SplineChar *scs[MmMax];
-
    int hadh3, hadv3, i, vbase;
-
    HintMask mask;
-
    StemInfo *h;
 
    if (sc->countermask_cnt != 0)
@@ -2315,9 +2084,7 @@ static void SCFigureSimpleCounterMasks(SplineChar *sc) {
 /*  coordinate) with main */
 static int stemmatches(StemInfo *main) {
    StemInfo *last=main, *test;
-
-   real mlen, olen;
-
+   double mlen, olen;
    int cnt;
 
    cnt=1;			/* for the main stem */
@@ -2364,11 +2131,8 @@ static int FigureCounters(StemInfo *stems,HintMask mask) {
 
 void SCFigureCounterMasks(SplineChar * sc) {
    HintMask masks[30];
-
    uint32_t script;
-
    StemInfo *h;
-
    int mc=0, i;
 
    /* I'm not supporting counter hints for mm fonts */
@@ -2417,7 +2181,6 @@ void SCFigureCounterMasks(SplineChar * sc) {
 
 void SCClearHintMasks(SplineChar * sc, int layer, int counterstoo) {
    MMSet *mm=sc->parent->mm;
-
    int i;
 
    if (mm==NULL)
@@ -2436,7 +2199,6 @@ void SCClearHintMasks(SplineChar * sc, int layer, int counterstoo) {
 
 static StemInfo *OnHHint(SplinePoint *sp,StemInfo *s) {
    StemInfo *possible=NULL;
-
    HintInstance *hi;
 
    if (sp==NULL)
@@ -2461,7 +2223,6 @@ static StemInfo *OnHHint(SplinePoint *sp,StemInfo *s) {
 
 static StemInfo *OnVHint(SplinePoint *sp,StemInfo *s) {
    StemInfo *possible=NULL;
-
    HintInstance *hi;
 
    if (sp==NULL)
@@ -2503,9 +2264,7 @@ static int ConflictsWithMask(StemInfo *stems,HintMask mask,StemInfo *h) {
 static void FigureHintMask(SplineChar *scs[MmMax],SplinePoint *to[MmMax],
 			   int instance_count, HintMask mask) {
    StemInfo *s;
-
    int i;
-
    SplinePoint *sp;
 
    memset(mask, '\0', sizeof(HintMask));
@@ -2566,7 +2325,6 @@ static void FigureHintMask(SplineChar *scs[MmMax],SplinePoint *to[MmMax],
 static int TestHintMask(SplineChar *scs[MmMax],SplinePoint *to[MmMax],
 			int instance_count, HintMask mask) {
    StemInfo *h=NULL, *v=NULL;
-
    int i;
 
    for (i=0; i < instance_count; ++i) {
@@ -2607,7 +2365,6 @@ static void UnnumberHints(SplineChar *sc) {
 
 static int NumberHints(SplineChar *sc) {
    StemInfo *h;
-
    int hcnt=0;
 
    for (h=sc->hstem; h != NULL; h=h->next)
@@ -2627,7 +2384,7 @@ static void UntickHints(SplineChar *sc) {
 }
 
 struct coords {
-   real coords[MmMax];
+   double coords[MmMax];
    struct coords *next;
 };
 
@@ -2640,7 +2397,6 @@ typedef struct mmh {
 static void AddCoord(MMH *mmh,SplinePoint *sps[MmMax],int instance_count,
 		     int ish) {
    struct coords *coords;
-
    int i;
 
    coords=chunkalloc(sizeof(struct coords));
@@ -2657,7 +2413,6 @@ static void AddCoord(MMH *mmh,SplinePoint *sps[MmMax],int instance_count,
 static MMH *AddHintSet(MMH *hints,StemInfo *h[MmMax],int instance_count,
 		       SplinePoint * sps[MmMax], int ish) {
    int i, cnt, bestc;
-
    MMH *test, *best;
 
    for (i=0; i < instance_count; ++i)
@@ -2770,9 +2525,7 @@ static MMH *SortMMH(MMH *head,int instance_count) {
 
 static int NumberMMH(MMH *mmh,int hstart,int instance_count) {
    int i;
-
    HintInstance *hi, *n;
-
    struct coords *coords;
 
    while (mmh != NULL) {
@@ -2807,9 +2560,7 @@ static int NumberMMH(MMH *mmh,int hstart,int instance_count) {
 static void SortMMH2(SplineChar *scs[MmMax],MMH *mmh,int instance_count,
 		     int ish) {
    int i;
-
    StemInfo *h, *n;
-
    MMH *m;
 
    for (i=0; i < instance_count; ++i) {
@@ -2840,7 +2591,6 @@ static void SortMMH2(SplineChar *scs[MmMax],MMH *mmh,int instance_count,
 
 static void MMHFreeList(MMH *mmh) {
    MMH *mn;
-
    struct coords *c, *n;
 
    for (; mmh != NULL; mmh=mn) {
@@ -2857,9 +2607,7 @@ static void SplResolveSplitHints(SplineChar *scs[MmMax],
 				 SplineSet * spl[MmMax], int instance_count,
 				 MMH ** hs, MMH ** vs) {
    SplinePoint *to[MmMax];
-
    StemInfo *h[MmMax], *v[MmMax];
-
    int i, anymore;
 
    while (1) {
@@ -2913,11 +2661,8 @@ static void ResolveSplitHints(SplineChar *scs[16],int layer,
    /*  but some of the intermediate forms might conflict. */
    /* We can't deal (nor can postscript) with the case where hints change order */
    SplinePointList *spl[MmMax];
-
    RefChar *ref[MmMax];
-
    int i, hcnt, hmax=0, anymore;
-
    MMH *hs=NULL, *vs=NULL;
 
    for (i=0; i < instance_count; ++i) {
@@ -2966,7 +2711,6 @@ static void ResolveSplitHints(SplineChar *scs[16],int layer,
 static int SplFigureHintMasks(SplineChar *scs[MmMax],SplineSet *spl[MmMax],
 			      int instance_count, HintMask mask, int inited) {
    SplinePoint *to[MmMax];
-
    int i, anymore;
 
    anymore=false;
@@ -3029,15 +2773,10 @@ static int SplFigureHintMasks(SplineChar *scs[MmMax],SplineSet *spl[MmMax],
 
 void SCFigureHintMasks(SplineChar * sc, int layer) {
    SplineChar *scs[MmMax];
-
    SplinePointList *spl[MmMax];
-
    RefChar *ref[MmMax];
-
    MMSet *mm=sc->parent->mm;
-
    int i, instance_count, conflicts, anymore, inited;
-
    HintMask mask;
 
    if (mm==NULL) {
@@ -3094,15 +2833,10 @@ void SCFigureHintMasks(SplineChar * sc, int layer) {
 
 static StemInfo *GDFindStems(struct glyphdata *gd,int major) {
    int i;
-
    StemInfo *head=NULL, *cur, *p, *t;
-
    StemBundle *bundle=major ? gd->vbundle : gd->hbundle;
-
    StemData *stem;
-
    int other=!major;
-
    double l, r;
 
    for (i=0; i < bundle->cnt; ++i) {
@@ -3139,9 +2873,7 @@ static StemInfo *GDFindStems(struct glyphdata *gd,int major) {
 
 static DStemInfo *GDFindDStems(struct glyphdata *gd) {
    int i;
-
    DStemInfo *head=NULL, *cur;
-
    struct stemdata *stem;
 
    for (i=0; i < gd->stemcnt; ++i) {
@@ -3209,7 +2941,6 @@ void _SplineCharAutoHint(SplineChar *sc,int layer,BlueData * bd,
 
 static void __SplineCharAutoHint(SplineChar *sc,int layer,BlueData *bd) {
    MMSet *mm=sc->parent->mm;
-
    int i;
 
    if (mm==NULL)
@@ -3245,7 +2976,6 @@ void SFSCAutoHint(SplineChar * sc, int layer, BlueData * bd) {
 
 int SFNeedsAutoHint(SplineFont *_sf, int layer) {
    int i, k;
-
    SplineFont *sf;
 
    k=0;
@@ -3264,11 +2994,8 @@ int SFNeedsAutoHint(SplineFont *_sf, int layer) {
 
 void SplineFontAutoHint(SplineFont *_sf, int layer) {
    int i, k;
-
    SplineFont *sf;
-
    BlueData *bd=NULL, _bd;
-
    SplineChar *sc;
 
    if (_sf->mm==NULL) {
@@ -3330,16 +3057,12 @@ void SplineFontAutoHintRefs(SplineFont *_sf, int layer) {
    } while (k < _sf->subfontcnt);
 }
 
-static void FigureStems(SplineFont *sf,real snaps[12],real cnts[12],
+static void FigureStems(SplineFont *sf,double snaps[12],double cnts[12],
 			int which) {
    int i, j, k, cnt, smax=0, smin=2000;
-
-   real stemwidths[2000];
-
+   double stemwidths[2000];
    StemInfo *stems, *test;
-
    int len;
-
    HintInstance *hi;
 
    memset(stemwidths, '\0', sizeof(stemwidths));
@@ -3423,12 +3146,11 @@ static void FigureStems(SplineFont *sf,real snaps[12],real cnts[12],
 	 }
       }
    } else {
-      real firstbiggest=0;
+      double firstbiggest=0;
 
       for (cnt=0; cnt < 12; ++cnt) {
 	 int biggesti=0;
-
-	 real biggest=0;
+	 double biggest=0;
 
 	 for (i=smin; i <= smax; ++i) {
 	    if (stemwidths[i] > biggest) {
@@ -3459,17 +3181,16 @@ static void FigureStems(SplineFont *sf,real snaps[12],real cnts[12],
    }
 }
 
-void FindHStems(SplineFont *sf, real snaps[12], real cnt[12]) {
+void FindHStems(SplineFont *sf, double snaps[12], double cnt[12]) {
    FigureStems(sf, snaps, cnt, 1);
 }
 
-void FindVStems(SplineFont *sf, real snaps[12], real cnt[12]) {
+void FindVStems(SplineFont *sf, double snaps[12], double cnt[12]) {
    FigureStems(sf, snaps, cnt, 0);
 }
 
 static int IsFlexSmooth(SplinePoint *sp) {
    BasePoint nvec, pvec;
-
    double proj_same, proj_normal;
 
    if (sp->nonextcp || sp->noprevcp)
@@ -3509,11 +3230,8 @@ static int _SplineCharIsFlexible(SplineChar *sc,int layer,int blueshift) {
       This is an heuristic requirement, not part of Adobe's spec.
     */
    SplineSet *spl;
-
    SplinePoint *sp, *np, *pp;
-
    int max=0, val;
-
    RefChar *r;
 
    if (sc==NULL)
@@ -3596,7 +3314,6 @@ static int _SplineCharIsFlexible(SplineChar *sc,int layer,int blueshift) {
 
 static void SCUnflex(SplineChar *sc,int layer) {
    SplineSet *spl;
-
    SplinePoint *sp;
 
    for (spl=sc->layers[layer].splines; spl != NULL; spl=spl->next) {
