@@ -1,4 +1,4 @@
-/* $Id: autotrace.c 4064 2015-06-25 14:15:40Z mskala $ */
+/* $Id: autotrace.c 4464 2015-11-30 09:57:27Z mskala $ */
 /* Copyright (C) 2000-2012  George Williams
  * Copyright (C) 2015  Matthew Skala
  *
@@ -44,8 +44,6 @@
 #include <errno.h>		/* for errors */
 #include <dirent.h>		/* for opendir,etc. */
 
-#include "ffglib.h"
-
 int preferpotrace=false;
 
 /* Interface to Martin Weber's autotrace program   */
@@ -60,21 +58,14 @@ int preferpotrace=false;
 static SplinePointList *localSplinesFromEntities(Entity *ent,Color bgcol,
 						 int ispotrace) {
    Entity *enext;
-
    SplinePointList *head =
       NULL, *last, *test, *next, *prev, *new, *nlast, *temp;
    int clockwise;
-
    SplineChar sc;
-
    StrokeInfo si;
-
    DBounds bb, sbb;
-
    int removed;
-
-   real fudge;
-
+   double fudge;
    Layer layers[2];
 
    /* We have a problem. The autotrace program includes contours for the */
@@ -203,7 +194,6 @@ static SplinePointList *localSplinesFromEntities(Entity *ent,Color bgcol,
 /* I think this is total paranoia. but it's annoying to have linker complaints... */
 static int mytempnam(char *buffer) {
    char *dir;
-
    int fd;
 
    /* char *old; */
@@ -216,17 +206,14 @@ static int mytempnam(char *buffer) {
    else
       strcpy(buffer, P_tmpdir);
    strcat(buffer, "/PfaEdXXXXXX");
-   fd=g_mkstemp(buffer);
+   fd=mkstemp(buffer);
    return (fd);
 }
 
 static char *mytempdir(void) {
    char buffer[1025];
-
    char *dir, *eon;
-
    static int cnt=0;
-
    int tries=0;
 
    if ((dir=getenv("TMPDIR")) != NULL)
@@ -265,7 +252,7 @@ void _SCAutoTrace(SplineChar * sc, int layer, char **args) {
    struct _GImage *ib;
    Color bgcol;
    int ispotrace;
-   real transform[6];
+   double transform[6];
    char tempname_in[1025];
    char tempname_out[1025];
    char *prog, *command, *cmd;
@@ -370,7 +357,7 @@ void _SCAutoTrace(SplineChar * sc, int layer, char **args) {
    SplineSet *new, *last;
    struct _GImage *ib;
    Color bgcol;
-   real transform[6];
+   double transform[6];
    int changed=false;
    char tempname[1025];
    char *arglist[30];
@@ -460,7 +447,7 @@ void _SCAutoTrace(SplineChar * sc, int layer, char **args) {
 
 	    rewind(ps);
 	    new_tmp_file=atmpfile();
-	    
+
 	    while ((c=agetc(new_tmp_file))>=0) aputc(c,new_tmp_file);
 	    afseek(new_tmp_file,0,SEEK_SET);
 
@@ -503,9 +490,7 @@ void _SCAutoTrace(SplineChar * sc, int layer, char **args) {
 
 static char **makevector(const char *str) {
    char **vector;
-
    const char *start, *pt;
-
    int i, cnt;
 
    if (str==NULL)
@@ -535,7 +520,6 @@ static char **makevector(const char *str) {
 
 static char *flatten(char *const *args) {
    char *ret, *rpt;
-
    int j, i, len;
 
    if (args==NULL)
@@ -646,11 +630,8 @@ char *ProgramExists(char *prog, char *buffer) {
 
 char *FindAutoTraceName(void) {
    static int searched=0;
-
    static int waspotraceprefered;
-
    static char *name=NULL;
-
    char buffer[1025];
 
    if (searched && waspotraceprefered==preferpotrace)
@@ -680,9 +661,7 @@ char *FindAutoTraceName(void) {
 
 char *FindMFName(void) {
    static int searched=0;
-
    static char *name=NULL;
-
    char buffer[1025];
 
    if (searched)
@@ -698,9 +677,7 @@ char *FindMFName(void) {
 
 static char *FindGfFile(char *tempdir) {
    DIR *temp;
-
    struct dirent *ent;
-
    char buffer[1025], *ret=NULL;
 
    temp=opendir(tempdir);
@@ -724,13 +701,9 @@ static char *FindGfFile(char *tempdir) {
 
 static void cleantempdir(char *tempdir) {
    DIR *temp;
-
    struct dirent *ent;
-
    char buffer[1025], *eod;
-
    char *todelete[100];
-
    int cnt=0;
 
    temp=opendir(tempdir);
