@@ -1,4 +1,4 @@
-/* $Id: autowidth.c 4064 2015-06-25 14:15:40Z mskala $ */
+/* $Id: autowidth.c 4464 2015-11-30 09:57:27Z mskala $ */
 /* Copyright (C) 2000-2012  George Williams
  * Copyright (C) 2015  Matthew Skala
  *
@@ -75,18 +75,15 @@ Autokern has similar ideas, but is simpler:
 	Again check for overlap (<dspace>/4 in any zone)
     Kerning by the left character can always propigate to dependents
     Kerning by the right char should not
-	(ie. A and À kern the same with V
-	 but V kerns differently with e and é-- the accent gets in the way)
-    No, I think it is better not to propigate kerning.
+	(i.e. A and \`A kern the same with V
+	 but V kerns differently with e and \'{e}-- the accent gets in the way)
+    No, I think it is better not to propagate kerning.
 */
 
 static void AW_AutoKern(WidthInfo *wi) {
    struct charpair *cp;
-
    SplineChar *lsc, *rsc;
-
    int i, diff;
-
    KernPair *kp;
 
    for (i=0; i < wi->pcnt; ++i) {
@@ -121,9 +118,8 @@ static void AW_AutoKern(WidthInfo *wi) {
    }
 }
 
-static real SplineFindMinXAtY(Spline *spline,real y,real min) {
-   extended t, t1, t2, tbase, val;
-
+static double SplineFindMinXAtY(Spline *spline,double y,double min) {
+   double t, t1, t2, tbase, val;
    Spline1D *xsp;
 
    if (y > spline->from->me.y && y > spline->from->nextcp.y &&
@@ -168,7 +164,7 @@ static real SplineFindMinXAtY(Spline *spline,real y,real min) {
    return (min);
 }
 
-static void PtFindEdges(real x,real y,struct charone *ch,WidthInfo *wi) {
+static void PtFindEdges(double x,double y,struct charone *ch,WidthInfo *wi) {
    int i;
 
    i=rint(y / wi->decimation);
@@ -187,9 +183,7 @@ static void PtFindEdges(real x,real y,struct charone *ch,WidthInfo *wi) {
 static void SplineFindEdges(Spline *spline,struct charone *ch,
 			    WidthInfo * wi) {
    Spline1D *xsp, *ysp;
-
-   extended t1, t2;
-
+   double t1, t2;
    double t, toff, ymin, ymax;
 
    /* first try the end points */
@@ -233,7 +227,7 @@ static void SplineFindEdges(Spline *spline,struct charone *ch,
    }
 }
 
-static real SSFindMinXAtY(SplineSet *spl,real y,real min) {
+static double SSFindMinXAtY(SplineSet *spl,double y,double min) {
    Spline *sp, *first;
 
    while (spl != NULL) {
@@ -249,11 +243,10 @@ static real SSFindMinXAtY(SplineSet *spl,real y,real min) {
    return (min);
 }
 
-static real SSIsMinXAtYCurved(SplineSet *spl,real y,real oldmin,
+static double SSIsMinXAtYCurved(SplineSet *spl,double y,double oldmin,
 			      int *curved) {
    Spline *sp, *first;
-
-   real min;
+   double min;
 
    while (spl != NULL) {
       first=NULL;
@@ -287,9 +280,8 @@ static void SSFindEdges(SplineSet *spl,struct charone *ch,WidthInfo *wi) {
    }
 }
 
-static real SCFindMinXAtY(SplineChar *sc,int layer,real y) {
-   real min=NOTREACHED;
-
+static double SCFindMinXAtY(SplineChar *sc,int layer,double y) {
+   double min=NOTREACHED;
    RefChar *ref;
 
    min=SSFindMinXAtY(sc->layers[layer].splines, y, NOTREACHED);
@@ -298,11 +290,9 @@ static real SCFindMinXAtY(SplineChar *sc,int layer,real y) {
    return (min);
 }
 
-static int SCIsMinXAtYCurved(SplineChar *sc,int layer,real y) {
-   real min=NOTREACHED;
-
+static int SCIsMinXAtYCurved(SplineChar *sc,int layer,double y) {
+   double min=NOTREACHED;
    int curved=false;
-
    RefChar *ref;
 
    min=SSFindMinXAtY(sc->layers[layer].splines, y, NOTREACHED);
@@ -313,11 +303,8 @@ static int SCIsMinXAtYCurved(SplineChar *sc,int layer,real y) {
 
 static void SCFindEdges(struct charone *ch,WidthInfo *wi) {
    RefChar *ref;
-
    SplineChar *sc;
-
    int i;
-
    DBounds bb;
 
    SplineCharQuickConservativeBounds(ch->sc, &bb);
@@ -373,11 +360,8 @@ static void SCFindEdges(struct charone *ch,WidthInfo *wi) {
 /*  that extends around every point on the edge */
 static void PairFindDistance(struct charpair *cp,WidthInfo *wi) {
    int i, j, wasserif, wasseriff;
-
-   real sum, cnt, min, fudge, minf, temp;
-
+   double sum, cnt, min, fudge, minf, temp;
    struct charone *left=cp->left, *right=cp->right;
-
    int fudgerange;
 
    fudgerange=rint(wi->caph / (20 * wi->decimation));
@@ -450,13 +434,9 @@ static void PairFindDistance(struct charpair *cp,WidthInfo *wi) {
 
 static void AW_FindFontParameters(WidthInfo *wi) {
    DBounds bb;
-
    SplineFont *sf=wi->sf;
-
    int i, j, si=-1;
-
-   real caph, ds, xh, serifsize, angle, ca, seriflength=0;
-
+   double caph, ds, xh, serifsize, angle, ca, seriflength=0;
    int cnt;
    static unichar_t caps[] =
       { 'A', 'Z', 0x391, 0x3a9, 0x40f, 0x418, 0x41a, 0x42f, 0 };
@@ -475,7 +455,7 @@ static void AW_FindFontParameters(WidthInfo *wi) {
       0x3a0, 0x3a1, 0x40a, 0x412, 0x413, 0x415, 0x41a, 0x41d, 0x41f,
       0x420, 0x428, 0
    };
-   real stemx, testx, y, ytop, ybottom, yorig, topx, bottomx;
+   double stemx, testx, y, ytop, ybottom, yorig, topx, bottomx;
 
    caph=0;
    cnt=0;
@@ -655,15 +635,11 @@ static void AW_FindFontParameters(WidthInfo *wi) {
       wi->space_guess=rint(.184 * (sf->ascent + sf->descent));
 }
 
-real SFGuessItalicAngle(SplineFont *sf) {
+double SFGuessItalicAngle(SplineFont *sf) {
    static char *easyserif="IBDEFHKLNPR";
-
    int i, si;
-
-   real as, topx, bottomx;
-
+   double as, topx, bottomx;
    DBounds bb;
-
    double angle;
 
    for (i=0; easyserif[i] != '\0'; ++i)
@@ -689,7 +665,6 @@ real SFGuessItalicAngle(SplineFont *sf) {
 
 static void AW_InitCharPairs(WidthInfo *wi) {
    int i, j;
-
    struct charpair *cp;
 
    wi->pcnt=wi->lcnt * wi->rcnt;
@@ -749,9 +724,7 @@ int KernThreshold(SplineFont *sf, int cnt) {
    /* We want only cnt kerning pairs in the entire font. Any pair whose */
    /*  absolute offset is less than the threshold should be removed */
    int *totals, tot;
-
    int high, i, val;
-
    KernPair *kp;
 
    if (cnt==0)		/* Infinite */
@@ -787,7 +760,6 @@ int KernThreshold(SplineFont *sf, int cnt) {
 
 static void AW_KernRemoveBelowThreshold(SplineFont *sf,int threshold) {
    int i;
-
    KernPair *kp, *prev, *next;
 
    if (threshold==0)
@@ -828,7 +800,6 @@ struct kernsets {
 static unichar_t *ugetstr(AFILE *file,int format,unichar_t *buffer,
 			  int len) {
    int ch, ch2;
-
    unichar_t *upt=buffer;
 
    if (format==0) {
@@ -959,13 +930,9 @@ static void AW_ScriptSerifChecker(WidthInfo *wi) {
 
 static int figurekernsets(WidthInfo *wi,struct kernsets *ks) {
    int i, j, k, cnt, lcnt, max;
-
    unichar_t *ch2s;
-
    unichar_t *cpt, *upt;
-
    struct charpair *cp;
-
    SplineFont *sf=wi->sf;
 
    if (ks->cur==0)
@@ -1106,15 +1073,13 @@ static int AW_ReadKernPairFile(char *fn,WidthInfo *wi) {
 
 void FVRemoveKerns(FontViewBase * fv) {
    int changed=false;
-
    SplineFont *sf=fv->sf;
-
    OTLookup *otl, *notl;
 
    if (sf->cidmaster != NULL)
       sf=sf->cidmaster;
 
-   for (otl=sf->gpos_lookups; otl != NULL; otl=notl) {
+   for (otl=sf->gsplookups[1]; otl != NULL; otl=notl) {
       notl=otl->next;
       if (otl->lookup_type==gpos_pair &&
 	  FeatureTagInFeatureScriptList(CHR('k', 'e', 'r', 'n'),
@@ -1130,15 +1095,13 @@ void FVRemoveKerns(FontViewBase * fv) {
 
 void FVRemoveVKerns(FontViewBase * fv) {
    int changed=false;
-
    SplineFont *sf=fv->sf;
-
    OTLookup *otl, *notl;
 
    if (sf->cidmaster != NULL)
       sf=sf->cidmaster;
 
-   for (otl=sf->gpos_lookups; otl != NULL; otl=notl) {
+   for (otl=sf->gsplookups[1]; otl != NULL; otl=notl) {
       notl=otl->next;
       if (otl->lookup_type==gpos_pair &&
 	  FeatureTagInFeatureScriptList(CHR('v', 'k', 'r', 'n'),
@@ -1173,9 +1136,7 @@ static SplineChar *SCHasVertVariant(SplineChar *sc) {
 
 static SplineChar **CharNamesToVertSC(SplineFont *sf,char *names) {
    char *pt, *end, ch;
-
    int cnt;
-
    SplineChar **list;
 
    if (names==NULL || *names=='\0')
@@ -1210,7 +1171,6 @@ static SplineChar **CharNamesToVertSC(SplineFont *sf,char *names) {
 
 static char *SCListToName(SplineChar ** sclist) {
    int i, len;
-
    char *names, *pt;
 
    for (i=len=0; sclist[i] != NULL; ++i)
@@ -1245,11 +1205,8 @@ struct lookupmap {
 static struct lookup_subtable *VSubtableFromH(struct lookupmap *lookupmap,
 					      struct lookup_subtable *sub) {
    int i, lc, sc;
-
    OTLookup *otl;
-
    struct lookup_subtable *nsub, *prev, *test, *ls;
-
    FeatureScriptLangList *fl;
 
    for (i=0; i < lookupmap->sc; ++i)
@@ -1257,7 +1214,7 @@ static struct lookup_subtable *VSubtableFromH(struct lookupmap *lookupmap,
 	 return (lookupmap->smap[i].to);
 
    if (lookupmap->lmap==NULL) {
-      for (otl=lookupmap->sf->gpos_lookups, lc=sc=0; otl != NULL;
+      for (otl=lookupmap->sf->gsplookups[1], lc=sc=0; otl != NULL;
 	   otl=otl->next) {
 	 if (otl->lookup_type==gpos_pair) {
 	    ++lc;
@@ -1320,21 +1277,13 @@ static struct lookup_subtable *VSubtableFromH(struct lookupmap *lookupmap,
 
 void FVVKernFromHKern(FontViewBase * fv) {
    int i, j;
-
    KernPair *kp, *vkp;
-
    SplineChar *sc1, *sc2;
-
    KernClass *kc, *vkc;
-
    SplineChar ***firsts, ***seconds;
-
    int any1, any2;
-
    SplineFont *sf=fv->sf;
-
    int *map1, *map2;
-
    struct lookupmap lookupmap;
 
    FVRemoveVKerns(fv);
@@ -1430,59 +1379,56 @@ void FVVKernFromHKern(FontViewBase * fv) {
 /* Scripting hooks */
 
 static struct charone **autowidthBuildCharList(FontViewBase *fv,
-					       SplineFont *sf, int *tot,
-					       int *rtot, int *ipos,
+					       SplineFont *sf,int *tot,
+					       int *rtot,int *ipos,
 					       int iswidth) {
-   int i, cnt, doit, s;
+   int i,cnt,doit,s;
    struct charone **ret=NULL;
    EncMap *map=fv->map;
    int gid;
 
-   for (doit=0; doit < 2; ++doit) {
-      for (i=cnt=0; i < map->enccount && cnt < 300; ++i) {
-	 if (fv->selected[i] && (gid=map->map[i]) != -1
-	     && SCWorthOutputting(sf->glyphs[gid])) {
-	    if (doit)
-	       ret[cnt++]=AW_MakeCharOne(sf->glyphs[gid]);
-	    else
-	       ++cnt;
-	 }
-      }
+   for (i=0,cnt=0;(i<map->enccount) && (cnt<300);i++)
+     if (fv->selected[i] && ((gid=map->map[i])!=-1)
+	 && SCWorthOutputting(sf->glyphs[gid]))
+       cnt++;
 
-      if (!doit)
-	 ret=malloc((cnt + 2) * sizeof(struct charone *));
-      else {
-	 *rtot=cnt;
-	 if (iswidth &&		/* I always want 'I' in the character list when doing widths */
-	     /*  or at least when doing widths of LGC alphabets where */
-	     /*  concepts like serifs make sense */
-	     ((ret[0]->sc->unicodeenc >= 'A'
-	       && ret[0]->sc->unicodeenc < 0x530)
-	      || (ret[0]->sc->unicodeenc >= 0x1d00
-		  && ret[0]->sc->unicodeenc < 0x2000))) {
-	    for (s=0; s < cnt; ++s)
-	       if (ret[s]->sc->unicodeenc=='I')
-		  break;
-	    if (s==cnt) {
-	       i=SFFindExistingSlot(sf, 'I', NULL);
-	       if (i != -1)
-		  ret[cnt++]=AW_MakeCharOne(sf->glyphs[i]);
-	       else
-		  s=-1;
-	    }
-	    *ipos=s;
-	 }
-	 ret[cnt]=NULL;
+   ret=malloc((cnt+2)*sizeof(struct charone *));
+
+   for (i=0,cnt=0;(i<map->enccount) && (cnt<300);i++)
+     if (fv->selected[i] && ((gid=map->map[i])!=-1)
+	 && SCWorthOutputting(sf->glyphs[gid]))
+       ret[cnt++]=AW_MakeCharOne(sf->glyphs[gid]);
+
+   *rtot=cnt;
+   if (iswidth &&
+       /* I always want 'I' in the character list when doing widths */
+       /*  or at least when doing widths of LGC alphabets where */
+       /*  concepts like serifs make sense */
+       ((ret[0]->sc->unicodeenc>='A'
+	 && ret[0]->sc->unicodeenc<0x530)
+	|| (ret[0]->sc->unicodeenc>=0x1d00
+	    && ret[0]->sc->unicodeenc<0x2000))) {
+      for (s=0;s<cnt;s++)
+	if (ret[s]->sc->unicodeenc=='I')
+	  break;
+      if (s==cnt) {
+	 i=SFFindExistingSlot(sf,'I',NULL);
+	 if (i!=-1)
+	   ret[cnt++]=AW_MakeCharOne(sf->glyphs[i]);
+	 else
+	   s=-1;
       }
+      *ipos=s;
    }
+   ret[cnt]=NULL;
+
    *tot=cnt;
-   return (ret);
+   return ret;
 }
 
 int AutoKernScript(FontViewBase * fv, int spacing, int threshold,
 		   struct lookup_subtable *sub, char *kernfile) {
    WidthInfo wi;
-
    SplineFont *sf=fv->sf;
 
    memset(&wi, '\0', sizeof(wi));
