@@ -1,4 +1,4 @@
-/* $Id: autowidth2.c 4020 2015-06-14 18:15:09Z mskala $ */
+/* $Id: autowidth2.c 4464 2015-11-30 09:57:27Z mskala $ */
 /* Copyright (C) 2009-2012  George Williams
  * Copyright (C) 2015  Matthew Skala
  *
@@ -38,12 +38,9 @@
 
 static int aw2_bbox_separation(AW_Glyph *g1,AW_Glyph *g2,AW_Data *all) {
    int j;
-
    int imin_y, imax_y;
-
-   real tot, cnt;
-
-   real denom;
+   double tot, cnt;
+   double denom;
 
    /* the goal is to give a weighted average that expresses the visual */
    /*  separation between two glyphs when they are placed so their bounding */
@@ -63,9 +60,8 @@ static int aw2_bbox_separation(AW_Glyph *g1,AW_Glyph *g2,AW_Data *all) {
       if (g2->left[j - g2->imin_y] < 32767
 	  && g1->right[j - g1->imin_y] > -32767) {
 	 /* beware of gaps such as those in "i" or "aaccute" */
-	 real sep=g2->left[j - g2->imin_y] - g1->right[j - g1->imin_y];
-
-	 real weight=1.0 / (sep + denom);
+	 double sep=g2->left[j - g2->imin_y] - g1->right[j - g1->imin_y];
+	 double weight=1.0 / (sep + denom);
 
 	 weight *= weight;
 
@@ -80,11 +76,8 @@ static int aw2_bbox_separation(AW_Glyph *g1,AW_Glyph *g2,AW_Data *all) {
 
 static void aw2_figure_lsb(int right_index,AW_Data *all) {
    int i;
-
    AW_Glyph *me, *other;
-
    int lsb, tot;
-
    int *vpt=all->visual_separation + right_index;
 
    lsb=0;
@@ -106,11 +99,8 @@ static void aw2_figure_lsb(int right_index,AW_Data *all) {
 
 static void aw2_figure_rsb(int left_index,AW_Data *all) {
    int i;
-
    AW_Glyph *me, *other;
-
    int rsb, tot;
-
    int *vpt=all->visual_separation + left_index * all->gcnt;
 
    rsb=0;
@@ -132,17 +122,11 @@ static void aw2_figure_rsb(int left_index,AW_Data *all) {
 
 static void aw2_figure_all_sidebearing(AW_Data *all) {
    int i, j;
-
    AW_Glyph *me, *other;
-
-   real transform[6], half;
-
+   double transform[6], half;
    int width, changed;
-
    uint8_t *rsel=calloc(all->fv->map->enccount, sizeof(char));
-
-   real denom=(all->sf->ascent + all->sf->descent) / DENOM_FACTOR_OF_EMSIZE;
-
+   double denom=(all->sf->ascent + all->sf->descent) / DENOM_FACTOR_OF_EMSIZE;
    int ldiff, rdiff;
 
    all->denom=denom;
@@ -236,17 +220,11 @@ static double MonotonicFindY(Monotonic *m,double test,double old_t) {
 
 static void aw2_findedges(AW_Glyph *me,AW_Data *all) {
    Monotonic *ms, *m;
-
-   real ytop, ybottom;
-
-   real x, xmin, xmax;
-
+   double ytop, ybottom;
+   double x, xmin, xmax;
    int i;
-
    double t;
-
    Spline1D *msp;
-
    SplineSet *base;
 
    me->imin_y=floor(me->bb.miny / all->sub_height);
@@ -313,7 +291,6 @@ static void aw2_findedges(AW_Glyph *me,AW_Data *all) {
 
 static void aw2_dummyedges(AW_Glyph *flat,AW_Data *all) {
    int i;
-
    int imin_y=32000, imax_y=-32000;
 
    if (all != NULL) {
@@ -343,7 +320,6 @@ static void AWGlyphFree(AW_Glyph *me) {
 
 static void aw2_handlescript(AW_Data *all) {
    int i;
-
    AW_Glyph *me;
 
    for (i=0; (me=&all->glyphs[i])->sc != NULL; ++i)
@@ -362,15 +338,10 @@ void AutoWidth2(FontViewBase * fv, int separation, int min_side, int max_side,
       AW_Glyph *glyphs;
       int gcnt;
    } *scripts;
-
    int scnt, smax;
-
    int enc, gid, s, i;
-
    SplineFont *sf=fv->sf;
-
    SplineChar *sc;
-
    AW_Data all;
 
    if (chunk_height <= 0)
