@@ -1,4 +1,4 @@
-/* $Id: cvexport.c 4020 2015-06-14 18:15:09Z mskala $ */
+/* $Id: cvexport.c 4464 2015-11-30 09:57:27Z mskala $ */
 /* Copyright (C) 2000-2012  George Williams
  * Copyright (C) 2015  Matthew Skala
  *
@@ -33,7 +33,6 @@
 #include "gfile.h"
 #include <time.h>
 #include "ustring.h"
-#include "gio.h"
 #include "print.h"		/* For pdf output routines */
 #include <utype.h>
 
@@ -77,17 +76,11 @@ static void EpsGeneratePreview(AFILE *eps,SplineChar *sc,int layer,
 
 int _ExportEPS(AFILE *eps, SplineChar * sc, int layer, int preview) {
    DBounds b;
-
    time_t now;
-
    struct tm *tm;
-
    int ret;
-
    char oldloc[24];
 
-   const char *author=GetAuthor();
-
    strcpy(oldloc, setlocale(LC_NUMERIC, NULL));
    setlocale(LC_NUMERIC, "C");
 
@@ -98,8 +91,6 @@ int _ExportEPS(AFILE *eps, SplineChar * sc, int layer, int preview) {
    afprintf(eps, "%%%%Pages: 0\n");
    afprintf(eps, "%%%%Title: %s from %s\n", sc->name, sc->parent->fontname);
    afprintf(eps, "%%%%Creator: FontAnvil\n");
-   if (author != NULL)
-      afprintf(eps, "%%%%Author: %s\n", author);
    time(&now);
    tm=localtime(&now);
    afprintf(eps, "%%%%CreationDate: %d:%02d %d-%d-%d\n", tm->tm_hour,
@@ -145,7 +136,6 @@ int _ExportEPS(AFILE *eps, SplineChar * sc, int layer, int preview) {
 
 static int ExportEPS(char *filename,SplineChar *sc,int layer) {
    AFILE *eps;
-
    int ret;
 
    eps=afopen(filename, "w");
@@ -160,21 +150,12 @@ static int ExportEPS(char *filename,SplineChar *sc,int layer) {
 int _ExportPDF(AFILE *pdf, SplineChar * sc, int layer) {
 /* TODO: Note, maybe this routine can be combined with print.c dump_pdfprologue() */
    DBounds b;
-
    time_t now;
-
    struct tm *tm;
-
    int ret;
-
    char oldloc[24];
-
    int _objlocs[8], xrefloc, streamstart, streamlength, resid, nextobj;
-
    int *objlocs=_objlocs;
-
-   const char *author=GetAuthor();
-
    int i;
 
    SFUntickAll(sc->parent);
@@ -254,14 +235,11 @@ int _ExportPDF(AFILE *pdf, SplineChar * sc, int layer) {
    }
 #endif
    afprintf(pdf, "    /Title (%s from %s)\n", sc->name, sc->parent->fontname);
-   if (author != NULL)
-      afprintf(pdf, "    /Author (%s)\n", author);
    afprintf(pdf, " >>\n");
 
    nextobj=7;
    if (sc->parent->multilayer) {
       PI pi;
-
       int resobj;
 
       memset(&pi, 0, sizeof(pi));
@@ -304,7 +282,6 @@ int _ExportPDF(AFILE *pdf, SplineChar * sc, int layer) {
 
 static int ExportPDF(char *filename,SplineChar *sc,int layer) {
    AFILE *eps;
-
    int ret;
 
    eps=afopen(filename, "w");
@@ -319,13 +296,9 @@ static int ExportPDF(char *filename,SplineChar *sc,int layer) {
 
 int _ExportPlate(AFILE *plate, SplineChar * sc, int layer) {
    char oldloc[24];
-
    int do_open;
-
    SplineSet *ss;
-
    spiro_cp *spiros;
-
    int i, ret;
 
    strcpy(oldloc, setlocale(LC_NUMERIC, NULL));
@@ -367,7 +340,6 @@ int _ExportPlate(AFILE *plate, SplineChar * sc, int layer) {
 
 static int ExportPlate(char *filename,SplineChar *sc,int layer) {
    AFILE *plate;
-
    int ret;
 
    plate=afopen(filename, "w");
@@ -381,7 +353,6 @@ static int ExportPlate(char *filename,SplineChar *sc,int layer) {
 
 static int ExportSVG(char *filename,SplineChar *sc,int layer) {
    AFILE *svg;
-
    int ret;
 
    svg=afopen(filename, "w");
@@ -395,7 +366,6 @@ static int ExportSVG(char *filename,SplineChar *sc,int layer) {
 
 static int ExportGlif(char *filename,SplineChar *sc,int layer) {
    AFILE *glif;
-
    int ret;
 
    glif=afopen(filename, "w");
@@ -406,19 +376,16 @@ static int ExportGlif(char *filename,SplineChar *sc,int layer) {
    return (ret);
 }
 
-static void FigDumpPt(AFILE *fig,BasePoint *me,real scale,real ascent) {
+static void FigDumpPt(AFILE *fig,BasePoint *me,double scale,double ascent) {
    afprintf(fig, "%d %d ", (int) rint(me->x * scale),
 	   (int) rint(ascent - me->y * scale));
 }
 
 static void FigSplineSet(AFILE *fig,SplineSet *spl,int spmax,int asc) {
    SplinePoint *sp;
-
    int cnt;
-
-   real scale=7 * 1200.0 / spmax;
-
-   real ascent=11 * 1200 * asc / spmax;
+   double scale=7 * 1200.0 / spmax;
+   double ascent=11 * 1200 * asc / spmax;
 
    while (spl != NULL) {
       /* type=3, SPline; sub_type=3, closed interpreted; linestyle=0(solid); thickness=1 */
@@ -596,11 +563,8 @@ int BCExportXBM(char *filename, BDFChar * bdfc, int format) {
 static void MakeExportName(char *buffer,int blen,char *format_spec,
 			   SplineChar * sc, EncMap * map) {
    char *end=buffer + blen - 3;
-
    char *pt, *bend;
-
    char unicode[8];
-
    int ch;
 
    while (*format_spec && buffer < end) {
