@@ -1,4 +1,4 @@
-/* $Id: cvundoes.c 4064 2015-06-25 14:15:40Z mskala $ */
+/* $Id: cvundoes.c 4464 2015-11-30 09:57:27Z mskala $ */
 /* Copyright (C) 2000-2012  George Williams
  * Copyright (C) 2015  Matthew Skala
  *
@@ -84,9 +84,7 @@ RefChar *RefCharsCopyState(SplineChar * sc, int layer) {
 static SplinePointList *RefCharsCopyUnlinked(SplinePointList *sofar,
 					     SplineChar * sc, int layer) {
    RefChar *crefs;
-
    SplinePointList *last=NULL, *new;
-
    int l;
 
    if (layer < 0 || sc->layers[layer].refs==NULL)
@@ -213,7 +211,7 @@ static void FixupRefChars(SplineChar *sc,RefChar *urefs,int layer) {
 	 else
 	    cprev->next=urefs;
 	 cprev=urefs;
-	 SCReinstanciateRefChar(sc, urefs, layer);
+	 SCReinstantiateRefChar(sc, urefs, layer);
 	 SCMakeDependent(sc, urefs->sc);
 	 urefs=unext;
       }
@@ -230,7 +228,7 @@ static void FixupRefChars(SplineChar *sc,RefChar *urefs,int layer) {
       else
 	 cprev->next=urefs;
       while (urefs != NULL) {
-	 SCReinstanciateRefChar(sc, urefs, layer);
+	 SCReinstantiateRefChar(sc, urefs, layer);
 	 SCMakeDependent(sc, urefs->sc);
 	 urefs=urefs->next;
       }
@@ -314,9 +312,7 @@ static void UHintListFree(void *hints) {
 
 static void *UHintCopy(SplineChar *sc,int docopy) {
    StemInfo *h=sc->hstem, *v=sc->vstem, *last=NULL;
-
    DStemInfo *d=sc->dstem;
-
    void *ret=NULL;
 
    if (docopy) {
@@ -356,9 +352,7 @@ static void *UHintCopy(SplineChar *sc,int docopy) {
 
 static void ExtractHints(SplineChar *sc,void *hints,int docopy) {
    StemInfo *h=NULL, *v=NULL, *p;
-
    DStemInfo *d=NULL;
-
    StemInfo *pv=NULL, *pd=NULL;
 
    p=NULL;
@@ -403,7 +397,6 @@ static void ExtractHints(SplineChar *sc,void *hints,int docopy) {
 
 void UndoesFree(Undoes * undo) {
    Undoes *unext;
-
    BDFRefChar *head, *next;
 
    while (undo != NULL) {
@@ -485,7 +478,6 @@ Undoes *SCPreserveState(SplineChar * sc, int dohints) {
    if (sc->parent->multilayer)
       for (i=ly_fore + 1; i < sc->layer_cnt; ++i)
 	 SCPreserveLayer(sc, i, false);
-
    Undoes *ret=SCPreserveLayer(sc, ly_fore, dohints);
 
 /*     collabclient_SCPreserveStateCalled( sc ); */
@@ -533,9 +525,7 @@ static void SCUndoAct(SplineChar *sc,int layer,Undoes *undo) {
 	} break;
      case ut_hints:{
 	   void *hints=UHintCopy(sc, false);
-
 	   uint8_t *instrs=sc->ttf_instrs;
-
 	   int instrs_len=sc->ttf_instrs_len;
 
 	   ExtractHints(sc, undo->u.state.hints, false);
@@ -555,7 +545,6 @@ static void SCUndoAct(SplineChar *sc,int layer,Undoes *undo) {
 
 	   if (layer==ly_fore) {
 	      int width=sc->width;
-
 	      int vwidth=sc->vwidth;
 
 	      if (sc->width != undo->u.state.width)
@@ -582,9 +571,7 @@ static void SCUndoAct(SplineChar *sc,int layer,Undoes *undo) {
 	       (undo->undotype==ut_statehint
 		|| undo->undotype==ut_statename)) {
 	      void *hints=UHintCopy(sc, false);
-
 	      uint8_t *instrs=sc->ttf_instrs;
-
 	      int instrs_len=sc->ttf_instrs_len;
 
 	      ExtractHints(sc, undo->u.state.hints, false);
@@ -607,11 +594,8 @@ static void SCUndoAct(SplineChar *sc,int layer,Undoes *undo) {
 	   }
 	   if (layer==ly_fore && undo->undotype==ut_statename) {
 	      char *temp=sc->name;
-
 	      int uni=sc->unicodeenc;
-
 	      PST *possub=sc->possub;
-
 	      char *comment=sc->comment;
 
 	      sc->name=undo->u.state.charname;
@@ -763,7 +747,6 @@ void CopyBufferClearCopiedFrom(SplineFont *dying) {
 
 int getAdobeEnc(char *name) {
    extern char *AdobeStandardEncoding[256];
-
    int i;
 
    for (i=0; i < 256; ++i)
@@ -777,9 +760,7 @@ int getAdobeEnc(char *name) {
 static Undoes *SCCopyAllLayer(SplineChar *sc,enum fvcopy_type full,
 			      int layer) {
    Undoes *cur;
-
    RefChar *ref;
-
    extern int copymetadata, copyttfinstr;
 
    /* If full==ct_fullcopy copy the glyph as is. */
@@ -945,10 +926,7 @@ static void PasteNonExistantRefCheck(SplineChar *sc,Undoes *paster,
       ErrorMsg(2,"We should never have called PasteNonExistantRefCheck if we had a glyph\n");
    if (fromsc==NULL) {
       if (!(*refstate & 0x4)) {
-	 char *buts[3];
-
 	 char buf[80];
-
 	 const char *name;
 
 	 if (ref->unicode_enc==-1)
@@ -956,19 +934,9 @@ static void PasteNonExistantRefCheck(SplineChar *sc,Undoes *paster,
 	 else
 	    name =
 	       StdGlyphName(buf, ref->unicode_enc, ui_none, (NameList *) - 1);
-	 buts[0]=_("Don't Warn Again");
-	 buts[1]=_("_OK");
-	 buts[2]=NULL;
       }
    } else {
       if (!(*refstate & 0x3)) {
-	 char *buts[5];
-
-	 buts[0]=_("_Yes");
-	 buts[1]=_("Yes to _All");
-	 buts[2]=_("No _to All");
-	 buts[3]=_("_No");
-	 buts[4]=NULL;
 	 yes=0;
       }
       if ((*refstate & 1) || yes <= 1) {
@@ -1000,7 +968,6 @@ static int anchor_lost_warning=false;
 
 static void APMerge(SplineChar *sc,AnchorPoint *anchor) {
    AnchorPoint *ap, *prev, *next, *test;
-
    AnchorClass *ac;
 
    if (anchor==NULL)
@@ -1075,17 +1042,11 @@ static void APMerge(SplineChar *sc,AnchorPoint *anchor) {
 static int InstrsSameParent(SplineChar *sc,SplineFont *copied_from) {
    static SplineFont *dontask_parent=NULL,*dontask_copied_from;
    static int dontask_ret=0;
-   char *buts[5];
 
    if (sc->parent==copied_from)
       return (true);
    if (sc->parent==dontask_parent && copied_from==dontask_copied_from)
       return (dontask_ret);
-   buts[0]=_("_Yes");
-   buts[3]=_("_No");
-   buts[1]=_("Yes to _All");
-   buts[2]=_("No _to All");
-   buts[4]=NULL;
    return (true);
 }
 
@@ -1110,11 +1071,11 @@ int SCWasEmpty(SplineChar * sc, int skip_this_layer) {
 
 /* when pasting from the fontview we do a clear first */
 static void _PasteToSC(SplineChar *sc,Undoes *paster,FontViewBase *fv,
-		       int pasteinto, int layer, real trans[6],
+		       int pasteinto, int layer, double trans[6],
 		       struct sfmergecontext *mc, int *refstate,
 		       int *already_complained) {
    DBounds bb;
-   real transform[6];
+   double transform[6];
    int width, vwidth;
    int xoff=0, yoff=0;
    int was_empty;
@@ -1182,7 +1143,7 @@ static void _PasteToSC(SplineChar *sc,Undoes *paster,FontViewBase *fv,
 					  transform, tpt_AllPoints);
 	      for (ref=sc->layers[layer].refs; ref != NULL; ref=ref->next) {
 		 ref->transform[4] += width;
-		 SCReinstanciateRefChar(sc, ref, layer);
+		 SCReinstantiateRefChar(sc, ref, layer);
 	      }
 	   } else {
 	      xoff=sc->width;
@@ -1326,7 +1287,7 @@ static void _PasteToSC(SplineChar *sc,Undoes *paster,FontViewBase *fv,
 		 new->sc=rsc;
 		 new->next=sc->layers[layer].refs;
 		 sc->layers[layer].refs=new;
-		 SCReinstanciateRefChar(sc, new, layer);
+		 SCReinstantiateRefChar(sc, new, layer);
 		 SCMakeDependent(sc, rsc);
 	      } else
 		PasteNonExistantRefCheck(sc, paster, refs, refstate);
@@ -1370,7 +1331,7 @@ static void _PasteToSC(SplineChar *sc,Undoes *paster,FontViewBase *fv,
 }
 
 static void PasteToSC(SplineChar *sc,int layer,Undoes *paster,
-		      FontViewBase * fv, int pasteinto, real trans[6],
+		      FontViewBase * fv, int pasteinto, double trans[6],
 		      struct sfmergecontext *mc, int *refstate,
 		      int *already_complained) {
    if (paster->undotype==ut_layers && sc->parent->multilayer) {
@@ -1522,7 +1483,7 @@ static void APInto(SplineChar *sc,AnchorPoint *ap,AnchorPoint *fromap,
 	 malloc(ap->yadjust.last_pixel_size - ap->yadjust.first_pixel_size +
 		1);
       memcpy(ap->yadjust.corrections, fromap->yadjust.corrections,
-	     ap->yadjust.last_pixel_size - ap->xadjust.first_pixel_size + 1);
+	     ap->yadjust.last_pixel_size - ap->yadjust.first_pixel_size + 1);
    }
 }
 
@@ -1690,82 +1651,87 @@ static int HasNonClass(OTLookup *otl) {
 
 static OTLookup **GetLookupsToCopy(SplineFont *sf,OTLookup *** backpairlist,
 				   int is_same) {
-   int cnt, bcnt, ftot=0, doit, isgpos, i, ret;
-
+   int cnt, bcnt, ftot=0, isgpos, i, ret;
    char **choices=NULL, *sel;
-
    OTLookup *otl, **list1=NULL, **list2=NULL, **list, **blist;
 
-   char *buttons[3];
-
-   buttons[0]=_("_OK");
-   buttons[1]=_("_Cancel");
-   buttons[2]=NULL;
-
    *backpairlist=NULL;
 
-   for (doit=0; doit < 2; ++doit) {
-      bcnt=cnt=0;
-      for (isgpos=0; isgpos < 2; ++isgpos) {
-	 for (otl=isgpos ? sf->gpos_lookups : sf->gsub_lookups; otl != NULL;
-	      otl=otl->next) {
-	    if (otl->lookup_type==gsub_single
-		|| otl->lookup_type==gsub_multiple
-		|| otl->lookup_type==gsub_alternate
-		|| otl->lookup_type==gsub_ligature
-		|| otl->lookup_type==gpos_single
-		|| otl->lookup_type==gpos_cursive
-		|| otl->lookup_type==gpos_mark2base
-		|| otl->lookup_type==gpos_mark2ligature
-		|| otl->lookup_type==gpos_mark2mark
-		|| (otl->lookup_type==gpos_pair && HasNonClass(otl))) {
-	       if (doit) {
-		  list1[cnt]=otl;
-		  choices[cnt++]=fastrdup(otl->lookup_name);
-		  if (otl->lookup_type==gpos_pair) {
-/* GT: I'm not happy with this phrase. Suggestions for improvements are welcome */
-/* GT:  Here I am generating a list of lookup names representing data that can */
-/* GT:  be copied from one glyph to another. For a kerning (pairwise) lookup */
-/* GT:  the first entry in the list (marked by the lookup name by itself) will */
-/* GT:  mean all data where the current glyph is the first glyph in a kerning */
-/* GT:  pair. But we can also (separatedly) copy data where the current glyph */
-/* GT:  is the second glyph in the kerning pair, and that's what this line */
-/* GT:  refers to. The "%s" will be filled in with the lookup name */
-		     char *format=_("Second glyph of %s");
-
-		     char *space =
-			malloc(strlen(format) + strlen(otl->lookup_name) + 1);
-		     sprintf(space, format, otl->lookup_name);
-		     list2[bcnt]=otl;
-		     choices[ftot + 1 + bcnt++]=space;
-		  }
-	       } else {
-		  ++cnt;
-		  if (otl->lookup_type==gpos_pair)
-		     ++bcnt;
-	       }
-	    }
-	 }
-      }
-      if (cnt==0) {		/* If cnt==0 then bcnt must be too */
-	 ErrorMsg(2,"No lookups to copy.\n");
-	 return (NULL);
-      }
-      if (!doit) {
-	 ftot=cnt;
-	 choices=malloc((cnt + bcnt + 2) * sizeof(char *));
-	 sel=calloc(cnt + bcnt + 1, 1);
-	 list1=malloc(cnt * sizeof(OTLookup *));
-	 if (bcnt==0) {
-	    choices[cnt]=NULL;
-	    list2=NULL;
-	 } else {
-	    choices[cnt]=fastrdup("-");
-	    choices[bcnt + cnt + 1]=NULL;
-	    list2=malloc(bcnt * sizeof(OTLookup *));
-	 }
-      }
+   bcnt=cnt=0;
+   for (isgpos=0;isgpos<2;isgpos++)
+     for (otl=sf->gsplookups[isgpos]; otl != NULL;
+	  otl=otl->next) {
+	if (otl->lookup_type==gsub_single
+	    || otl->lookup_type==gsub_multiple
+	    || otl->lookup_type==gsub_alternate
+	    || otl->lookup_type==gsub_ligature
+	    || otl->lookup_type==gpos_single
+	    || otl->lookup_type==gpos_cursive
+	    || otl->lookup_type==gpos_mark2base
+	    || otl->lookup_type==gpos_mark2ligature
+	    || otl->lookup_type==gpos_mark2mark
+	    || (otl->lookup_type==gpos_pair && HasNonClass(otl))) {
+	   ++cnt;
+	   if (otl->lookup_type==gpos_pair)
+	     ++bcnt;
+	}
+     }
+   if (cnt==0) {		/* If cnt==0 then bcnt must be too */
+      ErrorMsg(2,"No lookups to copy.\n");
+      return (NULL);
    }
+   ftot=cnt;
+   choices=malloc((cnt + bcnt + 2) * sizeof(char *));
+   sel=calloc(cnt + bcnt + 1, 1);
+   list1=malloc(cnt * sizeof(OTLookup *));
+   if (bcnt==0) {
+      choices[cnt]=NULL;
+      list2=NULL;
+   } else {
+      choices[cnt]=fastrdup("-");
+      choices[bcnt + cnt + 1]=NULL;
+      list2=malloc(bcnt * sizeof(OTLookup *));
+   }
+
+   bcnt=cnt=0;
+   for (isgpos=0;isgpos<2;isgpos++)
+     for (otl=sf->gsplookups[isgpos]; otl != NULL;
+	  otl=otl->next) {
+	if (otl->lookup_type==gsub_single
+	    || otl->lookup_type==gsub_multiple
+	    || otl->lookup_type==gsub_alternate
+	    || otl->lookup_type==gsub_ligature
+	    || otl->lookup_type==gpos_single
+	    || otl->lookup_type==gpos_cursive
+	    || otl->lookup_type==gpos_mark2base
+	    || otl->lookup_type==gpos_mark2ligature
+	    || otl->lookup_type==gpos_mark2mark
+	    || (otl->lookup_type==gpos_pair && HasNonClass(otl))) {
+	   list1[cnt]=otl;
+	   choices[cnt++]=fastrdup(otl->lookup_name);
+	   if (otl->lookup_type==gpos_pair) {
+	      /* GT: I'm not happy with this phrase. Suggestions for improvements are welcome */
+	      /* GT:  Here I am generating a list of lookup names representing data that can */
+	      /* GT:  be copied from one glyph to another. For a kerning (pairwise) lookup */
+	      /* GT:  the first entry in the list (marked by the lookup name by itself) will */
+	      /* GT:  mean all data where the current glyph is the first glyph in a kerning */
+	      /* GT:  pair. But we can also (separatedly) copy data where the current glyph */
+	      /* GT:  is the second glyph in the kerning pair, and that's what this line */
+	      /* GT:  refers to. The "%s" will be filled in with the lookup name */
+	      char *format="Second glyph of %s";
+	      char *space =
+		malloc(strlen(format) + strlen(otl->lookup_name) + 1);
+	      sprintf(space, format, otl->lookup_name);
+	      list2[bcnt]=otl;
+	      choices[ftot + 1 + bcnt++]=space;
+	   }
+	}
+     }
+   if (cnt==0) {		/* If cnt==0 then bcnt must be too */
+      ErrorMsg(2,"No lookups to copy.\n");
+      return (NULL);
+   }
+
    ret=-1;
    list=NULL;
    if (ret >= 0) {
@@ -1812,7 +1778,6 @@ static OTLookup **GetLookupsToCopy(SplineFont *sf,OTLookup *** backpairlist,
 static Undoes *BCCopyAll(BDFChar *bc,int pixelsize,int depth,
 			 enum fvcopy_type full) {
    Undoes *cur;
-
    BDFRefChar *ref, *head;
 
    cur=chunkalloc(sizeof(Undoes));
@@ -1933,9 +1898,7 @@ static void _PasteToBC(BDFChar *bc,int pixelsize,int depth,
 
 void FVCopyAnchors(FontViewBase * fv) {
    Undoes *head=NULL, *last=NULL, *cur;
-
    int i, any=false, gid;
-
    SplineChar *sc;
 
    CopyBufferFreeGrab();
@@ -2038,19 +2001,6 @@ static BDFFont *BitmapCreateCheck(FontViewBase *fv,int *yestoall,int first,
    int yes=0;
    BDFFont *bdf=NULL;
    if (*yestoall > 0 && first) {
-      char *buts[5];
-
-      char buf[20];
-
-      if (depth != 1)
-	 sprintf(buf, "%d@%d", pixelsize, depth);
-      else
-	 sprintf(buf, "%d", pixelsize);
-      buts[0]=_("_Yes");
-      buts[1]=_("Yes to _All");
-      buts[2]=_("No _to All");
-      buts[3]=_("_No");
-      buts[4]=NULL;
       yes=1;
    }
    if (yes==1 || *yestoall) {
@@ -2076,7 +2026,7 @@ static int copybufferHasLookups(Undoes *cb) {
    return (cb->undotype==ut_statelookup);
 }
 
-void PasteIntoFV(FontViewBase *fv,int pasteinto,real trans[6]) {
+void PasteIntoFV(FontViewBase *fv,int pasteinto,double trans[6]) {
    Undoes *cur=NULL, *bmp;
    BDFFont *bdf;
    int i, j, cnt=0, gid;
@@ -2119,7 +2069,6 @@ void PasteIntoFV(FontViewBase *fv,int pasteinto,real trans[6]) {
    if (cnt==1 && cur->undotype==ut_multiple
        && cur->u.multiple.mult->next != NULL) {
       Undoes *tot;
-
       int j;
 
       for (cnt=0, tot=cur->u.multiple.mult; tot != NULL;
@@ -2178,7 +2127,12 @@ void PasteIntoFV(FontViewBase *fv,int pasteinto,real trans[6]) {
 	      case ut_anchors:
 		 if (!sf->hasvmetrics && cur->undotype==ut_vwidth) {
 		    ErrorMsg(2,"No vertical metrics in font\n");
-		    goto err;
+		    if (oldsel != fv->selected)
+		      free(oldsel);
+		    SFFinishMergeContext(&mc);
+		    free(list);
+		    free(backpairlist);
+		    return;
 		 }
 		 PasteToSC(SFMakeChar(sf, fv->map, i), fv->active_layer, cur,
 			   fv, pasteinto, trans, &mc, &refstate,
@@ -2263,7 +2217,7 @@ void PasteIntoFV(FontViewBase *fv,int pasteinto,real trans[6]) {
 	    }
 	 }
       }
- err:
+
    if (oldsel != fv->selected)
       free(oldsel);
    SFFinishMergeContext(&mc);
