@@ -1,4 +1,4 @@
-/* $Id: dumppfa.c 4071 2015-06-29 09:11:43Z mskala $ */
+/* $Id: dumppfa.c 4478 2015-12-06 12:27:45Z mskala $ */
 /* Copyright (C) 2000-2012  George Williams
  * Copyright (C) 2015  Matthew Skala
  *
@@ -42,7 +42,7 @@
 #include <time.h>
 #include "psfont.h"
 #include "splinefont.h"
-#include <gdraw.h>		/* For image defn */
+#include <gimage.h>		/* For image defn */
 #include "print.h"		/* For makePatName */
 
 #ifdef __CygWin
@@ -135,7 +135,7 @@ static int isStdEncoding(char *encoding[256]) {
    return (1);
 }
 
-static void dumpblues(AFILE *f,char *name,real *arr,int len,char *ND) {
+static void dumpblues(AFILE *f,char *name,double *arr,int len,char *ND) {
    int i;
 
    for (--len; len >= 0 && arr[len]==0.0; --len);
@@ -149,7 +149,7 @@ static void dumpblues(AFILE *f,char *name,real *arr,int len,char *ND) {
 }
 
 static void dumpdblmaxarray(AFILE *f,
-			    char *name,real *arr,int len,char *modifiers,
+			    char *name,double *arr,int len,char *modifiers,
 			    char *ND) {
    int i;
 
@@ -344,8 +344,8 @@ static void dumpsplineset(AFILE *f,
    }
 }
 
-static int InvertTransform(real inverse[6],real transform[6]) {
-   real temp[6], val;
+static int InvertTransform(double inverse[6],double transform[6]) {
+   double temp[6], val;
    int i;
 
    for (i=0; i < 6; ++i)
@@ -450,7 +450,6 @@ static void dumpGradient(AFILE *f,
 	 aputc('\n',f);
 	 for (i=0; i <= 100; ++i) {
 	    int col;
-
 	    double t=grad->grad_stops[0].offset +
 	       (grad->grad_stops[grad->stop_cnt - 1].offset -
 		grad->grad_stops[0].offset) * i / 100.0;
@@ -505,7 +504,7 @@ static void dumpPattern(AFILE *f,
 			int layer, int pdfopers, int isstroke) {
    SplineChar *pattern_sc=SFGetChar(sc->parent, -1, pat->pattern);
    DBounds b;
-   real scale[6], result[6];
+   double scale[6], result[6];
 
    if (pdfopers) {
       char buffer[200];
@@ -632,7 +631,7 @@ static void PSDumpBinaryData(AFILE *f,uint8_t *bytes,int rows,
    AFILE *ps;
    int i,j,cnt,group_cnt;
    const int max_string=65536;
-   
+
    if (useful_bytes_per_row * rows < max_string) {
       /* It all fits in one string. Easy peasy */
       afputs("{<~",f);
@@ -773,7 +772,6 @@ static void PSBuildImageIndexDict(AFILE *f,struct _GImage *base) {
 }
 
 static void PSDrawImg(AFILE *f,struct _GImage *base) {
-
    if (base->image_type==it_index) {
       PSSetIndexColors(f, base->clut);
       PSBuildImageIndexDict(f, base);
@@ -824,7 +822,7 @@ void SC_PSDump(AFILE *f,
 	       SplineChar *sc, int refs_to_splines, int pdfopers,
 	       int layer) {
    RefChar *ref;
-   real inverse[6];
+   double inverse[6];
    int i, last, first;
    SplineSet *temp;
 
@@ -1005,7 +1003,6 @@ void SC_PSDump(AFILE *f,
       }
       if (sc->layers[i].images != NULL) {
 	 ImageList *img;
-
 	 int icnt=0;
 
 	 afputs(pdfopers?"q\n":"gsave\n",f);
@@ -1328,8 +1325,8 @@ static double FindMaxDiffOfBlues(char *pt,double max_diff) {
    return (max_diff);
 }
 
-double BlueScaleFigureForced(struct psdict *private_, real bluevalues[],
-			     real otherblues[]) {
+double BlueScaleFigureForced(struct psdict *private_, double bluevalues[],
+			     double otherblues[]) {
    double max_diff=0;
    char *pt;
    int i;
@@ -1366,11 +1363,11 @@ double BlueScaleFigureForced(struct psdict *private_, real bluevalues[],
    if (1 / max_diff > .039625)
       return (-1);
 
-   return (.99 / max_diff);
+   return rint(240.0*0.99/max_diff)/240.0;
 }
 
-double BlueScaleFigure(struct psdict *private_, real bluevalues[],
-		       real otherblues[]) {
+double BlueScaleFigure(struct psdict *private_, double bluevalues[],
+		       double otherblues[]) {
    if (PSDictHasEntry(private_, "BlueScale") != NULL)
       return (-1);
    return BlueScaleFigureForced(private_, bluevalues, otherblues);
@@ -1380,10 +1377,10 @@ static int dumpprivatestuff(AFILE *f,
 			    SplineFont *sf, struct fddata *incid, int flags,
 			    enum fontformat format, EncMap * map, int layer) {
    int cnt, mi;
-   real bluevalues[14], otherblues[10];
-   real snapcnt[12];
-   real stemsnaph[12], stemsnapv[12];
-   real stdhw[1], stdvw[1];
+   double bluevalues[14], otherblues[10];
+   double snapcnt[12];
+   double stemsnaph[12], stemsnapv[12];
+   double stdhw[1], stdvw[1];
    int flex_max;
    int i;
    int hasblue=0, hash=0, hasv =
@@ -1670,7 +1667,6 @@ static void dumpfontinfo(AFILE *f,
    }
    if (format==ff_mma || format==ff_mmb) {
       MMSet *mm=sf->mm;
-
       int j, k;
 
       afputs(" /BlendDesignPositions [",f);
@@ -1704,7 +1700,6 @@ static void dumpfontinfo(AFILE *f,
 
 static void dumpfontcomments(AFILE *f, SplineFont *sf, int format) {
    time_t now;
-   const char *author=GetAuthor();
 
    time(&now);
    /* Werner points out that the DSC Version comment has a very specific */
@@ -1722,17 +1717,13 @@ static void dumpfontcomments(AFILE *f, SplineFont *sf, int format) {
       afprintf(f,"%%Version: %s\n", sf->version);
    }
    afprintf(f,"%%%%CreationDate: %s", ctime(&now));
-   if (author != NULL)
-      afprintf(f,"%%%%Creator: %s\n", author);
 
    if (format==ff_cid || format==ff_cffcid || format==ff_type42cid ||
        format==ff_cff || format==ff_type42)
       afprintf(f,"%%%%LanguageLevel: 3\n");
    else if (sf->multilayer && format==ff_ptype3) {
       int gid, ly;
-
       SplineChar *sc;
-
       int had_pat=0, had_grad=0;
 
       for (gid=0; gid < sf->glyphcnt; ++gid)
@@ -1983,7 +1974,7 @@ static void dumpencodedstuff(AFILE *f,SplineFont *sf, int format,
    AFILE *obfs;
 
    obfs=ps_obfuscated_afile(f,(format==ff_pfb)||(format==ff_mmb));
-   
+
    dumpprivatestuff(obfs,sf,NULL,flags,format,map,layer);
    if (format==ff_ptype0) {
       aputc('/',obfs);
