@@ -1,4 +1,4 @@
-/* $Id: encoding.c 4070 2015-06-29 06:49:37Z mskala $ */
+/* $Id: encoding.c 4427 2015-11-22 17:13:49Z mskala $ */
 /* Copyright (C) 2000-2012  George Williams
  * Copyright (C) 2015  Matthew Skala
  *
@@ -35,13 +35,27 @@
 #include <sys/types.h>
 #include <dirent.h>
 #include <gfile.h>
-#include "encoding.h"
-#include "ffglib.h"
-#include <glib/gprintf.h>
 
 #include "macenctab.h"
 #include "nonmactab.h"
 
+struct cidaltuni {
+   struct cidaltuni *next;
+   int uni;
+   int cid;
+};
+
+struct cidmap {
+   char *registry, *ordering;
+   int supplement, maxsupple;
+   int cidmax;			/* Max cid found in the charset */
+   int namemax;			/* Max cid with useful info */
+   uint32_t *unicode;
+   char **name;
+   struct cidaltuni *alts;
+   struct cidmap *next;
+};
+
 typedef int (*EncFunc) (int);
 
 Encoding *default_encoding=NULL;
@@ -82,7 +96,6 @@ const char *FindUnicharName(void) {
    /* Even worse, both accept UCS-2, but under iconv it means native byte */
    /*  ordering and under libiconv it means big-endian */
    iconv_t test;
-
    static char *goodname=NULL;
    static char *names[] =
       { "UCS-4-INTERNAL", "UCS-4", "UCS4", "ISO-10646-UCS-4", "UTF-32",
@@ -90,7 +103,6 @@ NULL };
    static char *namesle[]={ "UCS-4LE","UTF-32LE",NULL };
    static char *namesbe[]={ "UCS-4BE","UTF-32BE",NULL };
    char **testnames;
-
    int i;
 
    union {
@@ -285,12 +297,12 @@ static Encoding *_FindOrMakeEncoding(const char *name,int make_it) {
    temp.builtin=true;
    temp.tounicode=iconv_open(FindUnicharName(), iconv_name);
    if (temp.tounicode==(iconv_t) - 1 || temp.tounicode==NULL)
-      return (NULL);		/* Iconv doesn't recognize this name */
+      return NULL;		/* Iconv doesn't recognize this name */
    temp.fromunicode=iconv_open(iconv_name, FindUnicharName());
    if (temp.fromunicode==(iconv_t) - 1 || temp.fromunicode==NULL) {
       /* This should never happen, but if it does... */
       iconv_close(temp.tounicode);
-      return (NULL);
+      return NULL;
    }
 
    memset(good, 0, sizeof(good));
@@ -369,9 +381,9 @@ static Encoding *_FindOrMakeEncoding(const char *name,int make_it) {
       }
    }
    if (!temp.has_1byte && !temp.has_2byte)
-      return (NULL);
+      return NULL;
    if (!make_it)
-      return (NULL);
+      return NULL;
 
    enc=chunkalloc(sizeof(Encoding));
    *enc=temp;
@@ -419,7 +431,6 @@ Encoding *FindOrMakeEncoding(const char *name) {
 /* Plugin API */
 int AddEncoding(char *name, EncFunc enc_to_uni, EncFunc uni_to_enc, int max) {
    Encoding *enc;
-
    int i;
 
    for (enc=enclist; enc != NULL; enc=enc->next) {
@@ -476,7 +487,6 @@ static void EncodingFree(Encoding *item) {
 
 static void DeleteEncoding(Encoding *me) {
    FontViewBase *fv;
-
    Encoding *prev;
 
    if (me->builtin)
@@ -508,11 +518,8 @@ static void DeleteEncoding(Encoding *me) {
     /* # is a comment character (to eol) */
 static Encoding *ParseConsortiumEncodingFile(AFILE *file) {
    char buffer[200];
-
    int32_t encs[0x10000];
-
    int enc, unienc, max;
-
    Encoding *item;
 
    memset(encs, 0, sizeof(encs));
@@ -530,7 +537,7 @@ static Encoding *ParseConsortiumEncodingFile(AFILE *file) {
    }
 
    if (max==-1)
-      return (NULL);
+      return NULL;
 
    ++max;
    if (max < 256)
@@ -556,13 +563,9 @@ static void RemoveMultiples(Encoding *item) {
 
 char *ParseEncodingFile(char *filename, char *encodingname) {
    AFILE *file;
-
    char *orig=filename;
-
    Encoding *head, *item, *prev, *next;
-
    char *buf, *name;
-
    int i, ch;
 
    if (filename==NULL)
@@ -571,12 +574,12 @@ char *ParseEncodingFile(char *filename, char *encodingname) {
    if (file==NULL) {
       if (orig != NULL)
 	 ErrorMsg(2,"Couldn't open file %.200s\n",orig);
-      return (NULL);
+      return NULL;
    }
    ch=agetc(file);
    if (ch==EOF) {
       afclose(file);
-      return (NULL);
+      return NULL;
    }
    aungetc(ch, file);
    if (ch=='#' || ch=='0') {
@@ -588,7 +591,7 @@ char *ParseEncodingFile(char *filename, char *encodingname) {
    afclose(file);
    if (head==NULL) {
       ErrorMsg(2,"Bad encoding file format\n");
-      return (NULL);
+      return NULL;
    }
 
    for (i=0, prev=NULL, item=head; item != NULL;
@@ -596,7 +599,7 @@ char *ParseEncodingFile(char *filename, char *encodingname) {
       next=item->next;
       if (item->enc_name==NULL) {
 	 ErrorMsg(2,"Bad encoding file format (unnamed encoding).\n");
-	 return (NULL);
+	 return NULL;
       }
    }
    for (item=head; item != NULL; item=item->next)
@@ -624,9 +627,7 @@ int CIDFromName(char *name, SplineFont *cidmaster) {
    /*  cid 504 */
    /* Other convention "cid-504.vert" */
    int len=strlen(cidmaster->ordering);
-
    int cid;
-
    char *end;
 
    if (strncmp(name, cidmaster->ordering, len)==0) {
@@ -647,7 +648,6 @@ int CIDFromName(char *name, SplineFont *cidmaster) {
 
 int CID2NameUni(struct cidmap *map, int cid, char *buffer, int len) {
    int enc=-1;
-
    const char *temp;
 
    if (map==NULL)
@@ -672,7 +672,6 @@ int CID2NameUni(struct cidmap *map, int cid, char *buffer, int len) {
 
 int NameUni2CID(struct cidmap *map, int uni, const char *name) {
    int i;
-
    struct cidaltuni *alts;
 
    if (map==NULL)
@@ -697,7 +696,6 @@ int NameUni2CID(struct cidmap *map, int uni, const char *name) {
 struct altuni *CIDSetAltUnis(struct cidmap *map, int cid) {
    /* Some CIDs are mapped to several unicode code points, damn it */
    struct altuni *sofar=NULL, *alt;
-
    struct cidaltuni *alts;
 
    for (alts=map->alts; alts != NULL; alts=alts->next) {
@@ -719,19 +717,14 @@ int MaxCID(struct cidmap *map) {
 static char *SearchDirForCidMap(char *dir,char *registry,char *ordering,
 				int supplement, char **maybefile) {
    char maybe[FILENAME_MAX + 1];
-
    struct dirent *ent;
-
    DIR *d;
-
    int len, rlen=strlen(registry), olen=strlen(ordering);
-
    char *pt, *end, *ret;
-
    int test, best=-1;
 
    if (dir==NULL)
-      return (NULL);
+      return NULL;
 
    if (*maybefile != NULL) {
       char *pt=strrchr(*maybefile, '.');
@@ -743,7 +736,7 @@ static char *SearchDirForCidMap(char *dir,char *registry,char *ordering,
 
    d=opendir(dir);
    if (d==NULL)
-      return (NULL);
+      return NULL;
    while ((ent=readdir(d)) != NULL) {
       if ((len=strlen(ent->d_name)) < 8)
 	 continue;
@@ -781,7 +774,7 @@ static char *SearchDirForCidMap(char *dir,char *registry,char *ordering,
       strcat(ret, maybe);
       *maybefile=ret;
    }
-   return (NULL);
+   return NULL;
 }
 
 static struct cidmap *MakeDummyMap(char *registry,char *ordering,
@@ -803,13 +796,9 @@ static struct cidmap *MakeDummyMap(char *registry,char *ordering,
 struct cidmap *LoadMapFromFile(char *file, char *registry, char *ordering,
 			       int supplement) {
    struct cidmap *ret=malloc(sizeof(struct cidmap));
-
    char *pt=strrchr(file, '.');
-
    AFILE *f;
-
    int cid1, cid2, uni, cnt, i, ch;
-
    char name[100];
 
    while (pt > file && isdigit(pt[-1]))
@@ -875,14 +864,12 @@ struct cidmap *FindCidMap(char *registry, char *ordering, int supplement,
    struct cidmap *map, *maybe=NULL;
    char *file, *maybefile=NULL;
    int maybe_sup=-1;
-   char *buts[3], *buts2[3], *buts3[3];
-   gchar *buf=NULL;
    int ret;
 
    if (sf != NULL && sf->cidmaster)
       sf=sf->cidmaster;
    if (sf != NULL && sf->loading_cid_map)
-      return (NULL);
+      return NULL;
 
    for (map=cidmaps; map != NULL; map=map->next) {
       if (strcmp(map->registry, registry)==0
@@ -920,9 +907,6 @@ struct cidmap *FindCidMap(char *registry, char *ordering, int supplement,
 	 maybe_sup=maybe->supplement;
       if (sf != NULL)
 	 sf->loading_cid_map=true;
-      buts[0]=_("_Use It");
-      buts[1]=_("_Search");
-      buts[2]=NULL;
       ret=0;
       if (sf != NULL)
 	 sf->loading_cid_map=false;
@@ -936,34 +920,15 @@ struct cidmap *FindCidMap(char *registry, char *ordering, int supplement,
    }
 
    if (file==NULL) {
-      char *uret;
-
-      buf=g_strdup_printf("%s-%s-*.cidmap", registry, ordering);
       if (maybe==NULL && maybefile==NULL) {
-	 buts3[0]=_("_Browse");
-	 buts3[1]=_("_Give Up");
-	 buts3[2]=NULL;
 	 ret=0;
-	 g_free(buf);
-	 buf=NULL;
-      }
-      uret=NULL;
-      if (uret==NULL) {
-	 buts2[0]="_Use It";
-	 buts2[1]="_Search";
-	 buts2[2]=NULL;
-	 if (maybe==NULL && maybefile==NULL)
-	    /* No luck */ ;
-	 else if (maybe!=NULL) {
-	    maybe->maxsupple=supplement;
-	    return (maybe);
-	 } else {
-	    file=maybefile;
-	    maybefile=NULL;
-	 }
+	 /* No luck */ ;
+      } else if (maybe!=NULL) {
+	 maybe->maxsupple=supplement;
+	 return (maybe);
       } else {
-	 file=fastrdup(uret);
-	 free(uret);
+	 file=maybefile;
+	 maybefile=NULL;
       }
    }
 
@@ -979,11 +944,8 @@ struct cidmap *FindCidMap(char *registry, char *ordering, int supplement,
 
 static void SFApplyOrdering(SplineFont *sf,int glyphcnt) {
    SplineChar **glyphs, *sc;
-
    int i;
-
    RefChar *refs, *rnext, *rprev;
-
    SplineSet *new, *spl;
 
    /* Remove references to characters which aren't in the new map (if any) */
@@ -1028,7 +990,6 @@ static void SFApplyOrdering(SplineFont *sf,int glyphcnt) {
 /* Convert a normal font to a cid font, rearranging glyphs into cid order */
 static void SFEncodeToMap(SplineFont *sf,struct cidmap *map) {
    SplineChar *sc;
-
    int i, max=0, anyextras=0;
 
    for (i=0; i < sf->glyphcnt; ++i)
@@ -1041,13 +1002,6 @@ static void SFEncodeToMap(SplineFont *sf,struct cidmap *map) {
       } else if (sc != NULL)
 	 sc->orig_pos=-1;
 
-   if (anyextras) {
-      char *buttons[3];
-
-      buttons[0]=_("_Delete");
-      buttons[1]=_("_Add");
-      buttons[2]=NULL;
-   }
    SFApplyOrdering(sf, max + 1);
 }
 
@@ -1106,17 +1060,11 @@ static char *readpsstr(char *str) {
 
 static struct cmap *ParseCMap(char *filename) {
    char buf2[200];
-
    AFILE *file;
-
    struct cmap *cmap;
-
    char *end, *pt;
-
    int val, pos;
-
    enum cmaptype in;
-
    static const char *bcsr="begincodespacerange",*bndr =
       "beginnotdefrange", *bcr="begincidrange";
    static const char *reg="/Registry",*ord="/Ordering",*sup =
@@ -1124,7 +1072,7 @@ static struct cmap *ParseCMap(char *filename) {
 
    file=afopen(filename, "r");
    if (file==NULL)
-      return (NULL);
+      return NULL;
 
    cmap=calloc(1, sizeof(struct cmap));
    in=cmt_out;
@@ -1186,7 +1134,6 @@ static struct cmap *ParseCMap(char *filename) {
 
 static void CompressCMap(struct cmap *cmap) {
    int32_t i, j, k, pos, base;
-
    uint32_t min, oldmax;
 
    /* we can't really deal with three and four byte encodings */
@@ -1254,17 +1201,13 @@ static void CompressCMap(struct cmap *cmap) {
 static SplineFont *CIDFlatten(SplineFont *cidmaster,SplineChar ** glyphs,
 		       int charcnt) {
    FontViewBase *fvs;
-
    SplineFont *new;
-
    char buffer[20];
-
    BDFFont *bdf;
-
    int j;
 
    if (cidmaster==NULL)
-      return (NULL);
+      return NULL;
    new=SplineFontEmpty();
    new->fontname=fastrdup(cidmaster->fontname);
    new->fullname=fastrdup(cidmaster->fullname);
@@ -1288,10 +1231,10 @@ static SplineFont *CIDFlatten(SplineFont *cidmaster,SplineChar ** glyphs,
    cidmaster->bitmaps=NULL;	/* don't free 'em */
    for (bdf=new->bitmaps; bdf != NULL; bdf=bdf->next)
       bdf->sf=new;
-   new->gpos_lookups=cidmaster->gpos_lookups;
-   cidmaster->gpos_lookups=NULL;
-   new->gsub_lookups=cidmaster->gsub_lookups;
-   cidmaster->gsub_lookups=NULL;
+   new->gsplookups[0]=cidmaster->gsplookups[0];
+   cidmaster->gsplookups[0]=NULL;
+   new->gsplookups[1]=cidmaster->gsplookups[1];
+   cidmaster->gsplookups[1]=NULL;
    new->kerns=cidmaster->kerns;
    new->vkerns=cidmaster->vkerns;
    cidmaster->kerns=cidmaster->vkerns=NULL;
@@ -1346,7 +1289,6 @@ static SplineFont *CIDFlatten(SplineFont *cidmaster,SplineChar ** glyphs,
 
 void SFFlatten(SplineFont *cidmaster) {
    SplineChar **glyphs;
-
    int i, j, max;
 
    if (cidmaster==NULL)
@@ -1421,66 +1363,68 @@ int SFFlattenByCMap(SplineFont *sf, char *cmapname) {
    }
    sf=CIDFlatten(sf, glyphs, curmax);
 
-   warned=true;
    for (fvs=sf->fv; fvs != NULL; fvs=fvs->nextsame) {
       EncMap *map=fvs->map;
 
-      for (j=0; j < 2; ++j) {
-	 extras=0;
-	 for (i=0; i < curmax; ++i) {
-	    sc=glyphs[i];
-	    if (sc != NULL) {
-	       m=0;
-	       for (l=0; l < cmap->groups[cmt_cid].n; ++l) {
-		  if (i >= cmap->groups[cmt_cid].ranges[l].cid &&
-		      i <= cmap->groups[cmt_cid].ranges[l].cid +
-		      cmap->groups[cmt_cid].ranges[l].last -
-		      cmap->groups[cmt_cid].ranges[l].first) {
-		     if (m < sizeof(found) / sizeof(found[0]))
-			found[m++]=l;
-		     else if (!warned) {
-			ErrorMsg(1,"The glyph at CID %d is mapped to more "
-			           "than %d encodings.  Only the first %d "
-			           "are handled.\n",
-                                 i,sizeof(found)/sizeof(found[0]),
-                                 sizeof(found)/sizeof(found[0]));
-			warned=true;
-		     }
-		  }
+      j=0;
+      extras=0;
+      for (i=0; i < curmax; ++i) {
+	 sc=glyphs[i];
+	 if (sc != NULL) {
+	    m=0;
+	    for (l=0; l < cmap->groups[cmt_cid].n; ++l) {
+	       if (i >= cmap->groups[cmt_cid].ranges[l].cid &&
+		   i <= cmap->groups[cmt_cid].ranges[l].cid +
+		   cmap->groups[cmt_cid].ranges[l].last -
+		   cmap->groups[cmt_cid].ranges[l].first) {
+		  if (m < sizeof(found) / sizeof(found[0]))
+		    found[m++]=l;
 	       }
-	       if (m==0) {
-		  if (j) {
-		     map->map[max + extras]=sc->orig_pos;
-		     map->backmap[sc->orig_pos]=max + extras;
-		  }
-		  ++extras;
-	       } else {
-		  if (j) {
-		     int p=cmap->groups[cmt_cid].ranges[found[0]].first +
-			i - cmap->groups[cmt_cid].ranges[found[0]].cid;
-		     map->map[p]=sc->orig_pos;
-		     map->backmap[sc->orig_pos]=p;
-		     for (l=1; l < m; ++l) {
-			int pos =
-			   cmap->groups[cmt_cid].ranges[found[l]].first + i -
-			   cmap->groups[cmt_cid].ranges[found[l]].cid;
-			map->map[pos]=sc->orig_pos;
-		     }
-		  }
+	       if (m==0)
+		 ++extras;
+	    }
+	 }
+      }
+      map->map =
+	realloc(map->map,
+		(map->encmax=map->enccount =
+		    max + extras) * sizeof(int32_t));
+      memset(map->map, -1, map->enccount * sizeof(int32_t));
+      memset(map->backmap, -1, sf->glyphcnt * sizeof(int32_t));
+      map->remap=cmap->remap;
+      cmap->remap=NULL;
+      
+      extras=0;
+      for (i=0; i < curmax; ++i) {
+	 sc=glyphs[i];
+	 if (sc != NULL) {
+	    m=0;
+	    for (l=0; l < cmap->groups[cmt_cid].n; ++l) {
+	       if (i >= cmap->groups[cmt_cid].ranges[l].cid &&
+		   i <= cmap->groups[cmt_cid].ranges[l].cid +
+		   cmap->groups[cmt_cid].ranges[l].last -
+		   cmap->groups[cmt_cid].ranges[l].first) {
+		  if (m < sizeof(found) / sizeof(found[0]))
+		    found[m++]=l;
+	       }
+	    }
+	    if (m==0) {
+	       map->map[max + extras]=sc->orig_pos;
+	       map->backmap[sc->orig_pos]=max + extras;
+	       ++extras;
+	    } else {
+	       int p=cmap->groups[cmt_cid].ranges[found[0]].first +
+		 i - cmap->groups[cmt_cid].ranges[found[0]].cid;
+	       map->map[p]=sc->orig_pos;
+	       map->backmap[sc->orig_pos]=p;
+	       for (l=1; l < m; ++l) {
+		  int pos =
+		    cmap->groups[cmt_cid].ranges[found[l]].first + i -
+		    cmap->groups[cmt_cid].ranges[found[l]].cid;
+		  map->map[pos]=sc->orig_pos;
 	       }
 	    }
 	 }
-	 if (!j) {
-	    map->map =
-	       realloc(map->map,
-		       (map->encmax=map->enccount =
-			max + extras) * sizeof(int32_t));
-	    memset(map->map, -1, map->enccount * sizeof(int32_t));
-	    memset(map->backmap, -1, sf->glyphcnt * sizeof(int32_t));
-	    map->remap=cmap->remap;
-	    cmap->remap=NULL;
-	 }
-	 warned=true;
       }
    }
    cmapfree(cmap);
@@ -1502,7 +1446,6 @@ static int Enc2CMap(struct cmap *cmap,int enc) {
 static void SFEncodeToCMap(SplineFont *cidmaster,SplineFont *sf,
 			   EncMap * oldmap, struct cmap *cmap) {
    SplineChar *sc, *GID0=NULL;
-
    int i, max=0, anyextras=0;
 
    cidmaster->cidregistry=cmap->registry;
@@ -1543,9 +1486,7 @@ static void SFEncodeToCMap(SplineFont *cidmaster,SplineFont *sf,
 /*  is meaningful. Set the master to the subfont with the most glyphs */
 static void CIDMasterAsDes(SplineFont *sf) {
    SplineFont *cidmaster=sf->cidmaster;
-
    SplineFont *best;
-
    int i, cid, cnt, bcnt;
 
    if (cidmaster==NULL)
@@ -1566,7 +1507,6 @@ static void CIDMasterAsDes(SplineFont *sf) {
       best=cidmaster->subfonts[0];
    if (best != NULL) {
       double ratio=1000.0 / (best->ascent + best->descent);
-
       int ascent=rint(best->ascent * ratio);
 
       if (cidmaster->ascent != ascent || cidmaster->descent != 1000 - ascent) {
@@ -1579,23 +1519,20 @@ static void CIDMasterAsDes(SplineFont *sf) {
 SplineFont *MakeCIDMaster(SplineFont *sf, EncMap * oldmap, int bycmap,
 			  char *cmapfilename, struct cidmap *cidmap) {
    SplineFont *cidmaster;
-
    struct cidmap *map;
-
    struct cmap *cmap;
-
    FontViewBase *fvs;
 
    cidmaster=SplineFontEmpty();
    if (bycmap) {
       if (cmapfilename==NULL) {
 	 SplineFontFree(cidmaster);
-	 return (NULL);
+	 return NULL;
       }
       cmap=ParseCMap(cmapfilename);
       if (cmap==NULL) {
 	 SplineFontFree(cidmaster);
-	 return (NULL);
+	 return NULL;
       }
       CompressCMap(cmap);
       SFEncodeToCMap(cidmaster, sf, oldmap, cmap);
@@ -1604,7 +1541,7 @@ SplineFont *MakeCIDMaster(SplineFont *sf, EncMap * oldmap, int bycmap,
       map=cidmap;
       if (map==NULL) {
 	 SplineFontFree(cidmaster);
-	 return (NULL);
+	 return NULL;
       }
       cidmaster->cidregistry=fastrdup(map->registry);
       cidmaster->ordering=fastrdup(map->ordering);
@@ -1640,10 +1577,10 @@ SplineFont *MakeCIDMaster(SplineFont *sf, EncMap * oldmap, int bycmap,
    cidmaster->subfontcnt=1;
    cidmaster->subfonts=calloc(2, sizeof(SplineFont *));
    cidmaster->subfonts[0]=sf;
-   cidmaster->gpos_lookups=sf->gpos_lookups;
-   sf->gpos_lookups=NULL;
-   cidmaster->gsub_lookups=sf->gsub_lookups;
-   sf->gsub_lookups=NULL;
+   cidmaster->gsplookups[0]=sf->gsplookups[0];
+   sf->gsplookups[0]=NULL;
+   cidmaster->gsplookups[1]=sf->gsplookups[1];
+   sf->gsplookups[1]=NULL;
    cidmaster->horiz_base=sf->horiz_base;
    sf->horiz_base=NULL;
    cidmaster->vert_base=sf->vert_base;
@@ -1672,7 +1609,6 @@ SplineFont *MakeCIDMaster(SplineFont *sf, EncMap * oldmap, int bycmap,
 
 static void BDFOrigFixup(BDFFont *bdf,int orig_cnt,SplineFont *sf) {
    BDFChar **glyphs;
-
    int i;
 
    if (bdf->glyphmax >= orig_cnt) {
@@ -1699,9 +1635,7 @@ static void BDFOrigFixup(BDFFont *bdf,int orig_cnt,SplineFont *sf) {
 
 static int _SFForceEncoding(SplineFont *sf,EncMap *old,Encoding *new_enc) {
    int enc_cnt, i;
-
    BDFFont *bdf;
-
    FontViewBase *fvs;
 
    /* Normally we base our encoding process on unicode code points. */
@@ -1730,9 +1664,7 @@ static int _SFForceEncoding(SplineFont *sf,EncMap *old,Encoding *new_enc) {
       for (i=0; i < sf->glyphcnt; ++i)
 	 if (sf->glyphs[i] != NULL) {
 	    struct splinecharlist *scl;
-
 	    int layer;
-
 	    RefChar *ref;
 
 	    for (scl=sf->glyphs[i]->dependents; scl != NULL;
@@ -1795,7 +1727,6 @@ static int _SFForceEncoding(SplineFont *sf,EncMap *old,Encoding *new_enc) {
    for (i=0; i < old->enccount && i < enc_cnt; ++i)
       if (old->map[i] != -1 && sf->glyphs[old->map[i]] != NULL) {
 	 SplineChar dummy;
-
 	 int j=old->map[i];
 
 	 SCBuildDummy(&dummy, sf, old, i);
@@ -1808,9 +1739,7 @@ static int _SFForceEncoding(SplineFont *sf,EncMap *old,Encoding *new_enc) {
    for (i=0; i < sf->glyphcnt; ++i)
       if (sf->glyphs[i] != NULL) {
 	 struct splinecharlist *scl;
-
 	 int layer;
-
 	 RefChar *ref;
 
 	 for (scl=sf->glyphs[i]->dependents; scl != NULL; scl=scl->next) {
@@ -1826,7 +1755,6 @@ static int _SFForceEncoding(SplineFont *sf,EncMap *old,Encoding *new_enc) {
 int SFForceEncoding(SplineFont *sf, EncMap * old, Encoding * new_enc) {
    if (sf->mm != NULL) {
       MMSet *mm=sf->mm;
-
       int i;
 
       for (i=0; i < mm->instance_count; ++i)
@@ -1840,17 +1768,13 @@ int SFForceEncoding(SplineFont *sf, EncMap * old, Encoding * new_enc) {
 
 EncMap *EncMapFromEncoding(SplineFont *sf, Encoding * enc) {
    int i, j, extras, found, base, unmax;
-
    int32_t *encoded, *unencoded;
-
    EncMap *map;
-
    struct altuni *altuni;
-
    SplineChar *sc;
 
    if (enc==NULL)
-      return (NULL);
+      return NULL;
 
    base=enc->char_cnt;
    if (enc->is_original)
@@ -1909,7 +1833,6 @@ EncMap *EncMapFromEncoding(SplineFont *sf, Encoding * enc) {
    if (enc->is_unicodefull && (sf->uni_interp==ui_trad_chinese ||
 			       sf->uni_interp==ui_ams)) {
       extern const int cns14pua[], amspua[];
-
       const int *pua=sf->uni_interp==ui_ams ? amspua : cns14pua;
 
       for (i=0xe000; i < 0xf8ff; ++i) {
@@ -2129,7 +2052,6 @@ static int MapAddEncodingSlot(EncMap *map,int gid) {
 
 static void FVAddEncodingSlot(FontViewBase *fv,int gid) {
    EncMap *map=fv->map;
-
    int enc;
 
    enc=MapAddEncodingSlot(map, gid);
@@ -2193,9 +2115,7 @@ static int MapAddEnc(SplineFont *sf,SplineChar *sc,EncMap *basemap,
 void SFAddGlyphAndEncode(SplineFont *sf, SplineChar * sc, EncMap * basemap,
 			 int baseenc) {
    int gid, mapfound=false;
-
    FontViewBase *fv;
-
    BDFFont *bdf;
 
    if (sf->cidmaster==NULL) {
@@ -2293,9 +2213,7 @@ static SplineChar *SplineCharMatch(SplineFont *parent,SplineChar *sc) {
 void SFMatchGlyphs(SplineFont *sf, SplineFont *target, int addempties) {
    /* reorder sf so that its glyphs array is the same as that in target */
    int i, j, cnt, cnt2;
-
    SplineChar **glyphs;
-
    BDFFont *bdf;
 
    for (i=0; i < sf->glyphcnt; ++i)
@@ -2352,9 +2270,7 @@ void SFMatchGlyphs(SplineFont *sf, SplineFont *target, int addempties) {
 void MMMatchGlyphs(MMSet * mm) {
    /* reorder all instances so that they have the same orig_pos */
    int i, j, index, lasthole;
-
    SplineFont *sf, *base=NULL;
-
    SplineChar *sc, *scnew, *sc2;
 
    for (i=0; i < mm->instance_count; ++i)
@@ -2414,13 +2330,9 @@ void MMMatchGlyphs(MMSet * mm) {
 
 int32_t UniFromEnc(int enc, Encoding * encname) {
    char from[20];
-
    unichar_t to[20];
-
    ICONV_CONST char *fpt;
-
    char *tpt;
-
    size_t fromlen, tolen;
 
    if (encname->is_custom || encname->is_original)
@@ -2476,7 +2388,6 @@ int32_t UniFromEnc(int enc, Encoding * encname) {
 
 	    printf("UniFromEnc(ret1) %ld\n", t);
 	    unichar_t low16=t & 0xFFFF;
-
 	    unichar_t high16=t >> 16;
 
 	    t=(low16 << 16) | high16;
@@ -2495,15 +2406,10 @@ int32_t UniFromEnc(int enc, Encoding * encname) {
 
 int32_t EncFromUni(int32_t uni, Encoding * enc) {
    unichar_t from[20];
-
    unsigned char to[20];
-
    ICONV_CONST char *fpt;
-
    char *tpt;
-
    size_t fromlen, tolen;
-
    int i;
 
    if (enc->is_custom || enc->is_original || enc->is_compact || uni==-1)
@@ -2571,7 +2477,6 @@ int32_t EncFromName(const char *name, enum uni_interp interp,
 
 void SFExpandGlyphCount(SplineFont *sf, int newcnt) {
    int old=sf->glyphcnt;
-
    FontViewBase *fv;
 
    if (old >= newcnt)
