@@ -1,4 +1,4 @@
-/* $Id: fontviewbase.c 4064 2015-06-25 14:15:40Z mskala $ */
+/* $Id: fontviewbase.c 4464 2015-11-30 09:57:27Z mskala $ */
 /* Copyright (C) 2000-2012  George Williams
  * Copyright (C) 2015  Matthew Skala
  *
@@ -30,7 +30,6 @@
 #include "baseviews.h"
 #include "psfont.h"
 #include <gfile.h>
-#include <gio.h>
 #include <ustring.h>
 #include <utype.h>
 #include <chardata.h>
@@ -76,7 +75,6 @@ static int BCUnselectedDependents(FontViewBase *fv,BDFChar *bc) {
 
 static int UnselectedDependents(FontViewBase *fv,int gid) {
    int ret=false;
-
    BDFFont *bdf;
 
    if (onlycopydisplayed && fv->active_bitmap==NULL) {
@@ -97,7 +95,6 @@ void FVClear(FontViewBase * fv) {
    int i;
    BDFFont *bdf;
    int refstate=0;
-   char *buts[6];
    int yes, unsel, gid;
 
    /* refstate==0 => ask, refstate==1 => clearall, refstate==-1 => skip all */
@@ -107,12 +104,6 @@ void FVClear(FontViewBase * fv) {
 	 /* If we are messing with the outline character, check for dependencies */
 	 if (refstate <= 0 && (unsel=UnselectedDependents(fv, gid))) {
 	    if (refstate==0) {
-	       buts[0]=_("_Yes");
-	       buts[1]=_("Yes to _All");
-	       buts[2]=_("_Unlink All");
-	       buts[3]=_("No _to All");
-	       buts[4]=_("_No");
-	       buts[5]=NULL;
 	       yes=2;
 	       refstate=-2;
 	    }
@@ -150,7 +141,6 @@ void FVClear(FontViewBase * fv) {
 
 void FVClearBackground(FontViewBase * fv) {
    SplineFont *sf=fv->sf;
-
    int i, gid;
 
    if (onlycopydisplayed && fv->active_bitmap != NULL)
@@ -279,11 +269,8 @@ static void LinkEncToGid(FontViewBase *fv,int enc,int gid) {
 
 void FVSameGlyphAs(FontViewBase * fv) {
    SplineFont *sf=fv->sf;
-
    RefChar *base=CopyContainsRef(sf);
-
    int i;
-
    EncMap *map=fv->map;
 
    if (base==NULL || fv->cidmaster != NULL)
@@ -296,14 +283,11 @@ void FVSameGlyphAs(FontViewBase * fv) {
 
 void FVBuildDuplicate(FontViewBase * fv) {
    extern const int cns14pua[], amspua[];
-
    const int *pua =
       fv->sf->uni_interp==ui_trad_chinese ? cns14pua : fv->sf->uni_interp ==
       ui_ams ? amspua : NULL;
    int i, cnt=0, gid;
-
    SplineChar dummy;
-
    const unichar_t *pt;
 
    for (i=0; i < fv->map->enccount; ++i)
@@ -313,7 +297,6 @@ void FVBuildDuplicate(FontViewBase * fv) {
    for (i=0; i < fv->map->enccount; ++i)
       if (fv->selected[i]) {
 	 SplineChar *sc;
-
 	 int baseuni=0;
 
 	 if ((gid=fv->map->map[i])==-1
@@ -334,7 +317,7 @@ void FVBuildDuplicate(FontViewBase * fv) {
       }
 }
 
-void TransHints(StemInfo * stem, real mul1, real off1, real mul2, real off2,
+void TransHints(StemInfo * stem, double mul1, double off1, double mul2, double off2,
 		int round_to_int) {
    HintInstance *hi;
 
@@ -367,8 +350,8 @@ void TransHints(StemInfo * stem, real mul1, real off1, real mul2, real off2,
 }
 
 /* added by akryukov 01/01/2008 to enable resizing and flipping DStem hints */
-void TransDStemHints(DStemInfo * ds, real xmul, real xoff, real ymul,
-		     real yoff, int round_to_int) {
+void TransDStemHints(DStemInfo * ds, double xmul, double xoff, double ymul,
+		     double yoff, int round_to_int) {
    HintInstance *hi;
    double dmul, temp;
 
@@ -407,7 +390,7 @@ void TransDStemHints(DStemInfo * ds, real xmul, real xoff, real ymul,
    }
 }
 
-void VrTrans(struct vr *vr, real transform[6]) {
+void VrTrans(struct vr *vr, double transform[6]) {
    /* I'm interested in scaling and skewing. I think translation should */
    /*  not affect these guys (they are offsets, so offsets should be */
    /*  unchanged by translation */
@@ -424,7 +407,7 @@ void VrTrans(struct vr *vr, real transform[6]) {
 }
 
 void BackgroundImageTransform(SplineChar * sc, ImageList * img,
-			      real transform[6]) {
+			      double transform[6]) {
    if (transform[1]==0 && transform[2]==0 && transform[0] > 0
        && transform[3] > 0) {
       img->xoff=transform[0] * img->xoff + transform[4];
@@ -443,7 +426,7 @@ void BackgroundImageTransform(SplineChar * sc, ImageList * img,
    }
 }
 
-static void GV_Trans(struct glyphvariants *gv,real transform[6],int is_v) {
+static void GV_Trans(struct glyphvariants *gv,double transform[6],int is_v) {
    int i;
 
    if (gv==NULL)
@@ -460,7 +443,7 @@ static void GV_Trans(struct glyphvariants *gv,real transform[6],int is_v) {
    }
 }
 
-static void MKV_Trans(struct mathkernvertex *mkv,real transform[6]) {
+static void MKV_Trans(struct mathkernvertex *mkv,double transform[6]) {
    int i;
 
    for (i=0; i < mkv->cnt; ++i) {
@@ -469,7 +452,7 @@ static void MKV_Trans(struct mathkernvertex *mkv,real transform[6]) {
    }
 }
 
-static void MK_Trans(struct mathkern *mk,real transform[6]) {
+static void MK_Trans(struct mathkern *mk,double transform[6]) {
    if (mk==NULL)
       return;
    MKV_Trans(&mk->top_right, transform);
@@ -478,7 +461,7 @@ static void MK_Trans(struct mathkern *mk,real transform[6]) {
    MKV_Trans(&mk->bottom_left, transform);
 }
 
-static void MATH_Trans(struct MATH *math,real transform[6]) {
+static void MATH_Trans(struct MATH *math,double transform[6]) {
    if (math==NULL)
       return;
    math->DelimitedSubFormulaMinHeight =
@@ -596,13 +579,10 @@ static void KCTrans(KernClass *kc,double scale) {
 }
 
 static void SCTransLayer(FontViewBase *fv,SplineChar *sc,int flags,int i,
-			 real transform[6], uint8_t * sel) {
+			 double transform[6], uint8_t * sel) {
    int j;
-
    RefChar *refs;
-
-   real t[6];
-
+   double t[6];
    ImageList *img;
 
    SplinePointListTransform(sc->layers[i].splines, transform, tpt_AllPoints);
@@ -669,19 +649,15 @@ static void SCTransLayer(FontViewBase *fv,SplineChar *sc,int flags,int i,
 /*  of the reference */
 /* If sel is NULL then we transform the reference */
 /* if flags&fvt_partialreftrans then we always just transform the offsets */
-void FVTrans(FontViewBase * fv, SplineChar * sc, real transform[6],
+void FVTrans(FontViewBase * fv, SplineChar * sc, double transform[6],
 	     uint8_t * sel, enum fvtrans_flags flags) {
    AnchorPoint *ap;
-
    int i, first, last;
-
    KernPair *kp;
-
    PST *pst;
 
    if (sc->blended) {
       int j;
-
       MMSet *mm=sc->parent->mm;
 
       for (j=0; j < mm->instance_count; ++j)
@@ -779,18 +755,13 @@ void FVTrans(FontViewBase * fv, SplineChar * sc, real transform[6],
    SCCharChangedUpdate(sc, fv->active_layer, true);
 }
 
-void FVTransFunc(void *_fv, real transform[6], int otype, BVTFunc * bvts,
+void FVTransFunc(void *_fv, double transform[6], int otype, BVTFunc * bvts,
 		 enum fvtrans_flags flags) {
    FontViewBase *fv=_fv;
-
-   real transx=transform[4], transy=transform[5];
-
+   double transx=transform[4], transy=transform[5];
    DBounds bb;
-
    BasePoint base;
-
    int i, cnt=0, gid;
-
    BDFFont *bdf;
 
    for (i=0; i < fv->map->enccount; ++i)
@@ -837,7 +808,6 @@ void FVTransFunc(void *_fv, real transform[6], int otype, BVTFunc * bvts,
 
    if (flags & fvt_scalekernclasses) {
       KernClass *kc;
-
       SplineFont *sf=fv->cidmaster != NULL ? fv->cidmaster : fv->sf;
 
       for (kc=sf->kerns; kc != NULL; kc=kc->next)
@@ -851,7 +821,6 @@ void FVTransFunc(void *_fv, real transform[6], int otype, BVTFunc * bvts,
 
 void FVOverlap(FontViewBase * fv, enum overlap_type ot) {
    int i, cnt=0, layer, first, last, gid;
-
    SplineChar *sc;
 
    for (i=0; i < fv->map->enccount; ++i)
@@ -882,11 +851,8 @@ void FVOverlap(FontViewBase * fv, enum overlap_type ot) {
 
 void FVAddExtrema(FontViewBase * fv, int force_adding) {
    int i, cnt=0, layer, first, last, gid;
-
    SplineChar *sc;
-
    SplineFont *sf=fv->sf;
-
    int emsize=sf->ascent + sf->descent;
 
    for (i=0; i < fv->map->enccount; ++i)
@@ -917,7 +883,6 @@ void FVAddExtrema(FontViewBase * fv, int force_adding) {
 
 void _FVSimplify(FontViewBase * fv, struct simplifyinfo *smpl) {
    int i, cnt=0, layer, first, last, gid;
-
    SplineChar *sc;
 
    for (i=0; i < fv->map->enccount; ++i)
@@ -946,9 +911,7 @@ void _FVSimplify(FontViewBase * fv, struct simplifyinfo *smpl) {
 
 void FVAutoHint(FontViewBase * fv) {
    int i, cnt=0, gid;
-
    BlueData *bd=NULL, _bd;
-
    SplineChar *sc;
 
    if (fv->sf->mm==NULL) {
@@ -1032,9 +995,7 @@ void FVDontAutoHint(FontViewBase * fv) {
 
 static int AllGlyphsSelected(FontViewBase *fv) {
    SplineFont *sf=fv->sf;
-
    int gid, enc;
-
    SplineChar *sc;
 
    for (gid=0; gid < sf->glyphcnt; ++gid)
@@ -1075,9 +1036,7 @@ static void ClearFpgmPrepCvt(SplineFont *sf) {
 
 void FVAutoInstr(FontViewBase * fv) {
    BlueData bd;
-
    int i, cnt=0, gid;
-
    GlobalInstrCt gic;
 
    /* If all glyphs are selected, then no legacy hint will remain after */
@@ -1110,7 +1069,6 @@ void FVAutoInstr(FontViewBase * fv) {
 
 void FVClearInstrs(FontViewBase * fv) {
    SplineChar *sc;
-
    int i, gid;
 
    for (i=0; i < fv->map->enccount; ++i)
@@ -1144,38 +1102,34 @@ void FVClearHints(FontViewBase * fv) {
 
 static int tester(SplineChar *sc,struct lookup_subtable *sub) {
    PST *pst;
-
    KernPair *kp;
-
    int isv;
-
    AnchorPoint *ap;
 
    if (sc==NULL)
-      return (false);
+      return false;
 
-   for (ap=sc->anchor; ap != NULL; ap=ap->next)
+   for (ap=sc->anchor;ap!=NULL;ap=ap->next)
       if (ap->anchor->subtable==sub)
-	 return (true);
-   for (pst=sc->possub; pst != NULL; pst=pst->next)
+	 return true;
+   for (pst=sc->possub;pst!=NULL;pst=pst->next)
       if (pst->subtable==sub)
-	 return (true);
-   for (isv=0; isv < 2; ++isv)
-      for (kp=isv ? sc->vkerns : sc->kerns; kp != NULL; kp=kp->next)
-	 if (kp->subtable==sub)
-	    return (true);
+	 return true;
+   for (kp=sc->kerns;kp!=NULL;kp=kp->next)
+     if (kp->subtable==sub)
+       return true;
+   for (kp=sc->vkerns;kp!=NULL;kp=kp->next)
+     if (kp->subtable==sub)
+       return true;
 
-   return (false);
+   return false;
 }
 
 int FVBParseSelectByPST(FontViewBase * fv, struct lookup_subtable *sub,
 			int search_type) {
    int i;
-
    SplineFont *sf;
-
    int first;
-
    int gid;
 
    sf=fv->sf;
@@ -1211,9 +1165,7 @@ int FVBParseSelectByPST(FontViewBase * fv, struct lookup_subtable *sub,
 
 void FVBuildAccent(FontViewBase * fv, int onlyaccents) {
    int i, cnt=0, gid;
-
    SplineChar dummy;
-
    SplineChar *sc;
 
    for (i=0; i < fv->map->enccount; ++i)
@@ -1237,19 +1189,16 @@ void FVBuildAccent(FontViewBase * fv, int onlyaccents) {
 	     (fv->sf, sc, fv->active_layer, onlyaccents)) {
 	    sc=SFMakeChar(fv->sf, fv->map, i);
 	    sc->ticked=true;
-	    SCBuildComposit(fv->sf, sc, fv->active_layer, fv->active_bitmap,
-			    onlycopydisplayed);
+	    SCBuildComposite(fv->sf, sc, fv->active_layer, fv->active_bitmap,
+			     onlycopydisplayed);
 	 }
       }
 }
 
 void FVDetachGlyphs(FontViewBase * fv) {
    int i, j, gid;
-
    EncMap *map=fv->map;
-
    int altered=false;
-
    SplineFont *sf=fv->sf;
 
    for (i=0; i < map->enccount; ++i)
@@ -1268,15 +1217,10 @@ void FVDetachGlyphs(FontViewBase * fv) {
 
 void FVDetachAndRemoveGlyphs(FontViewBase * fv) {
    int i, j, gid;
-
    EncMap *map=fv->map;
-
    SplineFont *sf=fv->sf;
-
    int flags=-1;
-
    int changed=false, altered=false;
-
    FontViewBase *fvs;
 
    for (i=0; i < map->enccount; ++i)
@@ -1305,7 +1249,7 @@ void FVMetricsCenter(FontViewBase * fv, int docenter) {
    SplineChar *sc;
    DBounds bb;
    IBounds ib;
-   real transform[6], itransform[6];
+   double transform[6], itransform[6];
    BVTFunc bvts[2];
    BDFFont *bdf;
 
@@ -1487,7 +1431,6 @@ void FVRevertBackup(FontViewBase * fv) {
 
 FontViewBase *_FontViewCreate(SplineFont *sf) {
    FontViewBase *fv=calloc(1, sizeof(FontViewBase));
-
    int i;
 
    fv->nextsame=sf->fv;
