@@ -1,4 +1,4 @@
-/* $Id: freetype.c 4020 2015-06-14 18:15:09Z mskala $ */
+/* $Id: freetype.c 4464 2015-11-30 09:57:27Z mskala $ */
 /* Copyright (C) 2000-2012  George Williams
  * Copyright (C) 2015  Matthew Skala
  *
@@ -82,13 +82,13 @@ void FreeTypeFreeContext(void *freetypecontext) {
 }
 
 struct freetype_raster *FreeType_GetRaster(void *single_glyph_context,
-					   int enc, real ptsizey,
-					   real ptsizex, int dpi, int depth) {
+					   int enc, double ptsizey,
+					   double ptsizex, int dpi, int depth) {
    return (NULL);
 }
 
 SplineSet *FreeType_GridFitChar(void *single_glyph_context,
-				int enc, real ptsizey, real ptsizex, int dpi,
+				int enc, double ptsizey, double ptsizex, int dpi,
 				uint16_t * width, SplineChar * sc, int depth,
 				int scaled) {
    return (NULL);
@@ -105,7 +105,6 @@ FT_Library ff_ft_context;
 
 int hasFreeType(void) {
    static int done=false;
-
    static int ok=false;
 
    if (done)
@@ -181,7 +180,6 @@ static int FreeTypeAtLeast(int major,int minor,int patch) {
 
 static char *FreeTypeStringVersion(void) {
    int ma, mi, pa;
-
    static char buffer[60];
 
    if (!hasFreeType())
@@ -317,7 +315,7 @@ void *_FreeTypeFontContext(SplineFont *sf, SplineChar * sc,
 	     && autohint_before_generate) {
 	    extern int preserve_hint_undoes;	/* users don't expect that rasterizing the glyph will cause an undo */
 	    int phu=preserve_hint_undoes;	/* if metrics view & char view are open, and a change is made in */
-	    
+
 	    /*  the char view, then metrics view rasterize glyph, changes hints, */
 	    /*  adds a hint undo. And suddenly Undo does the wrong thing. It */
 	    /*  undoes the hint change (which the user probably hasn't noticed) */
@@ -431,7 +429,6 @@ void *_FreeTypeFontContext(SplineFont *sf, SplineChar * sc,
 
 static void BCTruncateToDepth(BDFChar *bdfc,int depth) {
    int div=255 / ((1 << depth) - 1);
-
    int i, j;
 
    for (i=0; i <= bdfc->ymax - bdfc->ymin; ++i) {
@@ -461,10 +458,10 @@ static BDFChar *BdfCFromBitmap(FT_Bitmap *bitmap,int bitmap_left,
    if (sc != NULL) {
       bdfc->width =
 	 rint(sc->width * pixelsize /
-	      (real) (sc->parent->ascent + sc->parent->descent));
+	      (double) (sc->parent->ascent + sc->parent->descent));
       bdfc->vwidth =
 	 rint(sc->vwidth * pixelsize /
-	      (real) (sc->parent->ascent + sc->parent->descent));
+	      (double) (sc->parent->ascent + sc->parent->descent));
       bdfc->orig_pos=sc->orig_pos;
    }
    if (metrics != NULL) {
@@ -506,13 +503,9 @@ static BDFChar *BDFCReClut(BDFChar *bdfc) {
 BDFChar *SplineCharFreeTypeRasterize(void *freetypecontext, int gid,
 				     int ptsize, int dpi, int depth) {
    FTC *ftc=freetypecontext;
-
    BDFChar *bdfc;
-
    SplineChar *sc;
-
    FT_GlyphSlot slot;
-
    int pixelsize=(int) rint((ptsize * dpi) / 72.0);
 
    if (ftc->glyph_indices[gid]==-1)
@@ -546,11 +539,8 @@ BDFChar *SplineCharFreeTypeRasterize(void *freetypecontext, int gid,
 BDFFont *SplineFontFreeTypeRasterize(void *freetypecontext, int pixelsize,
 				     int depth) {
    FTC *ftc=freetypecontext, *subftc=NULL;
-
    SplineFont *sf=ftc->sf, *subsf;
-
    int i, k;
-
    BDFFont *bdf=SplineFontToBDFHeader(sf, pixelsize, true);
 
    if (depth != 1)
@@ -668,7 +658,6 @@ static int FT_LineTo(const FT_Vector *to,void *user) {
 static int FT_LineTo(FT_Vector *to,void *user) {
 #   endif
    struct ft_context *context=user;
-
    SplinePoint *sp;
 
    sp=SplinePointCreate(to->x * context->scalex, to->y * context->scaley);
@@ -692,7 +681,6 @@ static int FT_ConicTo(const FT_Vector *_cp,const FT_Vector *to,void *user) {
 static int FT_ConicTo(FT_Vector *_cp,FT_Vector *to,void *user) {
 #   endif
    struct ft_context *context=user;
-
    SplinePoint *sp;
 
    sp=SplinePointCreate(to->x * context->scalex, to->y * context->scaley);
@@ -724,7 +712,6 @@ static int FT_CubicTo(FT_Vector *cp1,FT_Vector *cp2,FT_Vector *to,
 		      void *user) {
 #   endif
    struct ft_context *context=user;
-
    SplinePoint *sp;
 
    sp=SplinePointCreate(to->x * context->scalex, to->y * context->scaley);
@@ -753,15 +740,12 @@ static FT_Outline_Funcs outlinefuncs={
 };
 
 SplineSet *FreeType_GridFitChar(void *single_glyph_context, int enc,
-				real ptsizey, real ptsizex, int dpi,
+				double ptsizey, double ptsizex, int dpi,
 				uint16_t * width, SplineChar * sc, int depth,
 				int scaled) {
    FT_GlyphSlot slot;
-
    FTC *ftc=(FTC *) single_glyph_context;
-
    struct ft_context outline_context;
-
    static int bc_checked=false;
 
    if (ftc->face==(void *) -1)
@@ -819,12 +803,10 @@ SplineSet *FreeType_GridFitChar(void *single_glyph_context, int enc,
 }
 
 struct freetype_raster *FreeType_GetRaster(void *single_glyph_context,
-					   int enc, real ptsizey,
-					   real ptsizex, int dpi, int depth) {
+					   int enc, double ptsizey,
+					   double ptsizex, int dpi, int depth) {
    FT_GlyphSlot slot;
-
    struct freetype_raster *ret;
-
    FTC *ftc=(FTC *) single_glyph_context;
 
    if (ftc->face==(void *) -1)
@@ -865,14 +847,11 @@ struct freetype_raster *FreeType_GetRaster(void *single_glyph_context,
 }
 
 static void FillOutline(SplineSet *spl,FT_Outline *outline,int *pmax,
-			int *cmax, real scale, DBounds * bb, int order2,
+			int *cmax, double scale, DBounds * bb, int order2,
 			int ignore_clip) {
    int k;
-
    int pcnt, ccnt;
-
    SplinePoint *sp;
-
    SplineSet *ss;
 
    if (order2) {
@@ -995,7 +974,6 @@ static void FillOutline(SplineSet *spl,FT_Outline *outline,int *pmax,
 
 static SplineSet *LayerAllOutlines(Layer *layer) {
    SplineSet *head, *last, *cur;
-
    RefChar *r;
 
    if (layer->refs==NULL)
@@ -1020,9 +998,7 @@ static SplineSet *LayerAllOutlines(Layer *layer) {
 
 static SplineSet *StrokeOutline(Layer *layer,SplineChar *sc) {
    StrokeInfo si;
-
    RefChar *r;
-
    SplineSet *head=NULL, *tail=NULL, *c;
 
    memset(&si, 0, sizeof(si));
@@ -1071,7 +1047,6 @@ static void MergeBitmaps(FT_Bitmap *bitmap,FT_Bitmap *newstuff,
 			 struct brush *brush, uint8_t * clipmask, double scale,
 			 DBounds * bbox, SplineChar * sc) {
    int i, j;
-
    uint32_t col=brush->col;
 
    if (col==COLOR_INHERITED)
@@ -1137,24 +1112,16 @@ static void MergeBitmaps(FT_Bitmap *bitmap,FT_Bitmap *newstuff,
 BDFChar *SplineCharFreeTypeRasterizeNoHints(SplineChar * sc, int layer,
 					    int ptsize, int dpi, int depth) {
    FT_Outline outline;
-
    FT_Bitmap bitmap, temp;
-
    int i;
-
    int cmax, pmax;
-
-   real rscale =
+   double rscale =
       (ptsize * dpi) / 72.0 / (double) (sc->parent->ascent +
 					sc->parent->descent);
-   real scale=rscale * (1 << 6);
-
+   double scale=rscale * (1 << 6);
    BDFChar *bdfc;
-
    int err=0;
-
    DBounds b;
-
    SplineSet *all;
 
    if (!hasFreeType())
@@ -1237,7 +1204,6 @@ BDFChar *SplineCharFreeTypeRasterizeNoHints(SplineChar * sc, int layer,
 	 SplinePointListsFree(all);
    } else {
       int j;
-
       RefChar *r;
 
       /* Can only get here if multilayer */
