@@ -1,4 +1,4 @@
-/* $Id: fvfonts.c 4064 2015-06-25 14:15:40Z mskala $ */
+/* $Id: fvfonts.c 4464 2015-11-30 09:57:27Z mskala $ */
 /* Copyright (C) 2000-2012  George Williams
  * Copyright (C) 2015  Matthew Skala
  *
@@ -118,10 +118,9 @@ struct lookup_subtable *MCConvertSubtable(struct sfmergecontext *mc,
       mc->prefix=strconcat(mc->sf_from->fontname, "-");
       for (doit=0; doit < 2; ++doit) {
 	 lcnt=scnt=0;
-	 for (isgpos=0; isgpos < 2; ++isgpos) {
-	    for (otl =
-		 isgpos ? mc->sf_from->gpos_lookups : mc->sf_from->
-		 gsub_lookups; otl != NULL; otl=otl->next) {
+	 for (isgpos=0; isgpos < 2; isgpos++) {
+	    for (otl=mc->sf_from->gsplookups[isgpos];otl!=NULL;
+		 otl=otl->next) {
 	       if (doit) {
 		  mc->lks[lcnt].from=otl;
 		  temp=strconcat(mc->prefix, otl->lookup_name);
@@ -263,17 +262,15 @@ void SFFinishMergeContext(struct sfmergecontext *mc) {
       otl=mc->lks[l].to;
       isgpos=(otl->lookup_type >= gpos_start);
       if (last==NULL || (last->lookup_type >= gpos_start) != isgpos) {
-	 last=isgpos ? mc->sf_to->gpos_lookups : mc->sf_to->gsub_lookups;
+	 last=mc->sf_to->gsplookups[isgpos];
 	 if (last != NULL)
 	    while (last->next != NULL)
 	       last=last->next;
       }
       if (last != NULL)
 	 last->next=otl;
-      else if (isgpos)
-	 mc->sf_to->gpos_lookups=otl;
       else
-	 mc->sf_to->gsub_lookups=otl;
+	 mc->sf_to->gsplookups[isgpos]=otl;
       last=otl;
    }
 
@@ -709,7 +706,6 @@ static void GlyphHashCreate(SplineFont *sf) {
 void SFHashGlyph(SplineFont *sf, SplineChar * sc) {
    /* sc just got added to the font. Put it in the lookup */
    int hash;
-
    struct glyphnamebucket *new;
 
    if (sf->glyphnames==NULL)
@@ -1014,8 +1010,7 @@ static void MFixupSC(SplineFont *sf,SplineChar *sc,int i) {
    sc->orig_pos=i;
    sc->parent=sf;
    sc->ticked=true;
-   for (l=0; l < sc->layer_cnt; ++l) {
-    retry:
+   for (l=0; l < sc->layer_cnt; l++) {
       for (ref=sc->layers[l].refs; ref != NULL; ref=ref->next) {
 	 /* The sc in the ref is from the old font. It's got to be in the */
 	 /*  new font too (was either already there or just got copied) */
@@ -1025,7 +1020,8 @@ static void MFixupSC(SplineFont *sf,SplineChar *sc,int i) {
 	    ErrorMsg(2,"Bad reference, can't fix it up\n");
 	    if (ref==sc->layers[l].refs) {
 	       sc->layers[l].refs=ref->next;
-	       goto retry;
+	       l--; /* take another look at this layer */
+	       break;
 	    } else {
 	       for (prev=sc->layers[l].refs; prev->next != ref;
 		    prev=prev->next);
@@ -1037,7 +1033,7 @@ static void MFixupSC(SplineFont *sf,SplineChar *sc,int i) {
 	    ref->sc=sf->glyphs[ref->orig_pos];
 	    if (!ref->sc->ticked)
 	       MFixupSC(sf, ref->sc, ref->orig_pos);
-	    SCReinstanciateRefChar(sc, ref, l);
+	    SCReinstantiateRefChar(sc, ref, l);
 	    SCMakeDependent(sc, ref->sc);
 	 }
       }
@@ -1327,7 +1323,7 @@ void MergeFont(FontViewBase * fv, SplineFont *other,
 /* *************************** Font Interpolation *************************** */
 /******************************************************************************/
 
-static RefChar *InterpRefs(RefChar *base,RefChar *other,real amount,
+static RefChar *InterpRefs(RefChar *base,RefChar *other,double amount,
 			   SplineChar * sc) {
    RefChar *head=NULL, *last=NULL, *cur;
    RefChar *test;
@@ -1374,10 +1370,10 @@ static RefChar *InterpRefs(RefChar *base,RefChar *other,real amount,
 }
 
 static void InterpPoint(SplineSet *cur,SplinePoint *base,
-			SplinePoint * other, real amount) {
+			SplinePoint * other, double amount) {
    SplinePoint *p=chunkalloc(sizeof(SplinePoint));
    int order2;
-   
+
    order2=
       base->prev != NULL ? base->prev->order2 : base->next !=
       NULL ? base->next->order2 : false;
@@ -1427,7 +1423,7 @@ static void InterpPoint(SplineSet *cur,SplinePoint *base,
 }
 
 static SplineSet *InterpSplineSet(SplineSet *base,SplineSet *other,
-				  real amount, SplineChar * sc) {
+				  double amount, SplineChar * sc) {
    SplineSet *cur=chunkalloc(sizeof(SplineSet));
    SplinePoint *bp, *op;
 
@@ -1480,7 +1476,7 @@ static SplineSet *InterpSplineSet(SplineSet *base,SplineSet *other,
 }
 
 SplineSet *SplineSetsInterpolate(SplineSet * base, SplineSet * other,
-				 real amount, SplineChar * sc) {
+				 double amount, SplineChar * sc) {
    SplineSet *head=NULL, *last=NULL, *cur;
 
    /* we could do something really complex to try and figure out which spline */
@@ -1507,7 +1503,7 @@ static int SCSameChar(SplineChar *sc1,SplineChar *sc2) {
    return (strcmp(sc1->name, sc2->name)==0);
 }
 
-static KernPair *InterpKerns(KernPair *kp1,KernPair *kp2,real amount,
+static KernPair *InterpKerns(KernPair *kp1,KernPair *kp2,double amount,
 			     SplineFont *new, SplineChar * scnew) {
    KernPair *head=NULL, *last, *nkp, *k;
 
@@ -1535,7 +1531,7 @@ static KernPair *InterpKerns(KernPair *kp1,KernPair *kp2,real amount,
    return (head);
 }
 
-static uint32_t InterpColor(uint32_t col1,uint32_t col2,real amount) {
+static uint32_t InterpColor(uint32_t col1,uint32_t col2,double amount) {
    int r1,g1,b1,r2,b2,g2;
 
    r1=(col1 >> 16) & 0xff;
@@ -1551,7 +1547,7 @@ static uint32_t InterpColor(uint32_t col1,uint32_t col2,real amount) {
 }
 
 static void LayerInterpolate(Layer *to,Layer *base,Layer *other,
-			     real amount, SplineChar * sc, int lc) {
+			     double amount, SplineChar * sc, int lc) {
    /* to already has things set to default values, so when an error occurs */
    /*  I just leave things as the default (and don't need to set it again) */
    if (base->dostroke==other->dostroke)
@@ -1647,7 +1643,7 @@ static void LayerInterpolate(Layer *to,Layer *base,Layer *other,
 }
 
 SplineChar *SplineCharInterpolate(SplineChar * base, SplineChar * other,
-				  real amount, SplineFont *newfont) {
+				  double amount, SplineFont *newfont) {
    SplineChar *sc;
    int i;
 
@@ -1705,7 +1701,7 @@ SplineChar *SplineCharInterpolate(SplineChar * base, SplineChar * other,
 
 static void _SplineCharInterpolate(SplineFont *new,int orig_pos,
 				   SplineChar * base, SplineChar * other,
-				   real amount) {
+				   double amount) {
    SplineChar *sc;
 
    sc=SplineCharInterpolate(base, other, amount, new);
@@ -1730,7 +1726,7 @@ static void IFixupSC(SplineFont *sf,SplineChar *sc,int i) {
 	    SFFindExistingSlot(sf, ref->sc->unicodeenc, ref->sc->name);
 	 ref->sc=sf->glyphs[ref->orig_pos];
 	 IFixupSC(sf, ref->sc, ref->orig_pos);
-	 SCReinstanciateRefChar(sc, ref, ly_fore);
+	 SCReinstantiateRefChar(sc, ref, ly_fore);
 	 SCMakeDependent(sc, ref->sc);
       }
 }
@@ -1745,7 +1741,7 @@ static void InterpFixupRefChars(SplineFont *sf) {
 }
 
 SplineFont *InterpolateFont(SplineFont *base, SplineFont *other,
-			    real amount, Encoding * enc) {
+			    double amount, Encoding * enc) {
    SplineFont *new;
    int i, index, lc;
 
