@@ -1,4 +1,4 @@
-/* $Id: mm.c 4064 2015-06-25 14:15:40Z mskala $ */
+/* $Id: mm.c 4464 2015-11-30 09:57:27Z mskala $ */
 /* Copyright (C) 2003-2012  George Williams
  * Copyright (C) 2015  Matthew Skala
  *
@@ -46,9 +46,8 @@ char *MMAxisAbrev(char *axis_name) {
    return (axis_name);
 }
 
-bigreal MMAxisUnmap(MMSet * mm, int axis, bigreal ncv) {
+double MMAxisUnmap(MMSet * mm, int axis, double ncv) {
    struct axismap *axismap=&mm->axismaps[axis];
-
    int j;
 
    if (ncv <= axismap->blends[0])
@@ -56,7 +55,7 @@ bigreal MMAxisUnmap(MMSet * mm, int axis, bigreal ncv) {
 
    for (j=1; j < axismap->points; ++j) {
       if (ncv <= axismap->blends[j]) {
-	 bigreal t =
+	 double t =
 	    (ncv - axismap->blends[j - 1]) / (axismap->blends[j] -
 					      axismap->blends[j - 1]);
 	 return (axismap->designs[j - 1] +
@@ -67,11 +66,9 @@ bigreal MMAxisUnmap(MMSet * mm, int axis, bigreal ncv) {
    return (axismap->designs[axismap->points - 1]);
 }
 
-static char *_MMMakeFontname(MMSet *mm,real *normalized,char **fullname) {
+static char *_MMMakeFontname(MMSet *mm,double *normalized,char **fullname) {
    char *pt, *pt2, *hyphen=NULL;
-
    char *ret=NULL;
-
    int i, j;
 
    if (mm->apple) {
@@ -151,12 +148,10 @@ char *MMMakeMasterFontname(MMSet * mm, int ipos, char **fullname) {
 	   (mm, &mm->positions[ipos * mm->axis_count], fullname));
 }
 
-static char *_MMGuessWeight(MMSet *mm,real *normalized,char *def) {
+static char *_MMGuessWeight(MMSet *mm,double *normalized,char *def) {
    int i;
-
    char *ret;
-
-   real design;
+   double design;
 
    for (i=0; i < mm->axis_count; ++i) {
       if (strcmp(mm->axes[i], "Weight")==0)
@@ -193,7 +188,6 @@ char *MMGuessWeight(MMSet * mm, int ipos, char *def) {
 /* Given a postscript array of scalars, what's the ipos'th element? */
 char *MMExtractNth(char *pt, int ipos) {
    int i;
-
    char *end;
 
    while (*pt==' ')
@@ -217,7 +211,6 @@ char *MMExtractNth(char *pt, int ipos) {
 /* return the array composed of the ipos'th element of each sub-array */
 char *MMExtractArrayNth(char *pt, int ipos) {
    char *hold[40], *ret;
-
    int i, j, len;
 
    while (*pt==' ')
@@ -266,9 +259,7 @@ char *MMExtractArrayNth(char *pt, int ipos) {
 void MMKern(SplineFont *sf, SplineChar * first, SplineChar * second,
 	    int diff, struct lookup_subtable *sub, KernPair * oldkp) {
    MMSet *mm=sf->mm;
-
    KernPair *kp;
-
    int i;
 
    /* If the user creates a kern pair in one font of a multiple master set */
@@ -281,7 +272,6 @@ void MMKern(SplineFont *sf, SplineChar * first, SplineChar * second,
    if (sf==mm->normal || oldkp==NULL) {
       for (i=-1; i < mm->instance_count; ++i) {
 	 SplineFont *cur=i==-1 ? mm->normal : mm->instances[i];
-
 	 SplineChar *psc, *ssc;
 
 	 if (cur==sf)		/* Done in caller */
@@ -332,42 +322,30 @@ static SplineChar *SFMakeGlyphLike(SplineFont *sf,int gid,
 
 static char *_MMBlendChar(MMSet *mm,int gid) {
    int i, j, worthit=-1;
-
    int all, any, any2, all2, anyend, allend, diff;
-
    SplineChar *sc;
-
    SplinePointList *spls[MmMax], *spl, *spllast;
-
    SplinePoint *tos[MmMax], *to;
-
    RefChar *refs[MmMax], *ref, *reflast;
-
    KernPair *kp0, *kptest, *kp, *kplast;
-
    StemInfo *hs[MmMax], *h, *hlast;
-
-   real width;
+   double width;
 
    for (i=0; i < mm->instance_count; ++i) {
       if (mm->instances[i]->layers[ly_fore].order2)
-	 return (_
-		 ("One of the multiple master instances contains quadratic splines. It must be converted to cubic splines before it can be used in a multiple master"));
+	 return "One of the multiple master instances contains quadratic splines. It must be converted to cubic splines before it can be used in a multiple master";
       if (gid >= mm->instances[i]->glyphcnt)
-	 return (_
-		 ("The different instances of this mm have a different number of glyphs"));
+	 return "The different instances of this mm have a different number of glyphs";
       if (SCWorthOutputting(mm->instances[i]->glyphs[gid])) {
 	 if (worthit==-1)
 	    worthit=true;
 	 else if (worthit != true)
-	    return (_
-		    ("This glyph is defined in one instance font but not in another"));
+	    return "This glyph is defined in one instance font but not in another";
       } else {
 	 if (worthit==-1)
 	    worthit=false;
 	 else if (worthit != false)
-	    return (_
-		    ("This glyph is defined in one instance font but not in another"));
+	    return "This glyph is defined in one instance font but not in another";
       }
    }
 
@@ -427,11 +405,9 @@ static char *_MMBlendChar(MMSet *mm,int gid) {
       }
    }
    if (any)
-      return (_
-	      ("This glyph contains a different number of references in different instances"));
+      return "This glyph contains a different number of references in different instances";
    if (diff)
-      return (_
-	      ("A reference in this glyph refers to a different encoding in different instances"));
+      return "A reference in this glyph refers to a different encoding in different instances";
 
    /* Blend Width */
    width=0;
@@ -502,8 +478,7 @@ static char *_MMBlendChar(MMSet *mm,int gid) {
 	       all2=false;
 	 }
 	 if (!all2 && any2)
-	    return (_
-		    ("A contour in this glyph contains a different number of points in different instances"));
+	    return "A contour in this glyph contains a different number of points in different instances";
 	 anyend=false;
 	 allend=true;
 	 for (i=0; i < mm->instance_count; ++i) {
@@ -518,8 +493,7 @@ static char *_MMBlendChar(MMSet *mm,int gid) {
 	    break;
 	 }
 	 if (anyend)
-	    return (_
-		    ("A contour in this glyph contains a different number of points in different instances"));
+	    return "A contour in this glyph contains a different number of points in different instances";
       }
       any=false;
       all=true;
@@ -532,8 +506,7 @@ static char *_MMBlendChar(MMSet *mm,int gid) {
       }
    }
    if (any)
-      return (_
-	      ("This glyph contains a different number of contours in different instances"));
+      return "This glyph contains a different number of contours in different instances";
 
    /* Blend hints */
    for (j=0; j < 2; ++j) {
@@ -577,8 +550,7 @@ static char *_MMBlendChar(MMSet *mm,int gid) {
 	 }
       }
       if (any)
-	 return (_
-		 ("This glyph contains a different number of hints in different instances"));
+	 return "This glyph contains a different number of hints in different instances";
    }
 
    /* Blend kernpairs */
@@ -595,8 +567,7 @@ static char *_MMBlendChar(MMSet *mm,int gid) {
 	    if (kptest->sc->orig_pos==kp0->sc->orig_pos)
 	       break;
 	 if (kptest==NULL)
-	    return (_
-		    ("This glyph contains different kerning pairs in different instances"));
+	    return "This glyph contains different kerning pairs in different instances";
 	 off += kptest->off * mm->defweights[i];
       }
       kp=chunkalloc(sizeof(KernPair));
@@ -615,18 +586,16 @@ static char *_MMBlendChar(MMSet *mm,int gid) {
 
 char *MMBlendChar(MMSet * mm, int gid) {
    char *ret;
-
    RefChar *ref;
 
    if (gid >= mm->normal->glyphcnt)
-      return (_
-	      ("The different instances of this mm have a different number of glyphs"));
+      return "The different instances of this mm have a different number of glyphs";
    ret=_MMBlendChar(mm, gid);
    if (mm->normal->glyphs[gid] != NULL) {
       SplineChar *sc=mm->normal->glyphs[gid];
 
       for (ref=sc->layers[ly_fore].refs; ref != NULL; ref=ref->next) {
-	 SCReinstanciateRefChar(sc, ref, ly_fore);
+	 SCReinstantiateRefChar(sc, ref, ly_fore);
 	 SCMakeDependent(sc, ref->sc);
       }
    }
@@ -635,13 +604,9 @@ char *MMBlendChar(MMSet * mm, int gid) {
 
 static struct psdict *BlendPrivate(struct psdict *private,MMSet *mm) {
    struct psdict *other;
-
-   real sum, val;
-
+   double sum, val;
    char *data;
-
    int i, j, k, cnt;
-
    char *values[MmMax], buffer[32], *space, *pt, *end;
 
    other=mm->instances[0]->private;
@@ -730,11 +695,8 @@ static struct psdict *BlendPrivate(struct psdict *private,MMSet *mm) {
 
 int MMReblend(FontViewBase * fv, MMSet * mm) {
    char *olderr, *err;
-
    int i, first=-1;
-
    SplineFont *sf=mm->instances[0];
-
    RefChar *ref;
 
    olderr=NULL;
@@ -768,7 +730,7 @@ int MMReblend(FontViewBase * fv, MMSet * mm) {
       if (sf->glyphs[i] != NULL) {
 	 for (ref=sf->glyphs[i]->layers[ly_fore].refs; ref != NULL;
 	      ref=ref->next) {
-	    SCReinstanciateRefChar(sf->glyphs[i], ref, ly_fore);
+	    SCReinstantiateRefChar(sf->glyphs[i], ref, ly_fore);
 	    SCMakeDependent(sf->glyphs[i], ref->sc);
 	 }
       }
@@ -787,7 +749,7 @@ int MMReblend(FontViewBase * fv, MMSet * mm) {
    return (false);
 }
 
-void MMWeightsUnMap(real weights[MmMax], real axiscoords[4], int axis_count) {
+void MMWeightsUnMap(double weights[MmMax], double axiscoords[4], int axis_count) {
 
    if (axis_count==1)
       axiscoords[0]=weights[1];
@@ -811,11 +773,9 @@ void MMWeightsUnMap(real weights[MmMax], real axiscoords[4], int axis_count) {
 }
 
 SplineFont *_MMNewFont(MMSet * mm, int index, char *familyname,
-		       real * normalized) {
+		       double * normalized) {
    SplineFont *sf, *base;
-
    char *pt1, *pt2;
-
    int i;
 
    sf=SplineFontNew();
@@ -879,14 +839,11 @@ SplineFont *MMNewFont(MMSet * mm, int index, char *familyname) {
 }
 
 FontViewBase *MMCreateBlendedFont(MMSet * mm, FontViewBase * fv,
-				  real blends[MmMax], int tonew) {
-   real oldblends[MmMax];
-
+				  double blends[MmMax], int tonew) {
+   double oldblends[MmMax];
    SplineFont *hold=mm->normal;
-
    int i;
-
-   real axispos[4];
+   double axispos[4];
 
    for (i=0; i < mm->instance_count; ++i) {
       oldblends[i]=mm->defweights[i];
@@ -931,7 +888,6 @@ FontViewBase *MMCreateBlendedFont(MMSet * mm, FontViewBase * fv,
 
 static int ContourCount(SplineChar *sc) {
    SplineSet *spl;
-
    int i;
 
    for (spl=sc->layers[ly_fore].splines, i=0; spl != NULL;
@@ -941,7 +897,6 @@ static int ContourCount(SplineChar *sc) {
 
 static int ContourPtMatch(SplineChar *sc1,SplineChar *sc2) {
    SplineSet *spl1, *spl2;
-
    SplinePoint *sp1, *sp2;
 
    for (spl1=sc1->layers[ly_fore].splines, spl2 =
@@ -982,7 +937,6 @@ static int ContourDirMatch(SplineChar *sc1,SplineChar *sc2) {
 
 static int ContourHintMaskMatch(SplineChar *sc1,SplineChar *sc2) {
    SplineSet *spl1, *spl2;
-
    SplinePoint *sp1, *sp2;
 
    for (spl1=sc1->layers[ly_fore].splines, spl2 =
@@ -1040,7 +994,6 @@ static int RefTransformsMatch(SplineChar *sc1,SplineChar *sc2) {
    /*  so if rotation, skewing, scaling, etc. differ then we can't deal with */
    /*  it. */
    RefChar *r1=sc1->layers[ly_fore].refs;
-
    RefChar *r2=sc2->layers[ly_fore].refs;
 
    while (r1 != NULL && r2 != NULL) {
@@ -1089,7 +1042,6 @@ static int KernsMatch(SplineChar *sc1,SplineChar *sc2) {
 
 static int ArrayCount(char *val) {
    char *end;
-
    int cnt;
 
    if (val==NULL)
@@ -1111,7 +1063,6 @@ static int ArrayCount(char *val) {
 
 int MMValid(MMSet * mm, int complain) {
    int i, j;
-
    SplineFont *sf;
    static char *arrnames[] =
       { "BlueValues", "OtherBlues", "FamilyBlues", "FamilyOtherBlues",
