@@ -1,4 +1,4 @@
-/* $Id: nonlineartrans.c 4020 2015-06-14 18:15:09Z mskala $ */
+/* $Id: nonlineartrans.c 4464 2015-11-30 09:57:27Z mskala $ */
 /* Copyright (C) 2003-2012  George Williams
  * Copyright (C) 2015  Matthew Skala
  *
@@ -65,11 +65,9 @@ void nlt_exprfree(struct expr *e) {
    chunkfree(e, sizeof(*e));
 }
 
-static int gettoken(struct context *c,real *val) {
+static int gettoken(struct context *c,double *val) {
    int ch, i;
-
    char *end, *pt;
-
    char buffer[40];
 
    if (c->backed_token != op_base) {
@@ -184,7 +182,7 @@ static int gettoken(struct context *c,real *val) {
       }
 }
 
-static void backup(struct context *c,enum operator  op,real val) {
+static void backup(struct context *c,enum operator  op,double val) {
    if (c->backed_token != op_base) {
       ErrorMsg(2,"Attempt to back up twice.\nnear ...%s\n", c->cur);
       c->had_error=true;
@@ -197,10 +195,8 @@ static void backup(struct context *c,enum operator  op,real val) {
 static struct expr *getexpr(struct context *c);
 
 static struct expr *gete0(struct context *c) {
-   real val=0;
-
+   double val=0;
    enum operator  op=gettoken(c, &val);
-
    struct expr *ret;
 
    switch (op) {
@@ -275,10 +271,8 @@ static struct expr *gete0(struct context *c) {
 }
 
 static struct expr *gete1(struct context *c) {
-   real val=0;
-
+   double val=0;
    enum operator  op;
-
    struct expr *ret, *op1;
 
    op1=gete0(c);
@@ -296,10 +290,8 @@ static struct expr *gete1(struct context *c) {
 }
 
 static struct expr *gete2(struct context *c) {
-   real val=0;
-
+   double val=0;
    enum operator  op;
-
    struct expr *ret, *op1;
 
    op1=gete1(c);
@@ -317,10 +309,8 @@ static struct expr *gete2(struct context *c) {
 }
 
 static struct expr *gete3(struct context *c) {
-   real val=0;
-
+   double val=0;
    enum operator  op;
-
    struct expr *ret, *op1;
 
    op1=gete2(c);
@@ -338,10 +328,8 @@ static struct expr *gete3(struct context *c) {
 }
 
 static struct expr *gete4(struct context *c) {
-   real val=0;
-
+   double val=0;
    enum operator  op;
-
    struct expr *ret, *op1;
 
    op1=gete3(c);
@@ -360,10 +348,8 @@ static struct expr *gete4(struct context *c) {
 }
 
 static struct expr *gete5(struct context *c) {
-   real val=0;
-
+   double val=0;
    enum operator  op;
-
    struct expr *ret, *op1;
 
    op1=gete4(c);
@@ -381,10 +367,8 @@ static struct expr *gete5(struct context *c) {
 }
 
 static struct expr *getexpr(struct context *c) {
-   real val=0;
-
+   double val=0;
    enum operator  op;
-
    struct expr *ret, *op1;
 
    op1=gete5(c);
@@ -426,8 +410,8 @@ struct expr *nlt_parseexpr(struct context *c, char *str) {
    return (ret);
 }
 
-static real evaluate_expr(struct context *c,struct expr *e) {
-   real val1, val2;
+static double evaluate_expr(struct context *c,struct expr *e) {
+   double val1, val2;
 
    switch (e->operator ) {
      case op_value:
@@ -541,8 +525,8 @@ static real evaluate_expr(struct context *c,struct expr *e) {
    }
 }
 
-static real NL_expr(struct context *c,struct expr *e) {
-   real val=evaluate_expr(c, e);
+static double NL_expr(struct context *c,struct expr *e) {
+   double val=evaluate_expr(c, e);
 
    if (isnan(val))
       return (0);
@@ -556,7 +540,6 @@ static real NL_expr(struct context *c,struct expr *e) {
 
 static void NLTransPoint(SplinePoint *sp,struct context *c) {
    BasePoint old, off, delta;
-
    int fixup=true;
 
    old=sp->me;
@@ -615,15 +598,10 @@ static void NLTransPoint(SplinePoint *sp,struct context *c) {
 static void SplineSetNLTrans(SplineSet *ss,struct context *c,
 			     int everything) {
    SplinePoint *first, *last, *next;
-
    SplinePoint *sp;
-
    TPoint mids[20];
-
-   bigreal t;
-
+   double t;
    int i;
-
    Spline1D *xsp, *ysp;
 
    /* When doing a linear transform, all we need to do is transform the */
@@ -712,9 +690,7 @@ static void SplineSetNLTrans(SplineSet *ss,struct context *c,
 
 static void _SCNLTrans(SplineChar *sc,struct context *c,int layer) {
    SplineSet *ss;
-
    RefChar *ref;
-
    int i, last, first;
 
    if (sc->layer_cnt==ly_fore + 1 &&
@@ -746,11 +722,8 @@ static void _SCNLTrans(SplineChar *sc,struct context *c,int layer) {
 
 void _SFNLTrans(FontViewBase * fv, struct context *c) {
    SplineChar *sc;
-
    RefChar *ref;
-
    int i, gid;
-
    int layer=fv->active_layer;
 
    SFUntickAll(fv->sf);
@@ -769,7 +742,7 @@ void _SFNLTrans(FontViewBase * fv, struct context *c) {
 	 /* A reference doesn't really work after a non-linear transform */
 	 /*  but let's do the obvious thing */
 	 for (ref=sc->layers[layer].refs; ref != NULL; ref=ref->next)
-	    SCReinstanciateRefChar(sc, ref, layer);
+	    SCReinstantiateRefChar(sc, ref, layer);
 	 SCCharChangedUpdate(sc, fv->active_layer, true);
       }
 }
