@@ -1,4 +1,4 @@
-/* $Id: parsettfvar.c 4020 2015-06-14 18:15:09Z mskala $ */
+/* $Id: parsettfvar.c 4464 2015-11-30 09:57:27Z mskala $ */
 /* Copyright (C) 2000-2012  George Williams
  * Copyright (C) 2015  Matthew Skala
  *
@@ -32,7 +32,6 @@
 #include <ustring.h>
 #include <math.h>
 #include <locale.h>
-#include <gwidget.h>
 #include "ttf.h"
 
 /***************************************************************************/
@@ -55,7 +54,6 @@
 
 void VariationFree(struct ttfinfo *info) {
    int i, j;
-
    struct variations *variation=info->variations;
 
    if (variation==NULL)
@@ -91,7 +89,6 @@ void VariationFree(struct ttfinfo *info) {
 
 static void parsefvar(struct ttfinfo *info,AFILE *ttf) {
    int data_off, axis_count, instance_count, cnt;
-
    int i, j;
 
    afseek(ttf, info->fvar_start, SEEK_SET);
@@ -136,7 +133,7 @@ static void parsefvar(struct ttfinfo *info,AFILE *ttf) {
       calloc(instance_count, sizeof(struct tinstance));
    for (i=0; i < instance_count; ++i)
       info->variations->instances[i].coords =
-	 malloc(axis_count * sizeof(real));
+	 malloc(axis_count * sizeof(double));
 
    afseek(ttf, info->fvar_start + data_off, SEEK_SET);
    for (i=0; i < axis_count; ++i) {
@@ -161,7 +158,6 @@ static void parsefvar(struct ttfinfo *info,AFILE *ttf) {
 
 static void parseavar(struct ttfinfo *info,AFILE *ttf) {
    int axis_count, pair_count;
-
    int i, j;
 
    if (info->variations==NULL || info->avar_start==0
@@ -183,8 +179,8 @@ static void parseavar(struct ttfinfo *info,AFILE *ttf) {
       pair_count=getushort(ttf);
       if (pair_count != 0) {
 	 info->variations->axes[i].mapfrom =
-	    malloc(pair_count * sizeof(real));
-	 info->variations->axes[i].mapto=malloc(pair_count * sizeof(real));
+	    malloc(pair_count * sizeof(double));
+	 info->variations->axes[i].mapto=malloc(pair_count * sizeof(double));
 	 for (j=0; j < pair_count; ++j) {
 	    info->variations->axes[i].mapfrom[j]=getushort(ttf) / 16384.0;
 	    info->variations->axes[i].mapto[j]=getushort(ttf) / 16384.0;
@@ -200,9 +196,7 @@ static void parseavar(struct ttfinfo *info,AFILE *ttf) {
 
 static SplineChar **InfoCopyGlyphs(struct ttfinfo *info) {
    SplineChar **chars=malloc(info->glyph_cnt * sizeof(SplineChar *));
-
    int i;
-
    RefChar *r;
 
    for (i=0; i < info->glyph_cnt; ++i) {
@@ -230,7 +224,6 @@ static SplineChar **InfoCopyGlyphs(struct ttfinfo *info) {
 #define BAD_DELTA	0x10001
 static int *readpackeddeltas(AFILE *ttf,int n) {
    int *deltas;
-
    int runcnt, i, j;
 
    deltas=malloc(n * sizeof(int));
@@ -264,7 +257,6 @@ static int *readpackeddeltas(AFILE *ttf,int n) {
 
 static int *readpackedpoints(AFILE *ttf) {
    int *points;
-
    int n, runcnt, i, j, first;
 
    n=agetc(ttf);
@@ -318,11 +310,8 @@ static int TuplesMatch(struct variations *v,int vtest,int dbase) {
 
 static int PointCount(SplineChar *sc) {
    int i;
-
    RefChar *ref;
-
    SplineSet *ss;
-
    SplinePoint *sp;
 
    if (sc->layers[ly_fore].refs != NULL)
@@ -350,9 +339,7 @@ static void SCShiftAllBy(SplineChar *sc,int xd,int yd) {
    /* If they change the left/right side-bearing, I think that means everything */
    /*  should be shifted over */
    SplineSet *ss;
-
    SplinePoint *sp;
-
    RefChar *ref;
 
    if (xd==0 && yd==0)
@@ -380,7 +367,7 @@ static void SCShiftAllBy(SplineChar *sc,int xd,int yd) {
    for (ref=sc->layers[ly_fore].refs; ref != NULL; ref=ref->next) {
       ref->transform[4] += xd;
       ref->transform[5] += yd;
-      SCReinstanciateRefChar(sc, ref, ly_fore);
+      SCReinstantiateRefChar(sc, ref, ly_fore);
    }
 }
 
@@ -388,13 +375,9 @@ static void VaryGlyph(SplineChar *sc,int *points,int *xdeltas,
 		      int *ydeltas, int pcnt) {
    /* A character contains either composites or contours */
    int i, j;
-
    RefChar *ref;
-
    SplineSet *ss;
-
    SplinePoint *sp;
-
    Spline *s, *first;
 
    if (points[0]==ALL_POINTS) {
@@ -404,7 +387,7 @@ static void VaryGlyph(SplineChar *sc,int *points,int *xdeltas,
 	    if (xdeltas[i] != 0 || ydeltas[i] != 0) {
 	       ref->transform[4] += xdeltas[i];
 	       ref->transform[5] += ydeltas[i];
-	       SCReinstanciateRefChar(sc, ref, ly_fore);
+	       SCReinstantiateRefChar(sc, ref, ly_fore);
 	    }
 	 }
       } else {
@@ -441,7 +424,7 @@ static void VaryGlyph(SplineChar *sc,int *points,int *xdeltas,
 	       if (xdeltas[j] != 0 || ydeltas[j] != 0) {
 		  ref->transform[4] += xdeltas[j];
 		  ref->transform[5] += ydeltas[j];
-		  SCReinstanciateRefChar(sc, ref, ly_fore);
+		  SCReinstantiateRefChar(sc, ref, ly_fore);
 	       }
 	       ++j;
 	    }
@@ -521,9 +504,7 @@ static void VaryGlyphs(struct ttfinfo *info,int tupleIndex,int gnum,
    /*  designs. well variations for [0,1] describes that design, but the */
    /*  design for [1,1] includes the variations [0,1], [1,0], and [1,1] */
    int pcnt, tc;
-
    int *xdeltas, *ydeltas;
-
    struct variations *v=info->variations;
 
    if (info->chars[gnum]==NULL)	/* Apple doesn't support ttc so this */
@@ -561,11 +542,8 @@ static void VaryGlyphs(struct ttfinfo *info,int tupleIndex,int gnum,
 static void parsegvar(struct ttfinfo *info,AFILE *ttf) {
    /* I'm only going to support a subset of the gvar. Only the global tuples */
    int axiscount, globaltc, gvarflags, gc, i, j, g;
-
    uint32_t tupoff, dataoff, *gvars;
-
    struct variations *v=info->variations;
-
    int warned=false;
 
    afseek(ttf, info->gvar_start, SEEK_SET);
@@ -621,9 +599,7 @@ static void parsegvar(struct ttfinfo *info,AFILE *ttf) {
    for (g=0; g < gc; ++g)
       if (gvars[g] != gvars[g + 1]) {
 	 int tc;
-
 	 uint32_t datoff;
-
 	 int *sharedpoints=NULL;
 
 	 afseek(ttf, gvars[g], SEEK_SET);
@@ -653,7 +629,6 @@ static void parsegvar(struct ttfinfo *info,AFILE *ttf) {
 		  afseek(ttf, 4 * axiscount, SEEK_CUR);
 	    } else {
 	       int *localpoints=NULL;
-
 	       uint32_t here=aftell(ttf);
 
 	       afseek(ttf, datoff, SEEK_SET);
@@ -681,7 +656,6 @@ static void AlterEntry(struct ttf_table *cvt,int i,int delta) {
 static void VaryCvt(struct tuples *tuple,int *points,int *deltas,
 		    int pcnt, struct ttf_table *orig_cvt) {
    struct ttf_table *cvt;
-
    int i;
 
    if ((cvt=tuple->cvt)==NULL) {
@@ -707,9 +681,7 @@ static void VaryCvts(struct ttfinfo *info,int tupleIndex,int *points,
    /*  design for [1,1] includes the variations [0,1], [1,0], and [1,1] */
    /* And same is true of cvar */
    int pcnt, tc;
-
    int *deltas;
-
    struct variations *v=info->variations;
 
    if (points[0]==ALL_POINTS)
@@ -782,15 +754,13 @@ static void parsecvar(struct ttfinfo *info,AFILE *ttf) {
 	    afseek(ttf, 4 * info->variations->axis_count, SEEK_CUR);
       } else {
 	 int *localpoints=NULL;
-
 	 uint32_t here;
-
 	 int j, k, ti;
 
 	 ti=tupleIndex & 0xfff;
 	 if (tupleIndex & 0x8000) {
-	    real *coords =
-	       malloc(info->variations->axis_count * sizeof(real));
+	    double *coords =
+	       malloc(info->variations->axis_count * sizeof(double));
 	    for (j=0; j < info->variations->axis_count; ++j)
 	       coords[j]=((int16_t) getushort(ttf)) / 16384.0;
 	    for (k=0; k < info->variations->tuple_count; ++k) {
