@@ -1,4 +1,4 @@
-/* $Id: savefont.c 4064 2015-06-25 14:15:40Z mskala $ */
+/* $Id: savefont.c 4302 2015-10-24 15:00:46Z mskala $ */
 /* Copyright (C) 2000-2012  George Williams
  * Copyright (C) 2015  Matthew Skala
  *
@@ -31,7 +31,6 @@
 #include "gfile.h"
 #include "gresource.h"
 #include "utype.h"
-#include "gio.h"
 #include <stdlib.h>
 #include <math.h>
 #include <string.h>
@@ -75,11 +74,8 @@ static int WriteAfmFile(char *filename,SplineFont *sf,int formattype,
 			EncMap * map, int flags, SplineFont *fullsf,
 			int layer) {
    char *buf=malloc(strlen(filename) + 6), *pt, *pt2;
-
    AFILE *afm;
-
    int ret;
-
    int subtype=formattype;
 
    if ((formattype==ff_mma || formattype==ff_mmb) && sf->mm != NULL) {
@@ -111,7 +107,6 @@ static int WriteAfmFile(char *filename,SplineFont *sf,int formattype,
 
    if ((formattype==ff_mma || formattype==ff_mmb) && sf->mm != NULL) {
       MMSet *mm=sf->mm;
-
       int i;
 
       for (i=0; i < mm->instance_count; ++i) {
@@ -161,13 +156,9 @@ static int WriteAfmFile(char *filename,SplineFont *sf,int formattype,
 static int WriteTfmFile(char *filename,SplineFont *sf,int formattype,
 			EncMap * map, int layer) {
    char *buf=malloc(strlen(filename) + 6), *pt, *pt2;
-
    AFILE *tfm, *enc;
-
    int ret;
-
    int i;
-
    char *encname;
 
    strcpy(buf, filename);
@@ -225,13 +216,9 @@ static int WriteTfmFile(char *filename,SplineFont *sf,int formattype,
 static int WriteOfmFile(char *filename,SplineFont *sf,int formattype,
 			EncMap * map, int layer) {
    char *buf=malloc(strlen(filename) + 6), *pt, *pt2;
-
    AFILE *tfm, *enc;
-
    int ret;
-
    int i;
-
    char *encname;
    char *texparamnames[] =
       { "SLANT", "SPACE", "STRETCH", "SHRINK", "XHEIGHT", "QUAD",
@@ -286,9 +273,7 @@ static int WriteOfmFile(char *filename,SplineFont *sf,int formattype,
 int WritePfmFile(char *filename, SplineFont *sf, int type0, EncMap * map,
 		 int layer) {
    char *buf=malloc(strlen(filename) + 6), *pt, *pt2;
-
    AFILE *pfm;
-
    int ret;
 
    strcpy(buf, filename);
@@ -312,7 +297,6 @@ int WritePfmFile(char *filename, SplineFont *sf, int type0, EncMap * map,
 static int WriteFontLog(char *filename,SplineFont *sf,int formattype,
 			EncMap * map, int flags, SplineFont *fullsf) {
    char *buf=malloc(strlen(filename) + 12), *pt;
-
    AFILE *flog;
 
    if (sf->fontlog==NULL || *sf->fontlog=='\0')
@@ -663,7 +647,6 @@ static int SaveSubFont(SplineFont *sf,char *newname,int32_t *sizes,int res,
       strcat(filename, names[subfont]);
    else {
       int len=strlen(names[subfont]);
-
       int l;
 
       if (len > 2) {
@@ -743,15 +726,10 @@ static int WriteMultiplePSFont(SplineFont *sf,char *newname,int32_t *sizes,
 			       int res, char *wernerfilename, EncMap * map,
 			       int layer) {
    int err=0, tofree=false, max, filecnt;
-
    int32_t *mapping;
-
    char *path;
-
    int i;
-
    char **names;
-
    char *pt;
 
    pt=strrchr(newname, '.');
@@ -794,12 +772,6 @@ int CheckIfTransparent(SplineFont *sf) {
    /* Type3 doesn't support translucent fills */
    int i, j;
 
-   char *buts[3];
-
-   buts[0]=_("_Yes");
-   buts[1]=_("_Cancel");
-   buts[2]=NULL;
-
    for (i=0; i < sf->glyphcnt; ++i)
       if (sf->glyphs[i] != NULL) {
 	 SplineChar *sc=sf->glyphs[i];
@@ -817,9 +789,7 @@ int CheckIfTransparent(SplineFont *sf) {
 int _DoSave(SplineFont *sf, char *newname, int32_t * sizes, int res,
 	    EncMap * map, char *subfontdefinition, int layer) {
    char *path;
-
    int err=false;
-
    int iscid=oldformatstate==ff_cid || oldformatstate==ff_cffcid ||
       oldformatstate==ff_otfcid || oldformatstate==ff_otfciddfont;
    int flags=0;
@@ -843,7 +813,6 @@ int _DoSave(SplineFont *sf, char *newname, int32_t * sizes, int res,
    free(path);
    if (oldformatstate != ff_none) {
       int oerr=0;
-
       int bmap=oldbitmapstate;
 
       if (bmap==bf_otb)
@@ -987,13 +956,9 @@ int _DoSave(SplineFont *sf, char *newname, int32_t * sizes, int res,
 
 void PrepareUnlinkRmOvrlp(SplineFont *sf, char *filename, int layer) {
    int gid;
-
    SplineChar *sc;
-
    RefChar *ref, *refnext;
-
    extern int maxundoes;
-
    int old_maxundoes=maxundoes;
 
    if (maxundoes==0)
@@ -1022,7 +987,6 @@ void PrepareUnlinkRmOvrlp(SplineFont *sf, char *filename, int layer) {
 
 void RestoreUnlinkRmOvrlp(SplineFont *sf, char *filename, int layer) {
    int gid;
-
    SplineChar *sc;
 
    for (gid=0; gid < sf->glyphcnt; ++gid)
@@ -1035,9 +999,7 @@ void RestoreUnlinkRmOvrlp(SplineFont *sf, char *filename, int layer) {
 
 static int32_t *AllBitmapSizes(SplineFont *sf) {
    int32_t *sizes=NULL;
-
    BDFFont *bdf;
-
    int i, cnt;
 
    for (i=0; i < 2; ++i) {
@@ -1064,17 +1026,11 @@ int GenerateScript(SplineFont *sf, char *filename, char *bitmaptype,
       { "bdf", "ttf", "dfont", "ttf", "otb", "bin", "fon", "fnt", "pdb",
 "pt3", NULL };
    int32_t *sizes=NULL;
-
    char *end=filename + strlen(filename);
-
    struct sflist *sfi;
-
    char *freeme=NULL;
-
    int ret;
-
    struct sflist *sfl;
-
    char **former;
 
    if (sf->bitmaps==NULL)
