@@ -1,4 +1,4 @@
-/* $Id: sfd1.c 4020 2015-06-14 18:15:09Z mskala $ */
+/* $Id: sfd1.c 4427 2015-11-22 17:13:49Z mskala $ */
 /* Copyright (C) 2000-2012  George Williams
  * Copyright (C) 2015  Matthew Skala
  *
@@ -36,7 +36,6 @@
 
 static void SFGuessScriptList(SplineFont1 *sf) {
    uint32_t scripts[32], script;
-
    int i, scnt=0, j;
 
    for (i=0; i < sf->sf.glyphcnt; ++i)
@@ -105,7 +104,6 @@ static int SLContains(struct script_record *sr,uint32_t script,uint32_t lang) {
 
 int SFAddScriptIndex(SplineFont1 * sf, uint32_t * scripts, int scnt) {
    int i, j;
-
    struct script_record *sr;
 
    if (scnt==0)
@@ -147,7 +145,6 @@ int SFAddScriptIndex(SplineFont1 * sf, uint32_t * scripts, int scnt) {
 
 static int SFAddScriptLangIndex(SplineFont *_sf,uint32_t script,uint32_t lang) {
    int i;
-
    SplineFont1 *sf;
 
    if (_sf->cidmaster)
@@ -187,7 +184,6 @@ static int SFAddScriptLangIndex(SplineFont *_sf,uint32_t script,uint32_t lang) {
 
 static int SLCount(struct script_record *sr) {
    int sl_cnt=0;
-
    int i, j;
 
    for (i=0; sr[i].script != 0; ++i) {
@@ -199,7 +195,6 @@ static int SLCount(struct script_record *sr) {
 
 int SFFindBiggestScriptLangIndex(SplineFont *_sf, uint32_t script, uint32_t lang) {
    int i, best_sli=-1, best_cnt=-1, cnt;
-
    SplineFont1 *sf=(SplineFont1 *) _sf;
 
    if (_sf->sfd_version >= 2)
@@ -225,11 +220,8 @@ int SFFindBiggestScriptLangIndex(SplineFont *_sf, uint32_t script, uint32_t lang
 static FeatureScriptLangList *FeaturesFromTagSli(uint32_t tag,int sli,
 						 SplineFont1 * sf) {
    FeatureScriptLangList *fl;
-
    struct script_record *sr;
-
    struct scriptlanglist *cur, *last;
-
    int i;
 
    fl=chunkalloc(sizeof(FeatureScriptLangList));
@@ -276,13 +268,8 @@ static OTLookup *CreateLookup(SplineFont1 *sf,uint32_t tag,int sli,
       type==pst_chainsub ? gsub_contextchain : ot_undef;
    if (otl->lookup_type==ot_undef)
       ErrorMsg(2,"Unknown lookup type\n");
-   if (otl->lookup_type < gpos_single) {
-      otl->next=sf->sf.gsub_lookups;
-      sf->sf.gsub_lookups=otl;
-   } else {
-      otl->next=sf->sf.gpos_lookups;
-      sf->sf.gpos_lookups=otl;
-   }
+   otl->next=sf->sf.gsplookups[(otl->lookup_type<gpos_single)?0:1];
+   sf->sf.gsplookups[(otl->lookup_type<gpos_single)?0:1]=otl;
    otl->lookup_flags=flags;
    otl->features=FeaturesFromTagSli(tag, sli, sf);
    /* We will set the lookup_index after we've ordered the list */
@@ -301,8 +288,8 @@ static OTLookup *CreateACLookup(SplineFont1 *sf,AnchorClass1 *ac) {
       ac->ac.type==act_mklg ? gpos_mark2ligature : ot_undef;
    if (otl->lookup_type==ot_undef)
       ErrorMsg(2,"Unknown AnchorClass type\n");
-   otl->next=sf->sf.gpos_lookups;
-   sf->sf.gpos_lookups=otl;
+   otl->next=sf->sf.gsplookups[1];
+   sf->sf.gsplookups[1]=otl;
    otl->lookup_flags=ac->flags;
    otl->features =
       FeaturesFromTagSli(ac->feature_tag, ac->script_lang_index, sf);
@@ -314,18 +301,15 @@ static OTLookup *CreateACLookup(SplineFont1 *sf,AnchorClass1 *ac) {
 
 static OTLookup *CreateMacLookup(SplineFont1 *sf,ASM1 *sm) {
    OTLookup *otl=chunkalloc(sizeof(OTLookup));
-
    int i, ch;
-
    char *pt, *start;
-
    SplineChar *sc;
 
    otl->features=chunkalloc(sizeof(FeatureScriptLangList));
    if (sm->sm.type==asm_kern) {
       otl->lookup_type=kern_statemachine;
-      otl->next=sf->sf.gpos_lookups;
-      sf->sf.gpos_lookups=otl;
+      otl->next=sf->sf.gsplookups[1];
+      sf->sf.gsplookups[1]=otl;
       otl->features->featuretag =
 	 (sm->sm.flags & 0x8000) ? CHR('v', 'k', 'r', 'n') : CHR('k', 'e',
 								 'r', 'n');
@@ -333,8 +317,8 @@ static OTLookup *CreateMacLookup(SplineFont1 *sf,ASM1 *sm) {
       otl->lookup_type =
 	 sm->sm.type==asm_indic ? morx_indic : sm->sm.type ==
 	 asm_context ? morx_context : morx_insert;
-      otl->next=sf->sf.gsub_lookups;
-      sf->sf.gsub_lookups=otl;
+      otl->next=sf->sf.gsplookups[0];
+      sf->sf.gsplookups[0]=otl;
       otl->features->featuretag=(sm->feature << 16) | (sm->setting);
       otl->features->ismac=true;
    }
@@ -396,12 +380,10 @@ static struct lookup_subtable *CreateSubtable(OTLookup *otl,
 
 static OTLookup *FindNestedLookupByTag(SplineFont1 *sf,uint32_t tag) {
    int isgpos;
-
    OTLookup *otl;
 
    for (isgpos=0; isgpos < 2; ++isgpos) {
-      for (otl=isgpos ? sf->sf.gpos_lookups : sf->sf.gsub_lookups;
-	   otl != NULL; otl=otl->next) {
+      for (otl=sf->sf.gsplookups[isgpos];otl!=NULL;otl=otl->next) {
 	 if (otl->features != NULL && otl->features->scripts==NULL
 	     && otl->features->featuretag==tag)
 	    return (otl);
@@ -453,11 +435,8 @@ static void ASMReplaceTagsWithLookups(ASM *sm,SplineFont1 *sf) {
 
 static void ACHasBaseLig(SplineFont1 *sf,AnchorClass1 *ac) {
    int gid, k;
-
    SplineFont1 *subsf;
-
    SplineChar *sc;
-
    AnchorPoint *ap;
 
    ac->has_bases=ac->has_ligatures=false;
@@ -489,15 +468,10 @@ static void ACHasBaseLig(SplineFont1 *sf,AnchorClass1 *ac) {
 
 static void ACDisassociateLigatures(SplineFont1 *sf,AnchorClass1 *ac) {
    int gid, k;
-
    SplineFont1 *subsf;
-
    SplineChar *sc;
-
    AnchorPoint *ap, *lap;
-
    AnchorClass1 *lac;
-
    char *format;
 
    lac=chunkalloc(sizeof(AnchorClass1));
@@ -508,7 +482,7 @@ static void ACDisassociateLigatures(SplineFont1 *sf,AnchorClass1 *ac) {
    /* GT: Need to split some AnchorClasses into two classes, one for normal */
    /* GT:  base letters, and one for ligatures. So create a new AnchorClass */
    /* GT:  name for the ligature version */
-   format=_("Ligature %s");
+   format="Ligature %s";
    lac->ac.name=malloc(strlen(ac->ac.name) + strlen(format) + 1);
    sprintf(lac->ac.name, format, ac->ac.name);
 
@@ -645,7 +619,6 @@ static int TTFFeatureIndex(uint32_t tag,struct table_ordering *ord) {
 
 static int GSubOrder(SplineFont1 *sf,FeatureScriptLangList *fl) {
    struct table_ordering *ord;
-
    int sofar=30000, temp;
 
    for (ord=sf->orders;
@@ -667,14 +640,11 @@ static int order_lookups(const void *_otl1,const void *_otl2) {
 
 static void SFDCleanupAnchorClasses(SplineFont *sf) {
    AnchorClass *ac;
-
    AnchorPoint *ap;
-
    int i, j, scnt;
 
 #define S_MAX	100
    uint32_t scripts[S_MAX];
-
    int merge=0;
 
    for (ac=sf->anchor; ac != NULL; ac=ac->next) {
@@ -723,27 +693,16 @@ enum uni_interp interp_from_encoding(Encoding * enc, enum uni_interp interp) {
 
 void SFD_AssignLookups(SplineFont1 * sf) {
    PST1 *pst, *pst2;
-
    int isv;
-
    KernPair1 *kp, *kp2;
-
    KernClass1 *kc, *kc2;
-
    FPST1 *fpst;
-
    ASM1 *sm;
-
    AnchorClass1 *ac, *ac2;
-
    int gid, gid2, cnt, i, k, isgpos;
-
    SplineFont1 *subsf;
-
    SplineChar *sc, *sc2;
-
    OTLookup *otl, **all;
-
    struct lookup_subtable *sub;
 
    /* Fix up some gunk from really old versions of the sfd format */
@@ -904,9 +863,8 @@ void SFD_AssignLookups(SplineFont1 * sf) {
 
    /* We retained the old nested feature tags so we could do the above conversion */
    /*  of tag to lookup. Get rid of them now */
-   for (isgpos=0; isgpos < 2; ++isgpos) {
-      for (otl=isgpos ? sf->sf.gpos_lookups : sf->sf.gsub_lookups;
-	   otl != NULL; otl=otl->next) {
+   for (isgpos=0;isgpos<2;isgpos++) {
+      for (otl=sf->sf.gsplookups[isgpos];otl!=NULL;otl=otl->next) {
 	 if (otl->features != NULL && otl->features->scripts==NULL) {
 	    chunkfree(otl->features, sizeof(FeatureScriptLangList));
 	    otl->features=NULL;
@@ -944,28 +902,27 @@ void SFD_AssignLookups(SplineFont1 * sf) {
 
    /* Now I want to order the gsub lookups. I shan't bother with the gpos */
    /*  lookups because I didn't before */
-   for (otl=sf->sf.gsub_lookups, cnt=0; otl != NULL;
+   for (otl=sf->sf.gsplookups[0], cnt=0; otl != NULL;
 	otl=otl->next, ++cnt);
    if (cnt != 0) {
       all=malloc(cnt * sizeof(OTLookup *));
-      for (otl=sf->sf.gsub_lookups, cnt=0; otl != NULL;
+      for (otl=sf->sf.gsplookups[0], cnt=0; otl != NULL;
 	   otl=otl->next, ++cnt) {
 	 all[cnt]=otl;
 	 otl->lookup_index=GSubOrder(sf, otl->features);
       }
       qsort(all, cnt, sizeof(OTLookup *), order_lookups);
-      sf->sf.gsub_lookups=all[0];
+      sf->sf.gsplookups[0]=all[0];
       for (i=1; i < cnt; ++i)
 	 all[i - 1]->next=all[i];
       all[cnt - 1]->next=NULL;
       free(all);
    }
 
-   for (isgpos=0; isgpos < 2; ++isgpos) {
-      for (otl=isgpos ? sf->sf.gpos_lookups : sf->sf.gsub_lookups, cnt=0;
-	   otl != NULL; otl=otl->next) {
+   for (isgpos=0;isgpos<2;isgpos++) {
+      for (otl=sf->sf.gsplookups[isgpos],cnt=0;otl!=NULL;otl=otl->next) {
 	 otl->lookup_index=cnt++;
-	 NameOTLookup(otl, &sf->sf);
+	 NameOTLookup(otl,&sf->sf);
       }
    }
 }
