@@ -1,4 +1,4 @@
-/* $Id: sflayout.c 4064 2015-06-25 14:15:40Z mskala $ */
+/* $Id: sflayout.c 4300 2015-10-24 13:03:29Z mskala $ */
 /* Copyright (C) 2007-2012 by George Williams */
 /*
  * Redistribution and use in source and binary forms, with or without
@@ -34,7 +34,6 @@
 #include <ustring.h>
 #include <utype.h>
 #include <chardata.h>
-#include <ffglib.h>
 
 static uint32_t simple_stdfeatures[] =
    { CHR('c', 'c', 'm', 'p'), CHR('l', 'o', 'c', 'a'), CHR('k', 'e', 'r',
@@ -136,7 +135,6 @@ int LI_FDDrawChar(void *data,
 
 uint32_t *LI_TagsCopy(uint32_t * tags) {
    int i;
-
    uint32_t *ret;
 
    if (tags==NULL)
@@ -247,7 +245,6 @@ static struct basescript *FindBS(struct Base *base,struct opentype_str *ch,
 
    if (script==DEFAULT_SCRIPT) {
       struct fontlist *fl=ch->fl;
-
       SplineChar *sc=fl->sctext[ch->orig_index];
 
       script=SCScriptFromUnicode(sc);
@@ -315,9 +312,7 @@ static void LIFigureLineHeight(LayoutInfo *li,int l,int p) {
 					      start_fd->sf->descent));
 	 for (i=1; line[i] != NULL; ++i) {
 	    FontData *fd=((struct fontlist *) (line[i]->fl))->fd;
-
 	    struct Base *base=fd->sf->horiz_base;
-
 	    uint32_t cur_bsln_tag;
 
 	    if (fd->sf->horiz_base==NULL)
@@ -363,7 +358,6 @@ static void LIFigureLineHeight(LayoutInfo *li,int l,int p) {
 	 last=fl;
       if (last != NULL) {
 	 FontData *fd=last->fd;
-
 	 double scale =
 	    fd->pointsize * li->dpi / (72.0 *
 				       (fd->sf->ascent + fd->sf->descent));
@@ -756,7 +750,6 @@ FontData *LI_RegenFontData(LayoutInfo * li, FontData * ret) {
       }
       if (ftc==NULL) {
 	 int flags=0;
-
 	 int ff=ret->fonttype==sftf_pfb ? ff_pfb :
 	    ret->fonttype==sftf_ttf ? ff_ttf : ff_otf;
 	 ftc =
@@ -997,7 +990,7 @@ void FontImage(SplineFont *sf, char *filename, Array * arr, int width,
    cnt=arr->argc / 2;
    len=1;
    for (i=0; i < cnt; ++i)
-      len += g_utf8_strlen(arr->vals[2 * i + 1].u.sval, -1) + 1;
+      len += utf8_strlen(arr->vals[2 * i + 1].u.sval) + 1;
 
    li->text=malloc(len * sizeof(unichar_t));
    len=0;
@@ -1018,7 +1011,7 @@ void FontImage(SplineFont *sf, char *filename, Array * arr, int width,
       script=DEFAULT_SCRIPT;
       for (upt=li->text + len; *upt && script==DEFAULT_SCRIPT; ++upt)
 	 script=ScriptFromUnicode(*upt, NULL);
-      len += g_utf8_strlen(arr->vals[2 * i + 1].u.sval, -1);
+      len += utf8_strlen(arr->vals[2 * i + 1].u.sval);
       li->text[len++]='\n';
 
       last->end=len - 1;
