@@ -1,4 +1,4 @@
-/* $Id: splinefont.c 4064 2015-06-25 14:15:40Z mskala $ */
+/* $Id: splinefont.c 4464 2015-11-30 09:57:27Z mskala $ */
 /* Copyright (C) 2000-2012  George Williams
  * Copyright (C) 2015  Matthew Skala
  *
@@ -36,7 +36,6 @@
 #include <sys/stat.h>
 #include <gfile.h>
 #include <time.h>
-#include "unicoderange.h"
 #include "psfont.h"
 #include <locale.h>
 
@@ -106,11 +105,9 @@ SplineChar *SCBuildDummy(SplineChar *dummy,SplineFont *sf,EncMap *map,
 
    if (sf->cidmaster != NULL)
      dummy->name=namebuf;
-
    else if (map->enc->psnames!=NULL && i<map->enc->char_cnt &&
 	    map->enc->psnames[i]!=NULL)
       dummy->name=map->enc->psnames[i];
-
    else if (dummy->unicodeenc==-1)
      dummy->name=NULL;
 
@@ -251,10 +248,6 @@ SplineChar *SFMakeChar(SplineFont *sf, EncMap * map, int enc) {
    return (_SFMakeChar(sf, map, enc));
 }
 
-struct unicoderange specialnames[]={
-   UNICODERANGE_EMPTY
-};
-
 int NameToEncoding(SplineFont *sf, EncMap * map, const char *name) {
    int enc, uni, i, ch;
    char *end, *freeme=NULL;
@@ -308,13 +301,6 @@ int NameToEncoding(SplineFont *sf, EncMap * map, const char *name) {
    } else {
       if (enc==-1) {
 	 uni=UniFromName(name, sf->uni_interp, map->enc);
-	 if (uni < 0) {
-	    for (i=0; specialnames[i].name != NULL; ++i)
-	       if (strcmp(name, specialnames[i].name)==0) {
-		  uni=specialnames[i].first;
-		  break;
-	       }
-	 }
 	 if (uni < 0 && name[1]=='\0')
 	    uni=name[0];
       }
@@ -433,7 +419,6 @@ static void SFScalePrivate(SplineFont *sf,double scale) {
 
    for (i=0; integerscalethese[i] != NULL; ++i) {
       char *str=PSDictHasEntry(sf->private, integerscalethese[i]);
-
       char *new=iscaleString(str, scale);
 
       if (new != NULL)
@@ -442,7 +427,6 @@ static void SFScalePrivate(SplineFont *sf,double scale) {
    }
    for (i=0; scalethese[i] != NULL; ++i) {
       char *str=PSDictHasEntry(sf->private, scalethese[i]);
-
       char *new=scaleString(str, scale);
 
       if (new != NULL)
@@ -471,15 +455,15 @@ static void ScaleBase(struct Base *base,double scale) {
 }
 
 int SFScaleToEm(SplineFont *sf, int as, int des) {
-   bigreal scale;
-   real transform[6];
+   double scale;
+   double transform[6];
    BVTFunc bvts;
    uint8_t *oldselected=sf->fv->selected;
    enum fvtrans_flags trans_flags =
       fvt_alllayers | fvt_round_to_int | fvt_dontsetwidth |
       fvt_scalekernclasses | fvt_scalepstpos | fvt_dogrid;
 
-   scale=(as + des) / (bigreal) (sf->ascent + sf->descent);
+   scale=(as + des) / (double) (sf->ascent + sf->descent);
    sf->pfminfo.hhead_ascent=rint(sf->pfminfo.hhead_ascent * scale);
    sf->pfminfo.hhead_descent=rint(sf->pfminfo.hhead_descent * scale);
    sf->pfminfo.linegap=rint(sf->pfminfo.linegap * scale);
@@ -682,17 +666,14 @@ static char *ArchiveParseTOC(char *listfile,enum archive_list_style ars,
       return (onlyname);
    }
 
-   /* Suppose they've got an archive of a directory format font? I mean a ufo */
-   /*  or a sfdir. It won't show up in the list of files (because either     */
+   /* Suppose they've got an archive of a UFO directory? */
+   /*  It won't show up in the list of files (because either */
    /*  tar or I have removed all directories from that list) */
    pt=strrchr(files[0], '/');
    if (pt != NULL) {
       if ((pt-files[0]>4
 	   && (strncasecmp(pt-4,".ufo",4)==0
-	       || strncasecmp(pt-4,"_ufo",4)==0))
-	  || (pt-files[0]>6
-	      && (strncasecmp(pt-6,".sfdir",6)==0
-		  || strncasecmp(pt-6,"_sfdir",6)== 0))) {
+	       || strncasecmp(pt-4,"_ufo",4)==0))) {
 	 /* Ok, looks like a potential directory font. Now is EVERYTHING */
 	 /*  in the archive inside this guy? */
 	 for (i=0; i < fcnt; ++i)
@@ -812,7 +793,7 @@ char *Unarchive(char *name, char **_archivedir) {
    }
 
    /* I tried sending everything to stdout, but that doesn't work if the */
-   /*  output is a directory file (ufo, sfdir) */
+   /*  output is a directory file */
    unarchivecmd=malloc(strlen(archivers[i].unarchive) + 1 +
 			 strlen(archivers[i].listargs) + 1 +
 			 strlen(name) + 1 +
@@ -879,7 +860,6 @@ static char *ForceFileToHaveName(AFILE *file,char *exten) {
       if (access(tmpfilename, F_OK)==-1 &&
 	  (newfile=afopen(tmpfilename, "w")) != NULL) {
 	 char buffer[1024];
-
 	 int len;
 
 	 while ((len=afread(buffer, 1, sizeof(buffer), file)) > 0)
@@ -990,7 +970,7 @@ SplineFont *_ReadSplineFont(AFILE *file, char *filename,
 
    /* If there are no pfaedit windows, give them something to look at */
    /*  immediately. Otherwise delay a bit */
-   strncpy(ubuf, _("Loading font from "), sizeof(ubuf) - 1);
+   strncpy(ubuf,"Loading font from ",sizeof(ubuf)-1);
    len=strlen(ubuf);
    if (!wasurl || i==-1)	/* If it wasn't compressed, or it wasn't an url, then the fullname is reasonable, else use the original name */
       strncat(ubuf, temp=fastrdup(GFileNameTail(fullname)), 100);
@@ -1014,7 +994,6 @@ SplineFont *_ReadSplineFont(AFILE *file, char *filename,
 /* checked=='c'   => cff */
 /* checked=='S'   => svg */
 /* checked=='f'   => sfd */
-/* checked=='F'   => sfdir */
 /* checked=='b'   => bdf */
 /* checked=='i'   => ikarus */
    if (!wasurl && GFileIsDir(strippedname)) {
@@ -1025,13 +1004,6 @@ SplineFont *_ReadSplineFont(AFILE *file, char *filename,
       if (GFileExists(temp)) {
 	 sf=SFReadUFO(strippedname, 0);
 	 checked='u';
-      } else {
-	 strcpy(temp, strippedname);
-	 strcat(temp, "/font.props");
-	 if (GFileExists(temp)) {
-	    sf=SFDirRead(strippedname);
-	    checked='F';
-	 }
       }
       free(temp);
       if (file != NULL)
@@ -1237,15 +1209,10 @@ SplineFont *_ReadSplineFont(AFILE *file, char *filename,
        && (sf->pfminfo.fstype & 0xff)==0x0002) {
       /* Ok, they have told us from a script they have access to the font */
    } else if (!fromsfd && sf != NULL && (sf->pfminfo.fstype & 0xff)==0x0002) {
-      char *buts[3];
-
-      buts[0]=_("_Yes");
-      buts[1]=_("_No");
-      buts[2]=NULL;
       SplineFontFree(sf);
-      return (NULL);
+      return NULL;
    }
-   return (sf);
+   return sf;
 }
 
 SplineFont *ReadSplineFont(char *filename, enum openflags openflags) {
@@ -1279,7 +1246,6 @@ SplineFont *LoadSplineFont(char *filename, enum openflags openflags) {
       /* For some reason Adobe distributes CID keyed fonts (both OTF and */
       /*  postscript) as extensionless files */
       int ok=false;
-
       AFILE *test=afopen(filename, "rb");
 
       if (test != NULL) {
@@ -1411,11 +1377,11 @@ char *SFGetModifiers(SplineFont *sf) {
 
 enum flatness { mt_flat, mt_round, mt_pointy, mt_unknown };
 
-static bigreal SPLMaxHeight(SplineSet *spl,enum flatness *isflat) {
+static double SPLMaxHeight(SplineSet *spl,enum flatness *isflat) {
    enum flatness f=mt_unknown;
-   bigreal max=-1.0e23;
+   double max=-1.0e23;
    Spline *s, *first;
-   extended ts[2];
+   double ts[2];
    int i;
 
    for (; spl != NULL; spl=spl->next) {
@@ -1438,7 +1404,7 @@ static bigreal SPLMaxHeight(SplineSet *spl,enum flatness *isflat) {
 	       SplineFindExtrema(&s->splines[1], &ts[0], &ts[1]);
 	       for (i=0; i < 2; ++i)
 		  if (ts[i] != -1) {
-		     bigreal y =
+		     double y =
 			((s->splines[1].a * ts[i] + s->splines[1].b) * ts[i] +
 			 s->splines[1].c) * ts[i] + s->splines[1].d;
 		     if (y > max) {
@@ -1468,11 +1434,11 @@ static bigreal SPLMaxHeight(SplineSet *spl,enum flatness *isflat) {
    return (max);
 }
 
-static bigreal SCMaxHeight(SplineChar *sc,int layer,enum flatness *isflat) {
+static double SCMaxHeight(SplineChar *sc,int layer,enum flatness *isflat) {
    /* Find the max height of this layer of the glyph. Also find whether that */
    /* max is flat (as in "z", curved as in "o" or pointy as in "A") */
    enum flatness f=mt_unknown, curf;
-   bigreal max=-1.0e23, test;
+   double max=-1.0e23, test;
    RefChar *r;
 
    max=SPLMaxHeight(sc->layers[layer].splines, &curf);
@@ -1488,11 +1454,11 @@ static bigreal SCMaxHeight(SplineChar *sc,int layer,enum flatness *isflat) {
    return (max);
 }
 
-static bigreal SPLMinHeight(SplineSet *spl,enum flatness *isflat) {
+static double SPLMinHeight(SplineSet *spl,enum flatness *isflat) {
    enum flatness f=mt_unknown;
-   bigreal min=1.0e23;
+   double min=1.0e23;
    Spline *s, *first;
-   extended ts[2];
+   double ts[2];
    int i;
 
    for (; spl != NULL; spl=spl->next) {
@@ -1515,7 +1481,7 @@ static bigreal SPLMinHeight(SplineSet *spl,enum flatness *isflat) {
 	       SplineFindExtrema(&s->splines[1], &ts[0], &ts[1]);
 	       for (i=0; i < 2; ++i)
 		  if (ts[i] != -1) {
-		     bigreal y =
+		     double y =
 			((s->splines[1].a * ts[i] + s->splines[1].b) * ts[i] +
 			 s->splines[1].c) * ts[i] + s->splines[1].d;
 		     if (y < min) {
@@ -1545,11 +1511,11 @@ static bigreal SPLMinHeight(SplineSet *spl,enum flatness *isflat) {
    return (min);
 }
 
-static bigreal SCMinHeight(SplineChar *sc,int layer,enum flatness *isflat) {
+static double SCMinHeight(SplineChar *sc,int layer,enum flatness *isflat) {
    /* Find the min height of this layer of the glyph. Also find whether that */
    /* min is flat (as in "z", curved as in "o" or pointy as in "A") */
    enum flatness f=mt_unknown, curf;
-   bigreal min=1.0e23, test;
+   double min=1.0e23, test;
    RefChar *r;
 
    min=SPLMinHeight(sc->layers[layer].splines, &curf);
@@ -1568,11 +1534,11 @@ static bigreal SCMinHeight(SplineChar *sc,int layer,enum flatness *isflat) {
 #define RANGE	0x40ffffff
 
 struct dimcnt {
-   bigreal pos;
+   double pos;
    int cnt;
 };
 
-static int dclist_insert(struct dimcnt *arr,int cnt,bigreal val) {
+static int dclist_insert(struct dimcnt *arr,int cnt,double val) {
    int i;
 
    for (i=0; i < cnt; ++i) {
@@ -1586,14 +1552,14 @@ static int dclist_insert(struct dimcnt *arr,int cnt,bigreal val) {
    return (i + 1);
 }
 
-static bigreal SFStandardHeight(SplineFont *sf,int layer,int do_max,
+static double SFStandardHeight(SplineFont *sf,int layer,int do_max,
 				unichar_t * list) {
    struct dimcnt flats[200], curves[200];
-   bigreal test;
+   double test;
    enum flatness curf;
    int fcnt=0, ccnt=0, cnt, tot, i, useit;
    unichar_t ch, top;
-   bigreal result, bestheight, bestdiff, diff, val;
+   double result, bestheight, bestdiff, diff, val;
    char *blues, *end;
 
    while (*list) {
@@ -1715,39 +1681,39 @@ static unichar_t descender_str[]={ 'g','j','p','q','y',
    0
 };
 
-bigreal SFCapHeight(SplineFont *sf, int layer, int return_error) {
-   bigreal result=SFStandardHeight(sf, layer, true, capheight_str);
+double SFCapHeight(SplineFont *sf, int layer, int return_error) {
+   double result=SFStandardHeight(sf, layer, true, capheight_str);
 
    if (result==-1e23 && !return_error)
       result=(8 * sf->ascent) / 10;
    return (result);
 }
 
-bigreal SFXHeight(SplineFont *sf, int layer, int return_error) {
-   bigreal result=SFStandardHeight(sf, layer, true, xheight_str);
+double SFXHeight(SplineFont *sf, int layer, int return_error) {
+   double result=SFStandardHeight(sf, layer, true, xheight_str);
 
    if (result==-1e23 && !return_error)
       result=(6 * sf->ascent) / 10;
    return (result);
 }
 
-bigreal SFAscender(SplineFont *sf, int layer, int return_error) {
-   bigreal result=SFStandardHeight(sf, layer, true, ascender_str);
+double SFAscender(SplineFont *sf, int layer, int return_error) {
+   double result=SFStandardHeight(sf, layer, true, ascender_str);
 
    if (result==-1e23 && !return_error)
       result=(81 * sf->ascent) / 100;
    return (result);
 }
 
-bigreal SFDescender(SplineFont *sf, int layer, int return_error) {
-   bigreal result=SFStandardHeight(sf, layer, false, descender_str);
+double SFDescender(SplineFont *sf, int layer, int return_error) {
+   double result=SFStandardHeight(sf, layer, false, descender_str);
 
    if (result==1e23 && !return_error)
       result=-sf->descent / 2;
    return (result);
 }
 
-static void arraystring(char *buffer,real *array,int cnt) {
+static void arraystring(char *buffer,double *array,int cnt) {
    int i, ei;
 
    for (ei=cnt; ei > 1 && array[ei - 1]==0; --ei);
@@ -1762,8 +1728,8 @@ static void arraystring(char *buffer,real *array,int cnt) {
    *buffer='\0';
 }
 
-static void SnapSet(struct psdict *private,real stemsnap[12],
-		    real snapcnt[12], char *name1, char *name2, int which) {
+static void SnapSet(struct psdict *private,double stemsnap[12],
+		    double snapcnt[12], char *name1, char *name2, int which) {
    int i, mi;
    char buffer[211];
 
@@ -1787,9 +1753,9 @@ static void SnapSet(struct psdict *private,real stemsnap[12],
 
 int SFPrivateGuess(SplineFont *sf, int layer, struct psdict *private,
 		   char *name, int onlyone) {
-   real bluevalues[14], otherblues[10];
-   real snapcnt[12];
-   real stemsnap[12];
+   double bluevalues[14], otherblues[10];
+   double snapcnt[12];
+   double stemsnap[12];
    char buffer[211];
    char *oldloc;
    int ret;
@@ -1820,7 +1786,7 @@ int SFPrivateGuess(SplineFont *sf, int layer, struct psdict *private,
       SnapSet(private, stemsnap, snapcnt, "StdVW", "StemSnapV",
 	      !onlyone ? 0 : strcmp(name, "StdVW")==0 ? 1 : 0);
    } else if (strcmp(name, "BlueScale")==0) {
-      bigreal val=-1;
+      double val=-1;
 
       if (PSDictFindEntry(private, "BlueValues") != -1) {
 	 /* Can guess BlueScale if we've got a BlueValues */
@@ -1889,8 +1855,8 @@ typedef struct SPLFirstVisitorFoundSoughtDataS {
 typedef struct SPLFirstVisitorFoundSoughtXYDataS {
    int use_x;
    int use_y;
-   real x;
-   real y;
+   double x;
+   double y;
 
    // outputs
    int found;
@@ -1948,7 +1914,7 @@ static void SPLFirstVisitorFoundSoughtXY(SplinePoint *splfirst,
 }
 
 SplinePoint *SplinePointListContainsPointAtX(SplinePointList * container,
-					     real x) {
+					     double x) {
    SplinePointList *spl;
 
    for (spl=container; spl != NULL; spl=spl->next) {
