@@ -1,4 +1,4 @@
-/* $Id: splineorder2.c 4020 2015-06-14 18:15:09Z mskala $ */
+/* $Id: splineorder2.c 4464 2015-11-30 09:57:27Z mskala $ */
 /* Copyright (C) 2000-2012  George Williams
  * Copyright (C) 2015  Matthew Skala
  *
@@ -59,20 +59,14 @@
 /* Does the quadratic spline in ttf approximate the cubic spline in ps */
 /*  within one pixel between tmin and tmax (on ps. presumably ttf between 0&1 */
 /* dim is the dimension in which there is the greatest change */
-static int comparespline(Spline *ps,Spline *ttf,real tmin,real tmax,
-			 real err) {
+static int comparespline(Spline *ps,Spline *ttf,double tmin,double tmax,
+			 double err) {
    int dim=0, other;
-
-   real dx, dy, ddim, dt, t;
-
-   real d, o;
-
-   real ttf_t, sq, val;
-
+   double dx, dy, ddim, dt, t;
+   double d, o;
+   double ttf_t, sq, val;
    DBounds bb;
-
-   extended ts[3];
-
+   double ts[3];
    int i;
 
    /* Are all points on ttf near points on ps? */
@@ -195,10 +189,9 @@ static int comparespline(Spline *ps,Spline *ttf,real tmin,real tmax,
    return (true);
 }
 
-static SplinePoint *MakeQuadSpline(SplinePoint *start,Spline *ttf,real x,
-				   real y, real tmax, SplinePoint * oldend) {
+static SplinePoint *MakeQuadSpline(SplinePoint *start,Spline *ttf,double x,
+				   double y, double tmax, SplinePoint * oldend) {
    Spline *new=chunkalloc(sizeof(Spline));
-
    SplinePoint *end=chunkalloc(sizeof(SplinePoint));
 
    if (tmax==1) {
@@ -236,11 +229,10 @@ static SplinePoint *MakeQuadSpline(SplinePoint *start,Spline *ttf,real x,
    return (end);
 }
 
-static int buildtestquads(Spline *ttf,real xmin,real ymin,real cx,
-			  real cy, real x, real y, real tmin, real t,
-			  real err, Spline * ps, DBounds * psbb) {
-   real fudge, normal, para;
-
+static int buildtestquads(Spline *ttf,double xmin,double ymin,double cx,
+			  double cy, double x, double y, double tmin, double t,
+			  double err, Spline * ps, DBounds * psbb) {
+   double fudge, normal, para;
    BasePoint segdir, cpdir;
 
    /* test the control points are reasonable */
@@ -279,11 +271,9 @@ static int buildtestquads(Spline *ttf,real xmin,real ymin,real cx,
    return (false);
 }
 
-static SplinePoint *LinearSpline(Spline *ps,SplinePoint *start,real tmax) {
-   real x, y;
-
+static SplinePoint *LinearSpline(Spline *ps,SplinePoint *start,double tmax) {
+   double x, y;
    Spline *new=chunkalloc(sizeof(Spline));
-
    SplinePoint *end=chunkalloc(sizeof(SplinePoint));
 
    x=((ps->splines[0].a * tmax + ps->splines[0].b) * tmax +
@@ -317,26 +307,17 @@ static SplinePoint *LinearSpline(Spline *ps,SplinePoint *start,real tmax) {
    return (end);
 }
 
-static SplinePoint *_ttfapprox(Spline *ps,real tmin,real tmax,
+static SplinePoint *_ttfapprox(Spline *ps,double tmin,double tmax,
 			       SplinePoint * start) {
    int dim=0;
-
-   real dx, dy, ddim, dt, t, err;
-
-   real x, y, xmin, ymin;
-
-   real dxdtmin, dydtmin, dxdt, dydt;
-
+   double dx, dy, ddim, dt, t, err;
+   double x, y, xmin, ymin;
+   double dxdtmin, dydtmin, dxdt, dydt;
    SplinePoint *sp;
-
-   real cx, cy;
-
+   double cx, cy;
    Spline ttf;
-
    int cnt=-1, forceit, unforceable;
-
    BasePoint end, rend, dend;
-
    DBounds bb;
 
    rend.x =
@@ -508,14 +489,11 @@ static SplinePoint *_ttfapprox(Spline *ps,real tmin,real tmax,
    goto tail_recursion;
 }
 
-static SplinePoint *__ttfApprox(Spline *ps,real tmin,real tmax,
+static SplinePoint *__ttfApprox(Spline *ps,double tmin,double tmax,
 				SplinePoint * start) {
-   extended inflect[2];
-
+   double inflect[2];
    int i=0;
-
    SplinePoint *end;
-
    Spline *s, *next;
 
    end=_ttfapprox(ps, tmin, tmax, start);
@@ -540,7 +518,7 @@ static SplinePoint *__ttfApprox(Spline *ps,real tmin,real tmax,
       if (RealNearish(inflect[0], inflect[1]))
 	 --i;
       else if (inflect[0] > inflect[1]) {
-	 real temp=inflect[0];
+	 double temp=inflect[0];
 
 	 inflect[0]=inflect[1];
 	 inflect[1]=temp;
@@ -560,16 +538,14 @@ static SplinePoint *__ttfApprox(Spline *ps,real tmin,real tmax,
 typedef struct qpoint {
    BasePoint bp;
    BasePoint cp;
-   bigreal t;
+   double t;
 } QPoint;
 
 static int comparedata(Spline *ps,QPoint *data,int qfirst,int qlast,
 		       int round_to_int, int test_level) {
    Spline ttf;
-
    int i;
-
-   bigreal err=round_to_int ? 1.5 : 1;
+   double err=round_to_int ? 1.5 : 1;
 
    if (qfirst==qlast)		/* happened (was a bug) */
       return (false);
@@ -610,7 +586,6 @@ static int comparedata(Spline *ps,QPoint *data,int qfirst,int qlast,
 static SplinePoint *CvtDataToSplines(QPoint *data,int qfirst,int qlast,
 				     SplinePoint * start) {
    SplinePoint *end;
-
    int i;
 
    for (i=qfirst; i < qlast; ++i) {
@@ -630,8 +605,7 @@ static SplinePoint *CvtDataToSplines(QPoint *data,int qfirst,int qlast,
 
 static int SplineWithWellBehavedControlPoints(Spline *ps) {
    BasePoint splineunit;
-
-   bigreal splinelen, npos, ppos;
+   double splinelen, npos, ppos;
 
    splineunit.x=ps->to->me.x - ps->from->me.x;
    splineunit.y=ps->to->me.y - ps->from->me.y;
@@ -649,21 +623,15 @@ static int SplineWithWellBehavedControlPoints(Spline *ps) {
    return (npos >= 0 && /* npos<=ppos && */ ppos <= splinelen);
 }
 
-static int PrettyApprox(Spline *ps,bigreal tmin,bigreal tmax,
+static int PrettyApprox(Spline *ps,double tmin,double tmax,
 			QPoint * data, int qcnt, int round_to_int,
 			int test_level) {
    int ptcnt, q, i;
-
-   bigreal distance, dx, dy, tstart;
-
+   double distance, dx, dy, tstart;
    BasePoint end, mid, slopemin, slopemid, slopeend;
-
    BasePoint splineunit, start;
-
-   bigreal splinelen, midpos, lastpos, lastpos2, cppos;
-
+   double splinelen, midpos, lastpos, lastpos2, cppos;
    int do_good_spline_check;
-
    QPoint data2[12];
 
    if (qcnt==-1)
@@ -676,7 +644,7 @@ static int PrettyApprox(Spline *ps,bigreal tmin,bigreal tmax,
       (3 * ps->splines[1].a * tmin + 2 * ps->splines[1].b) * tmin +
       ps->splines[1].c;
    if (slopemin.x==0 && slopemin.y==0) {
-      bigreal t=tmin + (tmax - tmin) / 256;
+      double t=tmin + (tmax - tmin) / 256;
 
       /* If there is no control point for this end point, then the slope is */
       /*  0/0 at the end point. Which isn't useful, it leads to a quadratic */
@@ -704,7 +672,7 @@ static int PrettyApprox(Spline *ps,bigreal tmin,bigreal tmax,
       (3 * ps->splines[1].a * tmax + 2 * ps->splines[1].b) * tmax +
       ps->splines[1].c;
    if (slopemin.x==0 && slopemin.y==0) {
-      bigreal t=tmax - (tmax - tmin) / 256;
+      double t=tmax - (tmax - tmin) / 256;
 
       /* Same problem as above, except at the other end */
       slopeend.x =
@@ -983,7 +951,7 @@ static SplinePoint *AlreadyQuadraticCheck(Spline *ps,SplinePoint *start) {
 }
 
 static SplinePoint *ttfApprox(Spline *ps,SplinePoint *start) {
-   extended magicpoints[6], last;
+   double magicpoints[6], last;
    int cnt, i, j, qcnt, test_level;
    QPoint data[8 * 10];
    int round_to_int =
@@ -1046,7 +1014,7 @@ static SplinePoint *ttfApprox(Spline *ps,SplinePoint *start) {
    for (i=0; i < cnt; ++i)
       for (j=i + 1; j < cnt; ++j) {
 	 if (magicpoints[i] > magicpoints[j]) {
-	    bigreal temp=magicpoints[i];
+	    double temp=magicpoints[i];
 
 	    magicpoints[i]=magicpoints[j];
 	    magicpoints[j]=temp;
@@ -1079,6 +1047,16 @@ static SplinePoint *ttfApprox(Spline *ps,SplinePoint *start) {
    return (__ttfApprox(ps, 0, 1, start));
 }
 
+SplinePoint *SplineTtfApprox(Spline *ps) {
+      SplinePoint *from;
+   
+      from=chunkalloc(sizeof(SplinePoint));
+      *from=*ps->from;
+      from->hintmask=NULL;
+      ttfApprox(ps,from);
+      return from;
+}
+
 static void ttfCleanup(SplinePoint *from) {
    SplinePoint *test, *next;
 
@@ -1113,7 +1091,6 @@ static void ttfCleanup(SplinePoint *from) {
 
 SplineSet *SSttfApprox(SplineSet * ss) {
    SplineSet *ret=chunkalloc(sizeof(SplineSet));
-
    Spline *spline, *first;
 
    ret->first=chunkalloc(sizeof(SplinePoint));
@@ -1168,17 +1145,13 @@ SplineSet *SplineSetsTTFApprox(SplineSet * ss) {
    return (head);
 }
 
-static void ImproveB3CPForQuadratic(real from,real *_ncp,real *_pcp,
-				    real to) {
-   real ncp=*_ncp, pcp=*_pcp;
-
-   real noff, poff;
-
-   real c, b, best;
-
+static void ImproveB3CPForQuadratic(double from,double *_ncp,double *_pcp,
+				    double to) {
+   double ncp=*_ncp, pcp=*_pcp;
+   double noff, poff;
+   double c, b, best;
    int err, i, besti;
-
-   real offs[9];
+   double offs[9];
 
    if ((noff=ncp / 32768.0) < 0)
       noff=-noff;
@@ -1250,9 +1223,7 @@ static void ImproveB3CPForQuadratic(real from,real *_ncp,real *_pcp,
 
 SplineSet *SSPSApprox(SplineSet * ss) {
    SplineSet *ret=chunkalloc(sizeof(SplineSet));
-
    Spline *spline, *first;
-
    SplinePoint *to;
 
    ret->first=chunkalloc(sizeof(SplinePoint));
@@ -1366,14 +1337,13 @@ static void SCConvertRefs(SplineChar *sc,int layer) {
    for (rf=sc->layers[layer].refs; rf != NULL; rf=rf->next) {
       if (!rf->sc->ticked)
 	 SCConvertRefs(rf->sc, layer);
-      SCReinstanciateRefChar(sc, rf, layer);	/* Conversion is done by reinstanciating */
+      SCReinstantiateRefChar(sc, rf, layer);	/* Conversion is done by reinstanciating */
       /* Since the base thing will have been converted, all we do is copy its data */
    }
 }
 
 void SFConvertLayerToOrder2(SplineFont *_sf, int layer) {
    int i, k;
-
    SplineFont *sf;
 
    if (_sf->cidmaster != NULL)
@@ -1402,9 +1372,7 @@ void SFConvertLayerToOrder2(SplineFont *_sf, int layer) {
 
 void SFConvertGridToOrder2(SplineFont *_sf) {
    int k;
-
    SplineSet *new;
-
    SplineFont *sf;
 
    if (_sf->cidmaster != NULL)
@@ -1436,11 +1404,8 @@ void SFConvertToOrder2(SplineFont *_sf) {
 
 void SCConvertLayerToOrder3(SplineChar * sc, int layer) {
    SplineSet *new;
-
    RefChar *ref;
-
    AnchorPoint *ap;
-
    int has_order2_layer_still, i;
 
    new=SplineSetsPSApprox(sc->layers[layer].splines);
@@ -1479,7 +1444,6 @@ void SCConvertLayerToOrder3(SplineChar * sc, int layer) {
 
 void SFConvertLayerToOrder3(SplineFont *_sf, int layer) {
    int i, k;
-
    SplineFont *sf;
 
    if (_sf->cidmaster != NULL)
@@ -1505,9 +1469,7 @@ void SFConvertLayerToOrder3(SplineFont *_sf, int layer) {
 
 void SFConvertGridToOrder3(SplineFont *_sf) {
    int k;
-
    SplineSet *new;
-
    SplineFont *sf;
 
    if (_sf->cidmaster != NULL)
@@ -1541,9 +1503,7 @@ void SFConvertToOrder3(SplineFont *_sf) {
 
 void SplineRefigure2(Spline * spline) {
    SplinePoint *from=spline->from, *to=spline->to;
-
    Spline1D *xsp=&spline->splines[0], *ysp=&spline->splines[1];
-
    Spline old;
 
 #ifdef DEBUG
@@ -1672,15 +1632,10 @@ static int IsHV(Spline *spline,int isfrom) {
 
 void SplineRefigureFixup(Spline * spline) {
    SplinePoint *from, *to, *prev, *next;
-
    BasePoint foff, toff, unit, new;
-
-   bigreal len;
-
+   double len;
    enum pointtype fpt, tpt;
-
    int done=false;
-
    extern int snaptoint;
 
    if (!spline->order2) {
