@@ -1,4 +1,4 @@
-/* $Id: ufo.c 4064 2015-06-25 14:15:40Z mskala $ */
+/* $Id: ufo.c 4464 2015-11-30 09:57:27Z mskala $ */
 /* Copyright (C) 2003-2012  George Williams
  * Copyright (C) 2015  Matthew Skala
  *
@@ -38,6 +38,7 @@
 #include <locale.h>
 #include <chardata.h>
 #include <gfile.h>
+#include <limits.h>
 #include <ustring.h>
 #include <unistd.h>
 #include <sys/types.h>
@@ -156,7 +157,6 @@ static int _GlifDump(AFILE *glif,SplineChar *sc,int layer) {
       /*  I've been asked to do that too */
       if (sc->layers[layer].refs != NULL) {
 	 RefChar **refs;
-
 	 int i, cnt;
 
 	 for (cnt=0, ref=sc->layers[layer].refs; ref != NULL;
@@ -877,7 +877,6 @@ SplineSet *SplinePointListInterpretGlif(SplineFont *sf, char *filename,
 #      undef iconv_close
 #   endif
 
-#   undef extended		/* used in xlink.h */
 #   include <libxml/parser.h>
 
 #   ifdef __CygWin
@@ -993,6 +992,37 @@ static StemInfo *GlifParseHints(xmlDocPtr doc,xmlNodePtr dict,
    return (head);
 }
 
+/* Finds or adds an AnchorClass of the given name. Resets it to have the given subtable if not NULL */
+static AnchorClass *SFFindOrAddAnchorClass(SplineFont *sf,char *name,struct lookup_subtable *sub) {
+   AnchorClass *ac;
+   int actype = act_unknown;
+   for ( ac=sf->anchor; ac!=NULL; ac=ac->next )
+     if (strcmp(name,ac->name)==0)
+       break;
+   if ( ac!=NULL && ( sub==NULL || ac->subtable==sub ) )
+     return( ac );
+   if ( sub!=NULL )
+     actype = sub->lookup->lookup_type==gpos_cursive ? act_curs :
+     sub->lookup->lookup_type==gpos_mark2base ? act_mark :
+     sub->lookup->lookup_type==gpos_mark2ligature ? act_mklg :
+     sub->lookup->lookup_type==gpos_mark2mark ? act_mkmk :
+     act_unknown;
+   if ( ac==NULL ) {
+      ac=chunkalloc(sizeof(AnchorClass));
+      ac->subtable=sub;
+      ac->type=actype;
+      ac->name=fastrdup(name);
+      ac->next=sf->anchor;
+      sf->anchor=ac;
+   }
+   else if ((sub!=NULL) && (ac->subtable!=sub)) {
+      ac->subtable=sub;
+      ac->type=actype;
+   }
+   return ac;
+}
+
+
 static SplineChar *_UFOLoadGlyph(SplineFont *sf,xmlDocPtr doc,
 				 char *glifname, char *glyphname,
 				 SplineChar * existingglyph, int layerdest) {
@@ -1180,13 +1210,9 @@ static SplineChar *_UFOLoadGlyph(SplineFont *sf,xmlDocPtr doc,
 		  if (sname != NULL) {
 		     /* make an AP and if necessary an AC */
 		     AnchorPoint *ap=chunkalloc(sizeof(AnchorPoint));
-
 		     AnchorClass *ac;
-
 		     char *namep=*sname=='_' ? sname + 1 : sname;
-
 		     char *xs=(char *) xmlGetProp(points, (xmlChar *) "x");
-
 		     char *ys=(char *) xmlGetProp(points, (xmlChar *) "y");
 
 		     ap->me.x=strtod(xs, NULL);
@@ -1218,9 +1244,7 @@ static SplineChar *_UFOLoadGlyph(SplineFont *sf,xmlDocPtr doc,
 	       for (points=contour->children; points != NULL;
 		    points=points->next) {
 		  char *xs, *ys, *type, *pname, *smooths;
-
 		  double x, y;
-
 		  int smooth=0;
 
 		  // We discard any entities in the splineset that are not points.
@@ -1547,7 +1571,7 @@ static void UFORefFixup(SplineFont *sf,SplineChar *sc) {
 	 SplineCharFree(r->sc);
 	 r->sc=rsc;
 	 prev=r;
-	 SCReinstanciateRefChar(sc, r, ly_fore);
+	 SCReinstantiateRefChar(sc, r, ly_fore);
       }
    }
 }
@@ -1591,7 +1615,6 @@ static void UFOLoadGlyphs(SplineFont *sf,char *glyphdir,int layerdest) {
 	 char *glyphname =
 	    (char *) xmlNodeListGetString(doc, keys->children, true);
 	 int newsc=0;
-
 	 SplineChar *existingglyph=NULL;
 
 	 if (glyphname != NULL) {
@@ -1977,12 +2000,13 @@ SplineFont *SFReadUFO(char *basedir, int flags) {
 	       sf->pfminfo.weight=strtol((char *) valname, &end, 10);
 	    else if (xmlStrcmp(keyname + 11, (xmlChar *) "VendorID")==0) {
 	       const int os2_vendor_sz=sizeof(sf->pfminfo.os2_vendor);
+	       int valname_len;
 
-	       const int valname_len=c_strlen(valname);
-
-	       if (valname && valname_len <= os2_vendor_sz)
-		  strncpy(sf->pfminfo.os2_vendor, valname, valname_len);
-
+	       if (valname &&
+		   (valname_len=strlen((const char *)valname))
+		   <=os2_vendor_sz)
+		  strncpy(sf->pfminfo.os2_vendor,(const char *)valname,
+			  valname_len);
 	       char *temp=sf->pfminfo.os2_vendor + os2_vendor_sz - 1;
 
 	       while (*temp==0 && temp >= sf->pfminfo.os2_vendor)
@@ -2165,7 +2189,6 @@ SplineFont *SFReadUFO(char *basedir, int flags) {
        strncmp(sf->names->names[ttf_version], "Version ", 8)==0)
       sf->version=fastrdup(sf->names->names[ttf_version] + 8);
    xmlFreeDoc(doc);
-
    char *layercontentsname=buildname(basedir, "layercontents.plist");
    char **layernames=NULL;
 
@@ -2173,11 +2196,8 @@ SplineFont *SFReadUFO(char *basedir, int flags) {
       return (NULL);
    } else if (GFileExists(layercontentsname)) {
       xmlDocPtr layercontentsdoc=NULL;
-
       xmlNodePtr layercontentsplist=NULL;
-
       xmlNodePtr layercontentsdict=NULL;
-
       xmlNodePtr layercontentslayer=NULL;
       xmlNodePtr layercontentsvalue=NULL;
       int layercontentslayercount=0;
@@ -2207,7 +2227,6 @@ SplineFont *SFReadUFO(char *basedir, int flags) {
 		   (layercontentslayer->name,
 		    (const xmlChar *) "array")==0) {
 		  xmlChar *layerlabel=NULL;
-
 		  xmlChar *layerglyphdirname=NULL;
 
 		  layercontentsvaluecount=0;
