@@ -1,4 +1,4 @@
-/* $Id: winfonts.c 4064 2015-06-25 14:15:40Z mskala $ */
+/* $Id: winfonts.c 4464 2015-11-30 09:57:27Z mskala $ */
 /* Copyright (C) 2002-2012  George Williams
  * Copyright (C) 2015  Matthew Skala
  *
@@ -186,17 +186,11 @@ static void lputlong(AFILE *f,int val) {
 
 static int FNT_Load(AFILE *fnt,SplineFont *sf) {
    struct fntheader fntheader;
-
    struct v3chars charinfo[258];	/* Max size */
-
    int i, j, k, ch;
-
    uint32_t base=aftell(fnt);
-
    char *pt, *spt, *temp;
-
    BDFFont *bdf;
-
    BDFChar *bdfc;
 
    memset(&fntheader, 0, sizeof(fntheader));
@@ -375,15 +369,10 @@ static int FNT_Load(AFILE *fnt,SplineFont *sf) {
 
 SplineFont *SFReadWinFON(char *filename, int toback) {
    AFILE *fon;
-
    int magic, i, shift_size;
-
    SplineFont *sf;
-
    uint32_t neoffset, recoffset, recend;
-
    int font_count;
-
    BDFFont *bdf, *next;
 
    fon=afopen(filename, "rb");
@@ -440,7 +429,6 @@ SplineFont *SFReadWinFON(char *filename, int toback) {
       }
       for (i=0; i < font_count; ++i) {
 	 uint32_t here=aftell(fon);
-
 	 uint32_t offset=lgetushort(fon) << shift_size;
 
 	 afseek(fon, offset, SEEK_SET);	/* FontDirEntries need a +4 here */
@@ -481,21 +469,13 @@ SplineFont *SFReadWinFON(char *filename, int toback) {
 
 static int _FntFontDump(AFILE *file,BDFFont *font,EncMap *map,int res) {
    uint32_t startpos, endpos, namelocpos, datapos, namepos;
-
    int i, j, k, l;
-
    int ch;
-
    int cnt, badch, defch;
-
    int first, last, avgwid, maxwid, samewid, maxy, miny, widbytes, spacesize;
-
    struct pfminfo pfminfo;
-
    int complained=false;
-
    int gid;
-
    BDFChar *bdfc;
 
    if (font->clut != NULL)
@@ -548,9 +528,10 @@ static int _FntFontDump(AFILE *file,BDFFont *font,EncMap *map,int res) {
    SFDefaultOS2Info(&pfminfo, font->sf, font->sf->fontname);
    widbytes=avgwid + spacesize;
    if (cnt != 0)
-      avgwid=rint(avgwid / (bigreal) cnt);
+      avgwid=rint(avgwid / (double) cnt);
    gid=map->map['X'];
-   if (font->glyphs[gid] != NULL && font->glyphs[gid]->sc != NULL &&
+   if (gid!=-1 &&
+       font->glyphs[gid] != NULL && font->glyphs[gid]->sc != NULL &&
        font->glyphs[gid]->sc->unicodeenc=='X')
       avgwid=font->glyphs[gid]->width;
 
@@ -586,7 +567,7 @@ static int _FntFontDump(AFILE *file,BDFFont *font,EncMap *map,int res) {
    lputshort(file, 0);		/* internal_leading */
    lputshort(file,		/* external_leading */
 	     rint(pfminfo.linegap * font->pixelsize /
-		  (bigreal) (font->sf->ascent + font->sf->descent)));
+		  (double) (font->sf->ascent + font->sf->descent)));
    if (font->sf->italicangle != 0
        || strstrmatch(font->sf->fontname, "ital") != NULL
        || strstrmatch(font->sf->fontname, "kurs") != NULL
@@ -648,7 +629,6 @@ static int _FntFontDump(AFILE *file,BDFFont *font,EncMap *map,int res) {
    widbytes=0;
    for (i=first; i <= last; ++i) {
       int gid=map->map[i];
-
       BDFChar *bdfc=gid==-1 ? NULL : font->glyphs[gid];
 
       if (bdfc != NULL && bdfc->width > 0) {
@@ -701,7 +681,6 @@ static int _FntFontDump(AFILE *file,BDFFont *font,EncMap *map,int res) {
 
 int FNTFontDump(char *filename, BDFFont * font, EncMap * map, int res) {
    AFILE *file;
-
    int ret;
 
    file=afopen(filename, "wb");
